@@ -11,7 +11,7 @@
 #include "itkImageRegionIteratorWithIndex.h"
 #include "vnl/algo/vnl_determinant.h"
 
-#include "ReadWriteImage.h"
+#include "ReadWriteData.h"
 
 #include "vnl/algo/vnl_determinant.h"
 #include "itkDiscreteGaussianImageFilter.h"
@@ -111,7 +111,7 @@ typename ImageType::Pointer ReadAnImage(char* fn)
     }
   catch( ... )
     {
-    return NULL;
+    return ITK_NULLPTR;
     }
   return reffilter->GetOutput();
 }
@@ -122,6 +122,8 @@ TransformVector(TDisplacementField* field, typename TImage::IndexType index )
 {
   enum { ImageDimension = TImage::ImageDimension };
   typename TDisplacementField::PixelType vec = field->GetPixel(index);
+  return vec;
+  /* buggy code from before
   typename TDisplacementField::PixelType newvec;
   newvec.Fill(0);
   for( unsigned int row = 0; row < ImageDimension; row++ )
@@ -131,8 +133,8 @@ TransformVector(TDisplacementField* field, typename TImage::IndexType index )
       newvec[row] += vec[col] * field->GetDirection()[row][col];
       }
     }
-
   return newvec;
+  */
 }
 
 template <class TImage, class TDisplacementField>
@@ -183,7 +185,7 @@ ComputeJacobian(TDisplacementField* field, char* fnm, char* maskfn, bool uselog
     antsjacobiansplit(projvec, 'x', v);
     for( std::vector<std::string>::size_type i = 0; i < v.size(); ++i )
       {
-      antscout << v[i] << '\n';
+      std::cout << v[i] << '\n';
       }
     }
 
@@ -192,7 +194,7 @@ ComputeJacobian(TDisplacementField* field, char* fnm, char* maskfn, bool uselog
   enum { ImageDimension = TImage::ImageDimension };
   typedef itk::Image<float, ImageDimension> FloatImageType;
   typename FloatImageType::RegionType m_JacobianRegion;
-  typename FloatImageType::Pointer mask = NULL;
+  typename FloatImageType::Pointer mask = ITK_NULLPTR;
   typename FieldType::PixelType pvec;
   if( !v.empty() )
     {
@@ -201,7 +203,7 @@ ComputeJacobian(TDisplacementField* field, char* fnm, char* maskfn, bool uselog
       pvec[i] = atof(v[i].c_str() );
       }
     pvec = pvec / pvec.GetNorm();
-    antscout << " using projection vector " << pvec << std::endl;
+    std::cout << " using projection vector " << pvec << std::endl;
     }
   mask = ReadAnImage<FloatImageType>(maskfn);
 
@@ -220,7 +222,7 @@ ComputeJacobian(TDisplacementField* field, char* fnm, char* maskfn, bool uselog
     typedef itk::MatrixOffsetTransformBase<double, ImageDimension, ImageDimension>             TransformType;
     typedef itk::WarpImageMultiTransformFilter<ImageType, ImageType, FieldType, TransformType> WarperType;
     typename WarperType::Pointer  warper = WarperType::New();
-    warper->SetInput(NULL);
+    warper->SetInput(ITK_NULLPTR);
     warper->SetEdgePaddingValue( 0);
     warper->SetSmoothScale(1);
     warper->PushBackDisplacementFieldTransform(field);
@@ -231,9 +233,9 @@ ComputeJacobian(TDisplacementField* field, char* fnm, char* maskfn, bool uselog
     typename writertype::Pointer writer = writertype::New();
     std::string fng = std::string(fnm) + "grid.nii.gz";
     writer->SetFileName(fng.c_str() );
-    writer->SetInput(NULL);
+    writer->SetInput(ITK_NULLPTR);
     writer->Write();
-    antscout << " Grid done ";
+    std::cout << " Grid done ";
     }
   typename FloatImageType::SizeType m_FieldSize = field->GetLargestPossibleRegion().GetSize();
 
@@ -262,7 +264,6 @@ ComputeJacobian(TDisplacementField* field, char* fnm, char* maskfn, bool uselog
   unsigned int posoff = 1;
   float        space = 1.0;
 
-  typedef itk::Vector<float, ImageDimension> VectorType;
 
   typename FieldType::PixelType dPix;
   typename FieldType::PixelType lpix;
@@ -365,14 +366,14 @@ ComputeJacobian(TDisplacementField* field, char* fnm, char* maskfn, bool uselog
             {
             val = dPix[col] / sp[col];
             }
-          //        antscout << " row " << row << " col " << col << " val " << val << std::endl;
+          //        std::cout << " row " << row << " col " << col << " val " << val << std::endl;
           jMatrix.put(col, row, val);
           avgMatrix.put(col, row, avgMatrix.get(col, row) + val);
           }
         }
 
       // the determinant of the jacobian matrix
-      // antscout << " get det " << std::endl;
+      // std::cout << " get det " << std::endl;
       det = vnl_determinant(jMatrix);
       //    float prodval = m_FloatImage->GetPixel(rindex);
       if( det < 0.0 )
@@ -385,11 +386,11 @@ ComputeJacobian(TDisplacementField* field, char* fnm, char* maskfn, bool uselog
       // totaljac+=det;
       } // oktosample if
     }
-  antscout << " avg Mat " << avgMatrix / (float)ct << std::endl;
+  std::cout << " avg Mat " << avgMatrix / (float)ct << std::endl;
 
   if( norm && mask )
     {
-    antscout << " using mask && normalizing " << std::endl;
+    std::cout << " using mask && normalizing " << std::endl;
     /*
     typedef itk::DiscreteGaussianImageFilter<TImage, TImage> dgf;
     float sig=2.0;
@@ -480,12 +481,12 @@ ComputeJacobian(TDisplacementField* field, char* fnm, char* maskfn, bool uselog
 template <unsigned int ImageDimension>
 int Jacobian(int argc, char *argv[])
 {
-  //  antscout << " enter " << ImageDimension << std::endl;
+  //  std::cout << " enter " << ImageDimension << std::endl;
   if( argc < 3 )
     {
-    antscout << "Usage:   Jacobian gWarp outfile uselog maskfn normbytotalbool VectorToProjectWarpAgainst "
+    std::cout << "Usage:   Jacobian gWarp outfile uselog maskfn normbytotalbool VectorToProjectWarpAgainst "
              << std::endl;
-    antscout
+    std::cout
       << " VectorToProjectWarpAgainst should be in the form 1.0x0.0x0.0 where x separates vector components "
       << std::endl;
     if( argc >= 2 &&
@@ -499,29 +500,23 @@ int Jacobian(int argc, char *argv[])
   typedef itk::Vector<float, ImageDimension>                     VectorType;
   typedef itk::Image<VectorType, ImageDimension>                 FieldType;
   typedef itk::Image<PixelType, ImageDimension>                  ImageType;
-  typedef itk::ImageFileReader<ImageType>                        readertype;
-  typedef itk::ImageFileWriter<ImageType>                        writertype;
-  typedef typename  ImageType::IndexType                         IndexType;
-  typedef typename  ImageType::SizeType                          SizeType;
-  typedef typename  ImageType::SpacingType                       SpacingType;
-  typedef itk::LinearInterpolateImageFunction<ImageType, double> InterpolatorType;
 
   typedef itk::ImageFileReader<FieldType> ReaderType;
-  // antscout << "read warp " << std::string(argv[1]) << std::endl;
+  // std::cout << "read warp " << std::string(argv[1]) << std::endl;
   typename ReaderType::Pointer reader = ReaderType::New();
   reader->SetFileName( argv[1] );
   //  reader->SetUseAvantsNamingConvention( true );
   reader->Update();
   typename FieldType::Pointer gWarp = reader->GetOutput();
   //
-  // antscout << "read warp 2 " << std::endl;
+  // std::cout << "read warp 2 " << std::endl;
   // typename FieldType::Pointer gWarp = ReadWarpFromFile<ImageType,FieldType>(argv[1],"vec.nii");
 
   // here hWarp is changed in place to be fWarp
 //  Jacobian<ImageType,FieldType>(gWarp,argv[2]);
-//  antscout << " vecanidiff " << std::endl;
+//  std::cout << " vecanidiff " << std::endl;
 //  gWarp = VectorAniDiff<FieldType>(gWarp , atoi(argv[3]) );
-//  antscout << " vecanidiffdone " << std::endl;
+//  std::cout << " vecanidiffdone " << std::endl;
   bool uselog = false;
   if( argc > 3 )
     {
@@ -543,7 +538,7 @@ int Jacobian(int argc, char *argv[])
     maskfn = std::string( argv[4] );
     }
 
-  //  antscout << " name "<< argv[2] <<  " mask " << argv[4] << " norm " << norm << " Log " << uselog << std::endl;
+  //  std::cout << " name "<< argv[2] <<  " mask " << argv[4] << " norm " << norm << " Log " << uselog << std::endl;
   ComputeJacobian<ImageType, FieldType>(gWarp, argv[2], const_cast<char *>( maskfn.c_str() ), uselog, norm, projvec);
 //  DiffeomorphicJacobian<ImageType,ImageType,FieldType>(gWarp,1,argv[2]);
 //  if (argc > 3) DiffeomorphicMetric<ImageType,ImageType,FieldType>(gWarp,argv[2]);
@@ -553,7 +548,7 @@ int Jacobian(int argc, char *argv[])
 
 // entry point for the library; parameter 'args' is equivalent to 'argv' in (argc,argv) of commandline parameters to
 // 'main()'
-int ANTSJacobian( std::vector<std::string> args, std::ostream* out_stream = NULL )
+int ANTSJacobian( std::vector<std::string> args, std::ostream* /*out_stream = NULL */)
 {
   // put the arguments coming in as 'args' into standard (argc,argv) format;
   // 'args' doesn't have the command name as first, argument, so add it manually;
@@ -570,7 +565,7 @@ int ANTSJacobian( std::vector<std::string> args, std::ostream* out_stream = NULL
     // place the null character in the end
     argv[i][args[i].length()] = '\0';
     }
-  argv[argc] = 0;
+  argv[argc] = ITK_NULLPTR;
   // class to automatically cleanup argv upon destruction
   class Cleanup_argv
   {
@@ -594,15 +589,18 @@ private:
   };
   Cleanup_argv cleanup_argv( argv, argc + 1 );
 
-  antscout->set_stream( out_stream );
+  // antscout->set_stream( out_stream );
+  std::cout << "Sorry! " << argv[0] << " is deprecated " << std::endl;
+  std::cout << "Please use CreateJacobianDeterminantImage " << std::endl;
+  return EXIT_SUCCESS;
 
   if( argc < 3 )
     {
-    antscout << "Usage: " << argv[0] << " ImageDim gWarp outfile uselog maskfn normbytotalbool projectionvector "
+    std::cout << "Usage: " << argv[0] << " ImageDim gWarp outfile uselog maskfn normbytotalbool projectionvector "
              << std::endl;
-    antscout << " for example " << std::endl
+    std::cout << " for example " << std::endl
              << " ANTSJacobian 3  myWarp.nii   Output  1   templatebrainmask.nii   1 1x0 " << std::endl;
-    antscout
+    std::cout
       <<
       " the last 1 normalizes the jacobian by the total in the mask.  use this to adjust for head size. 1x0 will project the warp along direction 1,0 --- don't add this option if you dont want to do this "
       << std::endl;
@@ -627,7 +625,7 @@ private:
       }
       break;
     default:
-      antscout << "Unsupported dimension" << std::endl;
+      std::cout << "Unsupported dimension" << std::endl;
       return EXIT_FAILURE;
     }
 
