@@ -23,7 +23,7 @@
 #include <cstdlib>
 #include <ctime>
 #include <iostream>
-#include "ReadWriteImage.h"
+#include "ReadWriteData.h"
 
 #include "itkMersenneTwisterRandomVariateGenerator.h"
 #include "itkHistogramMatchingImageFilter.h"
@@ -48,7 +48,7 @@ namespace ants
 template <class TImageType>
 void ReadImage(itk::SmartPointer<TImageType> & target, const char *file, bool copy)
 {
-  //  antscout << " reading b " << std::string(file) << std::endl;
+  //  std::cout << " reading b " << std::string(file) << std::endl;
   typedef itk::ImageFileReader<TImageType> readertype;
   typename readertype::Pointer reader = readertype::New();
   reader->SetFileName(file);
@@ -140,7 +140,7 @@ template <class TInputImage>
 void
 HistogramMatch(typename TInputImage::Pointer m_InputFixedImage,  typename TInputImage::Pointer m_InputMovingImage)
 {
-  antscout << " MATCHING INTENSITIES " << std::endl;
+  std::cout << " MATCHING INTENSITIES " << std::endl;
 
   typedef itk::HistogramMatchingImageFilter<TInputImage, TInputImage> FilterType;
   typename FilterType::Pointer filter = FilterType::New();
@@ -264,8 +264,8 @@ GetClusterStat(typename TImage::Pointer image, float Tthreshold, unsigned int mi
   threshold_hi = 1.e9;
 
   threshold->SetInput(image);
-  threshold->SetInsideValue(itk::NumericTraits<InternalPixelType>::One);
-  threshold->SetOutsideValue(itk::NumericTraits<InternalPixelType>::Zero);
+  threshold->SetInsideValue(itk::NumericTraits<InternalPixelType>::OneValue());
+  threshold->SetOutsideValue(itk::NumericTraits<InternalPixelType>::ZeroValue());
   threshold->SetLowerThreshold(threshold_low);
   threshold->SetUpperThreshold(threshold_hi);
   threshold->Update();
@@ -286,8 +286,8 @@ GetClusterStat(typename TImage::Pointer image, float Tthreshold, unsigned int mi
     }
   catch( itk::ExceptionObject & excep )
     {
-    antscout << "Relabel: exception caught !" << std::endl;
-    antscout << excep << std::endl;
+    std::cout << "Relabel: exception caught !" << std::endl;
+    std::cout << excep << std::endl;
     }
 
   typename TImage::Pointer Clusters = MakeNewImage<TImage>(relabel->GetOutput(), 0);
@@ -375,7 +375,7 @@ GetClusterStat(typename TImage::Pointer image, float Tthreshold, unsigned int mi
     }
 
   //  for (int i=0; i<=maximum; i++)
-  //  antscout << " label " << i << " ct is: " << histogram[i] << std::endl;
+  //  std::cout << " label " << i << " ct is: " << histogram[i] << std::endl;
 
   if( TRUTH )
     {
@@ -483,7 +483,7 @@ float npdf(std::vector<float> vec, bool opt,  float www)
     {
     return mean;
     }
-  //    else antscout << " Mean " << mean << " var " << var << std::endl;
+  //    else std::cout << " Mean " << mean << " var " << var << std::endl;
 
   // eval parzen probability
   std::vector<float> prob(size);
@@ -502,7 +502,7 @@ float npdf(std::vector<float> vec, bool opt,  float www)
     {
     width = sqrt(var) / 2.0;
     }
-  //        antscout << " using width " << width << std::endl;
+  //        std::cout << " using width " << width << std::endl;
 //        float N=(float)size;
   for( unsigned int j = 0; j < size; j++ )
     {
@@ -627,17 +627,9 @@ template <unsigned int ImageDimension>
 int ImageSetStatistics(int argc, char *argv[])
 {
   typedef float                                                           PixelType;
-  typedef itk::Vector<float, ImageDimension>                              VectorType;
-  typedef itk::Image<VectorType, ImageDimension>                          FieldType;
   typedef itk::Image<PixelType, ImageDimension>                           ImageType;
   typedef itk::ImageFileReader<ImageType>                                 readertype;
-  typedef itk::ImageFileWriter<ImageType>                                 writertype;
   typedef typename ImageType::IndexType                                   IndexType;
-  typedef typename ImageType::SizeType                                    SizeType;
-  typedef typename ImageType::SpacingType                                 SpacingType;
-  typedef itk::AffineTransform<double, ImageDimension>                    AffineTransformType;
-  typedef itk::LinearInterpolateImageFunction<ImageType, double>          InterpolatorType1;
-  typedef itk::NearestNeighborInterpolateImageFunction<ImageType, double> InterpolatorType2;
   typedef itk::ImageRegionIteratorWithIndex<ImageType>                    Iterator;
   unsigned int mch = 0;
   int          argct = 2;
@@ -661,14 +653,14 @@ int ImageSetStatistics(int argc, char *argv[])
   unsigned int localmeanrad = 0;
   // if (argc > argct) { localmeanrad=atoi(argv[argct]);argct++;}
 
-  //  antscout <<" roifn " << roifn << " fn1 " << fn1 << " whichstat " << whichstat << std::endl;
+  //  std::cout <<" roifn " << roifn << " fn1 " << fn1 << " whichstat " << whichstat << std::endl;
 
-  typename ImageType::Pointer outimage = NULL;
-  typename ImageType::Pointer ROIimg = NULL;
+  typename ImageType::Pointer outimage = ITK_NULLPTR;
+  typename ImageType::Pointer ROIimg = ITK_NULLPTR;
 
   if( roifn.length() > 4 )
     {
-    antscout << " reading roi image " << roifn << std::endl;
+    std::cout << " reading roi image " << roifn << std::endl;
     typename readertype::Pointer reader2 = readertype::New();
     reader2->SetFileName(roifn.c_str() );
     reader2->UpdateLargestPossibleRegion();
@@ -678,8 +670,8 @@ int ImageSetStatistics(int argc, char *argv[])
       }
     catch( ... )
       {
-      ROIimg = NULL;
-      antscout << " Error reading ROI image " << std::endl;
+      ROIimg = ITK_NULLPTR;
+      std::cout << " Error reading ROI image " << std::endl;
       //  return 0;
       }
     }
@@ -693,7 +685,7 @@ int ImageSetStatistics(int argc, char *argv[])
     std::ifstream inputStreamA( fn1.c_str(), std::ios::in );
     if( !inputStreamA.is_open() )
       {
-      antscout << "Can't open parameter file: " << fn1 << std::endl;
+      std::cout << "Can't open parameter file: " << fn1 << std::endl;
       return -1;
       }
     while( !inputStreamA.eof() )
@@ -702,8 +694,8 @@ int ImageSetStatistics(int argc, char *argv[])
 
       if( sscanf( lineBuffer, "%s ", filenm) != 1 )
         {
-        //      antscout << "Done.  read " << lineBuffer << " n " << ct1 << " files " << std::endl;
-        // antscout << std::endl;
+        //      std::cout << "Done.  read " << lineBuffer << " n " << ct1 << " files " << std::endl;
+        // std::cout << std::endl;
         continue;
         }
       else
@@ -714,7 +706,7 @@ int ImageSetStatistics(int argc, char *argv[])
 
     inputStreamA.close();
     }
-  antscout << " NFiles1 " << filecount1 << std::endl;
+  std::cout << " NFiles1 " << filecount1 << std::endl;
 
   unsigned int filecount2 = 0;
   if( simimagelist.length() > 2 && ( whichstat == 5 || whichstat == 6 ) )
@@ -722,7 +714,7 @@ int ImageSetStatistics(int argc, char *argv[])
     std::ifstream inputStreamA( simimagelist.c_str(), std::ios::in );
     if( !inputStreamA.is_open() )
       {
-      antscout << "Can't open parameter file: " << fn1 << std::endl;
+      std::cout << "Can't open parameter file: " << fn1 << std::endl;
       return -1;
       }
     while( !inputStreamA.eof() )
@@ -731,8 +723,8 @@ int ImageSetStatistics(int argc, char *argv[])
 
       if( sscanf( lineBuffer, "%s ", filenm) != 1 )
         {
-        //      antscout << "Done.  read " << lineBuffer << " n " << ct1 << " files " << std::endl;
-        // antscout << std::endl;
+        //      std::cout << "Done.  read " << lineBuffer << " n " << ct1 << " files " << std::endl;
+        // std::cout << std::endl;
         continue;
         }
       else
@@ -744,14 +736,14 @@ int ImageSetStatistics(int argc, char *argv[])
     inputStreamA.close();
     if( filecount1 != filecount2 )
       {
-      antscout
+      std::cout
         <<
         " the number of similarity images does not match the number of label images --- thus, we have to get out of here !! i.e. something's wrong. "
         << std::endl;
       return 1;
       }
     } // fi simimagelist
-  antscout << " NFiles2 " << filecount2 << std::endl;
+  std::cout << " NFiles2 " << filecount2 << std::endl;
 
   typename ImageType::Pointer meanimage;
   std::vector<typename ImageType::Pointer> imagestack;
@@ -763,7 +755,7 @@ int ImageSetStatistics(int argc, char *argv[])
   std::ifstream inputStreamA( fn1.c_str(), std::ios::in );
   if( !inputStreamA.is_open() )
     {
-    antscout << "Can't open parameter file: " << fn1 << std::endl;
+    std::cout << "Can't open parameter file: " << fn1 << std::endl;
     return -1;
     }
   while( !inputStreamA.eof() )
@@ -772,8 +764,8 @@ int ImageSetStatistics(int argc, char *argv[])
 
     if( sscanf( lineBuffer, "%s ", filenm) != 1 )
       {
-      //      antscout << "Done.  read " << lineBuffer << " n " << ct1 << " files " << std::endl;
-      // antscout << std::endl;
+      //      std::cout << "Done.  read " << lineBuffer << " n " << ct1 << " files " << std::endl;
+      // std::cout << std::endl;
       continue;
       }
     else
@@ -788,7 +780,7 @@ int ImageSetStatistics(int argc, char *argv[])
         {
         LocalMean<ImageType>(imagestack[ct], localmeanrad, meanimage);
         }
-      antscout << " done reading " << (float) ct / (float ) filecount1 << std::endl;
+      std::cout << " done reading " << (float) ct / (float ) filecount1 << std::endl;
       ct++;
       }
     }
@@ -804,7 +796,7 @@ int ImageSetStatistics(int argc, char *argv[])
     inputStreamA.open( simimagelist.c_str() );
     if( !inputStreamA.is_open() )
       {
-      antscout << "Can't open parameter file: " << fn1 << std::endl;
+      std::cout << "Can't open parameter file: " << fn1 << std::endl;
       return -1;
       }
     while( !inputStreamA.eof() )
@@ -840,7 +832,7 @@ int ImageSetStatistics(int argc, char *argv[])
     {
     if( ct % prog == 0 )
       {
-      antscout << " % " << (float) ct / (float) nvox << std::endl;
+      std::cout << " % " << (float) ct / (float) nvox << std::endl;
       }
     ct++;
     IndexType    ind = vfIter.GetIndex();
@@ -880,7 +872,7 @@ int ImageSetStatistics(int argc, char *argv[])
           stat = npdf(voxels, true, www);
           if( ct == 1 )
             {
-            antscout << "the max prob appearance \n";
+            std::cout << "the max prob appearance \n";
             }
           }
           break;
@@ -889,7 +881,7 @@ int ImageSetStatistics(int argc, char *argv[])
           stat = npdf(voxels, false, www);
           if( ct == 1 )
             {
-            antscout << "the probabilistically weighted appearance " << www << " \n";
+            std::cout << "the probabilistically weighted appearance " << www << " \n";
             }
           }
           break;
@@ -899,7 +891,7 @@ int ImageSetStatistics(int argc, char *argv[])
           stat = trimmean(voxels);
           if( ct == 1 )
             {
-            antscout << "the trimmed mean appearance \n";
+            std::cout << "the trimmed mean appearance \n";
             }
           }
           break;
@@ -909,7 +901,7 @@ int ImageSetStatistics(int argc, char *argv[])
           stat = myantsmax(voxels);
           if( ct == 1 )
             {
-            antscout << "the maximum appearance \n";
+            std::cout << "the maximum appearance \n";
             }
           }
           break;
@@ -918,7 +910,7 @@ int ImageSetStatistics(int argc, char *argv[])
           stat = myantssimilaritymaxlabel(voxels, similarities, true);
           if( ct == 1 )
             {
-            antscout << "the maximum similarity-based label \n";
+            std::cout << "the maximum similarity-based label \n";
             }
           }
           break;
@@ -927,7 +919,7 @@ int ImageSetStatistics(int argc, char *argv[])
           stat = myantssimilaritymaxlabel(voxels, similarities, false);
           if( ct == 1 )
             {
-            antscout << "which image provides the maximum similarity-based label \n";
+            std::cout << "which image provides the maximum similarity-based label \n";
             }
           }
           break;
@@ -936,7 +928,7 @@ int ImageSetStatistics(int argc, char *argv[])
           stat = voxels[maxval];
           if( ct == 1 )
             {
-            antscout << "which image provides the maximum similarity-based label \n";
+            std::cout << "which image provides the maximum similarity-based label \n";
             }
           }
           break;
@@ -946,7 +938,7 @@ int ImageSetStatistics(int argc, char *argv[])
           stat = median(voxels);
           if( ct == 1 )
             {
-            antscout << "the median appearance \n";
+            std::cout << "the median appearance \n";
             }
           }
           break;
@@ -965,13 +957,13 @@ int ImageSetStatistics(int argc, char *argv[])
     }
   WriteImage<ImageType>(StatImage, outfn.c_str() );
 
-  antscout << " Done " << std::endl;
+  std::cout << " Done " << std::endl;
   return 0;
 }
 
 // entry point for the library; parameter 'args' is equivalent to 'argv' in (argc,argv) of commandline parameters to
 // 'main()'
-int ImageSetStatistics( std::vector<std::string> args, std::ostream* out_stream = NULL )
+int ImageSetStatistics( std::vector<std::string> args, std::ostream* /*out_stream = NULL */ )
 {
   // put the arguments coming in as 'args' into standard (argc,argv) format;
   // 'args' doesn't have the command name as first, argument, so add it manually;
@@ -989,7 +981,7 @@ int ImageSetStatistics( std::vector<std::string> args, std::ostream* out_stream
     // place the null character in the end
     argv[i][args[i].length()] = '\0';
     }
-  argv[argc] = 0;
+  argv[argc] = ITK_NULLPTR;
   // class to automatically cleanup argv upon destruction
   class Cleanup_argv
   {
@@ -1013,21 +1005,21 @@ private:
   };
   Cleanup_argv cleanup_argv( argv, argc + 1 );
 
-  antscout->set_stream( out_stream );
+  // antscout->set_stream( out_stream );
 
   if( argc < 4 )
     {
-    antscout << "Usage:  " << std::endl;
-    antscout << argv[0]
+    std::cout << "Usage:  " << std::endl;
+    std::cout << argv[0]
              <<
       " ImageDimension controlslist.txt outimage.nii whichstat {roi.nii} {imagelist2forsimilarityweightedstats.txt}"
              << std::endl;
-    antscout
+    std::cout
       <<
       " whichstat = 0:  median,  1:  max prob appearance  , 2: weighted mean appearance ,  3: trimmed mean , 4 : max value , option 5 : similarity-weighted (must pass imagelist2 as well) else median , option 6 : same as similarity-weighted option 5 but the label corresponds to the image that provides the best local match ... useful if you want to MRF smooth these indices  , option 7 : similar to 5 but expects the max-value to be stored in the ROI image and uses it to get the intensity ... "
       << std::endl;
-    antscout << " example:   ImageSetStatistics  3   imagelist.txt  maxvalueimage.nii.gz 4 " << std::endl;
-    antscout
+    std::cout << " example:   ImageSetStatistics  3   imagelist.txt  maxvalueimage.nii.gz 4 " << std::endl;
+    std::cout
       <<
       " similarity weighted --- pass in a list of similarity images here which will be used to select the best label --- thus, number of similarity images must match the number of label images . "
       << std::endl;
@@ -1054,7 +1046,7 @@ private:
       }
       break;
     default:
-      antscout << "Unsupported dimension" << std::endl;
+      std::cout << "Unsupported dimension" << std::endl;
       return EXIT_FAILURE;
     }
   return EXIT_SUCCESS;
