@@ -8,9 +8,10 @@
 #include "itkConstantPadImageFilter.h"
 #include "itkExpImageFilter.h"
 #include "itkExtractImageFilter.h"
-#include "ReadWriteImage.h"
+#include "ReadWriteData.h"
 #include "itkImageRegionIterator.h"
 #include "itkImageRegionIteratorWithIndex.h"
+#include "itkLabelStatisticsImageFilter.h"
 #include "itkN4BiasFieldCorrectionImageFilter.h"
 #include "itkOtsuThresholdImageFilter.h"
 #include "itkShrinkImageFilter.h"
@@ -37,12 +38,12 @@ protected:
   };
 public:
 
-  void Execute(itk::Object *caller, const itk::EventObject & event)
+  void Execute(itk::Object *caller, const itk::EventObject & event) ITK_OVERRIDE
   {
     Execute( (const itk::Object *) caller, event);
   }
 
-  void Execute(const itk::Object * object, const itk::EventObject & event)
+  void Execute(const itk::Object * object, const itk::EventObject & event) ITK_OVERRIDE
   {
     const TFilter * filter =
       dynamic_cast<const TFilter *>( object );
@@ -53,14 +54,14 @@ public:
       }
     if( filter->GetElapsedIterations() == 1 )
       {
-      antscout << "Current level = " << filter->GetCurrentLevel() + 1
+      std::cout << "Current level = " << filter->GetCurrentLevel() + 1
                << std::endl;
       }
-    antscout << "  Iteration " << filter->GetElapsedIterations()
+    std::cout << "  Iteration " << filter->GetElapsedIterations()
              << " (of "
              << filter->GetMaximumNumberOfIterations()[filter->GetCurrentLevel()]
              << ").  ";
-    antscout << " Current convergence value = "
+    std::cout << " Current convergence value = "
              << filter->GetCurrentConvergenceMeasurement()
              << " (threshold = " << filter->GetConvergenceThreshold()
              << ")" << std::endl;
@@ -73,10 +74,10 @@ int N4( itk::ants::CommandLineParser *parser )
   typedef float RealType;
 
   typedef itk::Image<RealType, ImageDimension> ImageType;
-  typename ImageType::Pointer inputImage = NULL;
+  typename ImageType::Pointer inputImage = ITK_NULLPTR;
 
   typedef itk::Image<RealType, ImageDimension> MaskImageType;
-  typename MaskImageType::Pointer maskImage = NULL;
+  typename MaskImageType::Pointer maskImage = ITK_NULLPTR;
 
   typedef itk::N4BiasFieldCorrectionImageFilter<ImageType, MaskImageType,
                                                 ImageType> CorrecterType;
@@ -93,7 +94,7 @@ int N4( itk::ants::CommandLineParser *parser )
     }
   else
     {
-    antscout << "Input image not specified." << std::endl;
+    std::cout << "Input image not specified." << std::endl;
     return EXIT_FAILURE;
     }
 
@@ -101,6 +102,8 @@ int N4( itk::ants::CommandLineParser *parser )
    * handle the mask image
    */
 
+  bool isMaskImageSpecified = false;
+
   typename itk::ants::CommandLineParser::OptionType::Pointer maskImageOption =
     parser->GetOption( "mask-image" );
   if( maskImageOption && maskImageOption->GetNumberOfFunctions() )
@@ -109,10 +112,12 @@ int N4( itk::ants::CommandLineParser *parser )
     ReadImage<MaskImageType>( maskImage, inputFile.c_str() );
     maskImage->Update();
     maskImage->DisconnectPipeline();
+
+    isMaskImageSpecified = true;
     }
   if( !maskImage )
     {
-    antscout << "Mask not read.  Creating Otsu mask." << std::endl;
+    std::cout << "Mask not read.  Creating Otsu mask." << std::endl;
     typedef itk::OtsuThresholdImageFilter<ImageType, MaskImageType>
       ThresholderType;
     typename ThresholderType::Pointer otsu = ThresholderType::New();
@@ -126,7 +131,7 @@ int N4( itk::ants::CommandLineParser *parser )
     maskImage->DisconnectPipeline();
     }
 
-  typename ImageType::Pointer weightImage = NULL;
+  typename ImageType::Pointer weightImage = ITK_NULLPTR;
 
   typename itk::ants::CommandLineParser::OptionType::Pointer weightImageOption =
     parser->GetOption( "weight-image" );
@@ -275,7 +280,7 @@ int N4( itk::ants::CommandLineParser *parser )
         }
       else
         {
-        antscout << "Incorrect mesh resolution" << std::endl;
+        std::cout << "Incorrect mesh resolution" << std::endl;
         return EXIT_FAILURE;
         }
       correcter->SetNumberOfControlPoints( numberOfControlPoints );
@@ -356,14 +361,14 @@ int N4( itk::ants::CommandLineParser *parser )
     }
   catch( itk::ExceptionObject & e )
     {
-    antscout << "Exception caught: " << e << std::endl;
+    std::cout << "Exception caught: " << e << std::endl;
     return EXIT_FAILURE;
     }
 
-  correcter->Print( antscout, 3 );
+  correcter->Print( std::cout, 3 );
 
   timer.Stop();
-  antscout << "Elapsed time: " << timer.GetMean() << std::endl;
+  std::cout << "Elapsed time: " << timer.GetMean() << std::endl;
 
   /**
    * output
@@ -412,16 +417,72 @@ int N4( itk::ants::CommandLineParser *parser )
     divider->SetInput2( expFilter->GetOutput() );
     divider->Update();
 
-    if( weightImage &&
-        ( maskImageOption && maskImageOption->GetNumberOfFunctions() > 0 ) )
+    if( maskImageOption && maskImageOption->GetNumberOfFunctions() > 0 )
       {
+      itk::ImageRegionIteratorWithIndex<ImageType> ItD( divider->GetOutput(),
+                                                        divider->GetOutput()->GetLargestPossibleRegion() );
+      itk::ImageRegionIterator<ImageType> ItI( inputImage,
+                                               inputImage->GetLargestPossibleRegion() );
+      for( ItD.GoToBegin(), ItI.GoToBegin(); !ItD.IsAtEnd(); ++ItD, ++ItI )
+        {
+        if( maskImage->GetPixel( ItD.GetIndex() ) != correcter->GetMaskLabel() )
+          {
+          ItD.Set( ItI.Get() );
+          }
+        }
+      }
+
+    bool doRescale = true;
+
+    typename itk::ants::CommandLineParser::OptionType::Pointer rescaleOption =
+      parser->GetOption( "rescale-intensities" );
+    if( ! isMaskImageSpecified || ( rescaleOption && rescaleOption->GetNumberOfFunctions() &&
+      ! parser->Convert<bool>( rescaleOption->GetFunction()->GetName() ) ) )
+      {
+      doRescale = false;
+      }
+
+    if( doRescale )
+      {
+      typedef itk::Image<unsigned short, ImageDimension> ShortImageType;
+      typedef itk::CastImageFilter<MaskImageType, ShortImageType> CasterType;
+      typename CasterType::Pointer caster = CasterType::New();
+      caster->SetInput( maskImage );
+      caster->Update();
+
+      typedef itk::LabelStatisticsImageFilter<ImageType, ShortImageType> StatsType;
+      typename StatsType::Pointer stats = StatsType::New();
+      stats->SetInput( inputImage );
+      stats->SetLabelInput( caster->GetOutput() );
+      stats->UseHistogramsOff();
+      stats->Update();
+
+      typedef typename StatsType::LabelPixelType StatsLabelType;
+      StatsLabelType maskLabel = static_cast<StatsLabelType>( correcter->GetMaskLabel() );
+
+      RealType minOriginal = stats->GetMinimum( maskLabel );
+      RealType maxOriginal = stats->GetMaximum( maskLabel );
+
+      typename StatsType::Pointer stats2 = StatsType::New();
+      stats2->SetInput( divider->GetOutput() );
+      stats2->SetLabelInput( caster->GetOutput() );
+      stats2->UseHistogramsOff();
+      stats2->Update();
+
+      RealType minBiasCorrected = stats2->GetMinimum( maskLabel );
+      RealType maxBiasCorrected = stats2->GetMaximum( maskLabel );
+
+      RealType slope = ( maxOriginal - minOriginal ) / ( maxBiasCorrected - minBiasCorrected );
+
       itk::ImageRegionIteratorWithIndex<ImageType> ItD( divider->GetOutput(),
                                                         divider->GetOutput()->GetLargestPossibleRegion() );
       for( ItD.GoToBegin(); !ItD.IsAtEnd(); ++ItD )
         {
-        if( maskImage->GetPixel( ItD.GetIndex() ) != correcter->GetMaskLabel() )
+        if( maskImage->GetPixel( ItD.GetIndex() ) == maskLabel )
           {
-          ItD.Set( inputImage->GetPixel( ItD.GetIndex() ) );
+          RealType originalIntensity = ItD.Get();
+          RealType rescaledIntensity = maxOriginal - slope * ( maxBiasCorrected - originalIntensity );
+          ItD.Set( rescaledIntensity );
           }
         }
       }
@@ -460,7 +521,7 @@ int N4( itk::ants::CommandLineParser *parser )
   return EXIT_SUCCESS;
 }
 
-void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
+void N4InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
 {
   typedef itk::ants::CommandLineParser::OptionType OptionType;
 
@@ -513,6 +574,23 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
     parser->AddOption( option );
     }
 
+    {
+    std::string description =
+      std::string( "At each iteration, a new intensity mapping is calculated " )
+      + std::string( "and applied but there is nothing which constrains the " )
+      + std::string( "new intensity range to be within certain values.  The " )
+      + std::string( "result is that the range can \"drift\" from the original " )
+      + std::string( "at each iteration.  This option rescales to the [min,max] " )
+      + std::string( "range of the original image intensities within the user-specified mask." );
+
+    OptionType::Pointer option = OptionType::New();
+    option->SetLongName( "rescale-intensities" );
+    option->SetShortName( 'r' );
+    option->SetUsageOption( 0, "0/(1)" );
+    option->SetDescription( description );
+    parser->AddOption( option );
+    }
+
     {
     std::string description =
       std::string( "The weight image allows the user to perform a relative " )
@@ -622,7 +700,6 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
     OptionType::Pointer option = OptionType::New();
     option->SetShortName( 'h' );
     option->SetDescription( description );
-    option->AddFunction( std::string( "0" ) );
     parser->AddOption( option );
     }
 
@@ -632,14 +709,13 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
     OptionType::Pointer option = OptionType::New();
     option->SetLongName( "help" );
     option->SetDescription( description );
-    option->AddFunction( std::string( "0" ) );
     parser->AddOption( option );
     }
 }
 
 // entry point for the library; parameter 'args' is equivalent to 'argv' in (argc,argv) of commandline parameters to
 // 'main()'
-int N4BiasFieldCorrection( std::vector<std::string> args, std::ostream* out_stream = NULL )
+int N4BiasFieldCorrection( std::vector<std::string> args, std::ostream* /*out_stream = NULL */ )
 {
   // put the arguments coming in as 'args' into standard (argc,argv) format;
   // 'args' doesn't have the command name as first, argument, so add it manually;
@@ -657,7 +733,7 @@ int N4BiasFieldCorrection( std::vector<std::string> args, std::ostream* out_stre
     // place the null character in the end
     argv[i][args[i].length()] = '\0';
     }
-  argv[argc] = 0;
+  argv[argc] = ITK_NULLPTR;
   // class to automatically cleanup argv upon destruction
   class Cleanup_argv
   {
@@ -681,7 +757,7 @@ private:
   };
   Cleanup_argv cleanup_argv( argv, argc + 1 );
 
-  antscout->set_stream( out_stream );
+  // antscout->set_stream( out_stream );
 
   itk::ants::CommandLineParser::Pointer parser =
     itk::ants::CommandLineParser::New();
@@ -703,22 +779,26 @@ private:
     + std::string( "IEEE Transactions on Medical Imaging, 29(6):1310-1320, June 2010." );
 
   parser->SetCommandDescription( commandDescription );
-  InitializeCommandLineOptions( parser );
+  N4InitializeCommandLineOptions( parser );
 
-  parser->Parse( argc, argv );
-
-  if( argc < 2 || parser->Convert<bool>( parser->GetOption( "help" )->GetFunction( 0 )->GetName() ) )
+  if( parser->Parse( argc, argv ) == EXIT_FAILURE )
     {
-    parser->PrintMenu( antscout, 5, false );
-    if( argc < 2 )
-      {
-      return EXIT_FAILURE;
-      }
+    return EXIT_FAILURE;
+    }
+
+  if( argc == 1 )
+    {
+    parser->PrintMenu( std::cout, 5, false );
+    return EXIT_FAILURE;
+    }
+  else if( parser->GetOption( "help" )->GetFunction() && parser->Convert<bool>( parser->GetOption( "help" )->GetFunction()->GetName() ) )
+    {
+    parser->PrintMenu( std::cout, 5, false );
     return EXIT_SUCCESS;
     }
-  else if( parser->Convert<bool>( parser->GetOption( 'h' )->GetFunction( 0 )->GetName() ) )
+  else if( parser->GetOption( 'h' )->GetFunction() && parser->Convert<bool>( parser->GetOption( 'h' )->GetFunction()->GetName() ) )
     {
-    parser->PrintMenu( antscout, 5, true );
+    parser->PrintMenu( std::cout, 5, true );
     return EXIT_SUCCESS;
     }
 
@@ -751,7 +831,7 @@ private:
       }
     else
       {
-      antscout << "No input images were specified.  Specify an input image"
+      std::cout << "No input images were specified.  Specify an input image"
                << " with the -i option" << std::endl;
       return EXIT_FAILURE;
       }
@@ -760,7 +840,7 @@ private:
     dimension = imageIO->GetNumberOfDimensions();
     }
 
-  antscout << std::endl << "Running N4 for "
+  std::cout << std::endl << "Running N4 for "
            << dimension << "-dimensional images." << std::endl << std::endl;
 
   switch( dimension )
@@ -781,7 +861,7 @@ private:
       }
       break;
     default:
-      antscout << "Unsupported dimension" << std::endl;
+      std::cout << "Unsupported dimension" << std::endl;
       return EXIT_FAILURE;
     }
   return EXIT_SUCCESS;
