@@ -23,7 +23,7 @@
 #include "antsCommandLineOption.h"
 #include "antsCommandLineParser.h"
 #include "antsSCCANObject.h"
-#include "ReadWriteImage.h"
+#include "ReadWriteData.h"
 #include "itkImageRegionIteratorWithIndex.h"
 #include <vnl/vnl_vector.h>
 #include <vnl/vnl_matrix.h>
@@ -57,7 +57,7 @@ double vnl_pearson_corr( vnl_vector<TComp> v1, vnl_vector<TComp> v2 )
 
 template <class NetworkType>
 bool RegionSCCA(typename NetworkType::Pointer network, typename NetworkType::Pointer time, typename NetworkType::Pointer labels,
-                unsigned int nLabels, unsigned int minRegionSize, unsigned int n_evec, unsigned int iterct, float sparsity, 
+                unsigned int nLabels, unsigned int minRegionSize, unsigned int n_evec, unsigned int iterct, float sparsity,
                 bool robust, bool useL1, float gradstep, bool keepPositive, unsigned int minClusterSize )
 {
   typedef itk::ants::antsSCCANObject<NetworkType, double>  SCCANType;
@@ -70,7 +70,7 @@ bool RegionSCCA(typename NetworkType::Pointer network, typename NetworkType::Poi
 
   if ( nLabels == 0 )
     {
-    
+
     while( !it.IsAtEnd() )
       {
       if ( it.Value() > 0 )
@@ -80,7 +80,7 @@ bool RegionSCCA(typename NetworkType::Pointer network, typename NetworkType::Poi
       ++it;
       }
     }
-  else 
+  else
     {
     for ( unsigned int i=0; i<nLabels; i++ )
       {
@@ -89,7 +89,7 @@ bool RegionSCCA(typename NetworkType::Pointer network, typename NetworkType::Poi
     }
 
   unsigned int N = labelset.size();
-  antscout << "Network Size = " << N << " x " << N << std::endl;
+  std::cout << "Network Size = " << N << " x " << N << std::endl;
 
   typename NetworkType::RegionType region;
   typename NetworkType::RegionType::SizeType size;
@@ -105,7 +105,7 @@ bool RegionSCCA(typename NetworkType::Pointer network, typename NetworkType::Poi
 
   if ( nVoxels != time->GetLargestPossibleRegion().GetSize()[1] )
     {
-    antscout << "number of labels does not match number of voxels" << std::endl;
+    std::cout << "number of labels does not match number of voxels" << std::endl;
     return EXIT_FAILURE;
     }
 
@@ -217,7 +217,7 @@ bool RegionSCCA(typename NetworkType::Pointer network, typename NetworkType::Poi
           // is truecorr just sccancorrs[0]?
           cca->SparsePartialArnoldiCCA(n_evec);
           VectorType sccancorrs = cca->GetCanonicalCorrelations();
-                            
+
           VectorType pVec = cca->GetVariateP();
           for ( unsigned int ip=0; ip<pVec.size(); ip++)
             {
@@ -232,12 +232,12 @@ bool RegionSCCA(typename NetworkType::Pointer network, typename NetworkType::Poi
             qVec[iq] = vnl_math_abs( qVec[iq] );
             }
           //qVec = qVec.normalize();
-          qVec = Q * qVec;       
+          qVec = Q * qVec;
 
           double final_corr = vnl_pearson_corr(pVec,qVec);
           if ( ! vnl_math_isfinite( final_corr ) )
             {
-            final_corr = 0.0; 
+            final_corr = 0.0;
             }
 
           typename NetworkType::IndexType connIdx;
@@ -266,8 +266,6 @@ bool RegionAveraging(typename NetworkType::Pointer network, typename NetworkType
 {
 
   typedef vnl_vector<float>                                     VectorType;
-  typedef VectorType*                                           VectorPointerType;
-  typedef itk::VectorContainer<unsigned int, VectorPointerType> VectorContainerType;
   typedef vnl_matrix<float>                                     MatrixType;
 
   // Determine the number of regions to examine
@@ -276,7 +274,7 @@ bool RegionAveraging(typename NetworkType::Pointer network, typename NetworkType
 
   if ( nLabels == 0 )
     {
-    
+
     while( !it.IsAtEnd() )
       {
       if ( it.Value() > 0 )
@@ -286,7 +284,7 @@ bool RegionAveraging(typename NetworkType::Pointer network, typename NetworkType
       ++it;
       }
     }
-  else 
+  else
     {
     for ( unsigned int i=0; i<nLabels; i++ )
       {
@@ -295,7 +293,7 @@ bool RegionAveraging(typename NetworkType::Pointer network, typename NetworkType
     }
 
   unsigned int N = labelset.size();
-  antscout << "Network Size = " << N << " x " << N << std::endl;
+  std::cout << "Network Size = " << N << " x " << N << std::endl;
 
   typename NetworkType::RegionType region;
   typename NetworkType::RegionType::SizeType size;
@@ -311,7 +309,7 @@ bool RegionAveraging(typename NetworkType::Pointer network, typename NetworkType
 
   if ( nVoxels != time->GetLargestPossibleRegion().GetSize()[1] )
     {
-    antscout << "number of labels does not match number of voxels" << std::endl;
+    std::cout << "number of labels does not match number of voxels" << std::endl;
     return EXIT_FAILURE;
     }
 
@@ -324,9 +322,9 @@ bool RegionAveraging(typename NetworkType::Pointer network, typename NetworkType
     {
     typename NetworkType::IndexType idx;
     idx[1] = 0;
-    
+
     for ( unsigned int v=0; v<nVoxels; v++)
-      {      
+      {
       idx[0] = v;
       if ( labels->GetPixel(idx) == (i+1) )
         {
@@ -356,9 +354,9 @@ bool RegionAveraging(typename NetworkType::Pointer network, typename NetworkType
 
 for (unsigned int i=0; i<N; i++)
     {
-    for ( unsigned int j=(i+1); j<N; j++ )      
+    for ( unsigned int j=(i+1); j<N; j++ )
       {
-      
+
       if ( (labelCounts[i] > minSize) && (labelCounts[j] > minSize ) )
         {
         VectorType p = timeSig.get_row(i);
@@ -368,9 +366,9 @@ for (unsigned int i=0; i<N; i++)
 
         if ( ! vnl_math_isfinite( corr ) )
           {
-          corr = 0.0; 
+          corr = 0.0;
           }
-               
+
         typename NetworkType::IndexType connIdx;
         connIdx[0] = i;
         connIdx[1] = j;
@@ -378,21 +376,19 @@ for (unsigned int i=0; i<N; i++)
         connIdx[0] = j;
         connIdx[1] = i;
         network->SetPixel( connIdx, corr );
-          
+
         }
       }
     }
 
   return network;
-  
+
 }
 
 int timesccan( itk::ants::CommandLineParser *parser )
 {
 
   typedef itk::Image<float,2>               NetworkType;
-  typedef itk::ImageFileReader<NetworkType> NetworkReaderType;
-  typedef itk::ImageFileWriter<NetworkType> NetworkWriterType;
 
 
   std::string                                       outname = "output.nii.gz";
@@ -400,12 +396,12 @@ int timesccan( itk::ants::CommandLineParser *parser )
     parser->GetOption( "output" );
   if( !outputOption || outputOption->GetNumberOfFunctions() == 0 )
     {
-    antscout << "Warning:  no output option set." << std::endl;
+    std::cout << "Warning:  no output option set." << std::endl;
     }
   else
     {
     outname = outputOption->GetFunction()->GetName();
-    antscout << "Writing output to: " << outname << std::endl;
+    std::cout << "Writing output to: " << outname << std::endl;
     }
 
   unsigned int                                      nLabels = 0;
@@ -413,7 +409,7 @@ int timesccan( itk::ants::CommandLineParser *parser )
     parser->GetOption( "number-consecutive-labels" );
   if( !labels_option || labels_option->GetNumberOfFunctions() == 0 )
     {
-    //    antscout << "Warning:  no permutation option set." << std::endl;
+    //    std::cout << "Warning:  no permutation option set." << std::endl;
     }
   else
     {
@@ -425,7 +421,7 @@ int timesccan( itk::ants::CommandLineParser *parser )
     parser->GetOption( "minimum-region-size" );
   if( !size_option || size_option->GetNumberOfFunctions() == 0 )
     {
-    //    antscout << "Warning:  no permutation option set." << std::endl;
+    //    std::cout << "Warning:  no permutation option set." << std::endl;
     }
   else
     {
@@ -437,7 +433,7 @@ int timesccan( itk::ants::CommandLineParser *parser )
     parser->GetOption( "minimum-cluster-size" );
   if( !clust_option || clust_option->GetNumberOfFunctions() == 0 )
     {
-    //    antscout << "Warning:  no permutation option set." << std::endl;
+    //    std::cout << "Warning:  no permutation option set." << std::endl;
     }
   else
     {
@@ -449,7 +445,7 @@ int timesccan( itk::ants::CommandLineParser *parser )
     parser->GetOption( "n_eigenvectors" );
   if( !evec_option || evec_option->GetNumberOfFunctions() == 0 )
     {
-    //    antscout << "Warning:  no permutation option set." << std::endl;
+    //    std::cout << "Warning:  no permutation option set." << std::endl;
     }
   else
     {
@@ -461,7 +457,7 @@ int timesccan( itk::ants::CommandLineParser *parser )
     parser->GetOption( "iterations" );
   if( !iter_option || iter_option->GetNumberOfFunctions() == 0 )
     {
-    //    antscout << "Warning:  no permutation option set." << std::endl;
+    //    std::cout << "Warning:  no permutation option set." << std::endl;
     }
   else
     {
@@ -473,7 +469,7 @@ int timesccan( itk::ants::CommandLineParser *parser )
     parser->GetOption( "sparsity" );
   if( !sparse_option || sparse_option->GetNumberOfFunctions() == 0 )
     {
-    //    antscout << "Warning:  no permutation option set." << std::endl;
+    //    std::cout << "Warning:  no permutation option set." << std::endl;
     }
   else
     {
@@ -485,7 +481,7 @@ int timesccan( itk::ants::CommandLineParser *parser )
     parser->GetOption( "keep-positive" );
   if( !pos_option || pos_option->GetNumberOfFunctions() == 0 )
     {
-    //    antscout << "Warning:  no permutation option set." << std::endl;
+    //    std::cout << "Warning:  no permutation option set." << std::endl;
     }
   else
     {
@@ -497,7 +493,7 @@ int timesccan( itk::ants::CommandLineParser *parser )
     parser->GetOption( "l1" );
   if( !l1_option || l1_option->GetNumberOfFunctions() == 0 )
     {
-    //    antscout << "Warning:  no permutation option set." << std::endl;
+    //    std::cout << "Warning:  no permutation option set." << std::endl;
     }
   else
     {
@@ -509,63 +505,54 @@ int timesccan( itk::ants::CommandLineParser *parser )
     parser->GetOption( "robustify" );
   if( !robust_option || robust_option->GetNumberOfFunctions() == 0 )
     {
-    //    antscout << "Warning:  no permutation option set." << std::endl;
+    //    std::cout << "Warning:  no permutation option set." << std::endl;
     }
   else
     {
     robustify = parser->Convert<unsigned int>( robust_option->GetFunction()->GetName() );
     }
 
-  unsigned int                                      evecgradientpenalty = 1;
   itk::ants::CommandLineParser::OptionType::Pointer evecg_option =
     parser->GetOption( "EvecGradPenalty" );
-  if( !evecg_option || evecg_option->GetNumberOfFunctions() == 0 )
+  if( evecg_option && evecg_option->GetNumberOfFunctions() != 0 )
     {
-    }
-  else
-    {
-    evecgradientpenalty = parser->Convert<unsigned int>( evecg_option->GetFunction()->GetName() );
+    parser->Convert<unsigned int>( evecg_option->GetFunction()->GetName() );
     }
 
-  bool                                              eigen_imp = false;
   itk::ants::CommandLineParser::OptionType::Pointer eigen_option =
     parser->GetOption( "ridge_cca" );
-  if( !eigen_option || eigen_option->GetNumberOfFunctions() == 0 )
+  if( eigen_option && eigen_option->GetNumberOfFunctions() != 0 )
     {
-    //    antscout << "Warning:  no permutation option set." << std::endl;
+    parser->Convert<bool>( eigen_option->GetFunction()->GetName() );
     }
-  else
-    {
-    eigen_imp = parser->Convert<bool>( eigen_option->GetFunction()->GetName() );
-    }  
 
   NetworkType::Pointer network = NetworkType::New();
 
   itk::ants::CommandLineParser::OptionType::Pointer netOption = parser->GetOption( "network" );
   if( netOption && netOption->GetNumberOfFunctions() > 0 )
     {
-    antscout << "Build network" << std::endl;
+    std::cout << "Build network" << std::endl;
     if( netOption && netOption->GetFunction( 0 )->GetNumberOfParameters() < 2 )
       {
-      antscout << "  Incorrect number of parameters." <<  std::endl;
+      std::cout << "  Incorrect number of parameters." <<  std::endl;
       return EXIT_FAILURE;
       }
     std::string connectivityStrategy = netOption->GetFunction()->GetName();
     std::string timeMatrixName = std::string(netOption->GetFunction( 0 )->GetParameter( 0 ) );
-    std::string labelMatrixName = std::string(netOption->GetFunction( 0 )->GetParameter( 1 ) );    
+    std::string labelMatrixName = std::string(netOption->GetFunction( 0 )->GetParameter( 1 ) );
 
-    antscout << "Method: " << connectivityStrategy << std::endl;
+    std::cout << "Method: " << connectivityStrategy << std::endl;
 
     if ( connectivityStrategy == "scca" )
       {
-      antscout << "Time Series Data: " << timeMatrixName << std::endl;
-      antscout << "Time Series Labels: " << labelMatrixName << std::endl;
+      std::cout << "Time Series Data: " << timeMatrixName << std::endl;
+      std::cout << "Time Series Labels: " << labelMatrixName << std::endl;
 
-      NetworkType::Pointer timeMat = NULL;
+      NetworkType::Pointer timeMat = ITK_NULLPTR;
       ReadImage<NetworkType>( timeMat, timeMatrixName.c_str() );
 
-      NetworkType::Pointer labelMat = NULL;
-      ReadImage<NetworkType>( labelMat, labelMatrixName.c_str() );      
+      NetworkType::Pointer labelMat = ITK_NULLPTR;
+      ReadImage<NetworkType>( labelMat, labelMatrixName.c_str() );
 
       float gradstep = -0.5 + vnl_math_abs( usel1 );
 
@@ -574,23 +561,23 @@ int timesccan( itk::ants::CommandLineParser *parser )
       }
     else if ( connectivityStrategy == "region-averaging" )
       {
-      antscout << "Time Series Data: " << timeMatrixName << std::endl;
-      antscout << "Time Series Labels: " << labelMatrixName << std::endl;
+      std::cout << "Time Series Data: " << timeMatrixName << std::endl;
+      std::cout << "Time Series Labels: " << labelMatrixName << std::endl;
 
-      NetworkType::Pointer timeMat = NULL;
+      NetworkType::Pointer timeMat = ITK_NULLPTR;
       ReadImage<NetworkType>( timeMat, timeMatrixName.c_str() );
 
-      NetworkType::Pointer labelMat = NULL;
-      ReadImage<NetworkType>( labelMat, labelMatrixName.c_str() );  
+      NetworkType::Pointer labelMat = ITK_NULLPTR;
+      ReadImage<NetworkType>( labelMat, labelMatrixName.c_str() );
 
       RegionAveraging<NetworkType>( network, timeMat, labelMat, nLabels, roiSize );
       }
     else
       {
-      antscout << "Unknown method:" << connectivityStrategy << std::endl;
+      std::cout << "Unknown method:" << connectivityStrategy << std::endl;
       return EXIT_FAILURE;
       }
-    
+
     }
 
   WriteImage<NetworkType>( network, outname.c_str() );
@@ -609,7 +596,6 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
   OptionType::Pointer option = OptionType::New();
   option->SetShortName( 'h' );
   option->SetDescription( description );
-  option->AddFunction( std::string( "0" ) );
   parser->AddOption( option );
   }
 
@@ -618,10 +604,9 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
   OptionType::Pointer option = OptionType::New();
   option->SetLongName( "help" );
   option->SetDescription( description );
-  option->AddFunction( std::string( "0" ) );
   parser->AddOption( option );
   }
-  
+
   {
   std::string description =
     std::string( "Output is a 2D correlation matrix." );
@@ -632,7 +617,7 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
   option->SetDescription( description );
   parser->AddOption( option );
   }
-  
+
   {
   std::string description =
     std::string( "Number of consecutive labels in data" );
@@ -687,7 +672,7 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
   option->SetDescription( description );
   parser->AddOption( option );
   }
-  
+
   {
   std::string description =
     std::string( "rank-based scca" );
@@ -698,7 +683,7 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
   option->SetDescription( description );
   parser->AddOption( option );
   }
-  
+
   {
   std::string description =
     std::string(
@@ -710,7 +695,7 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
   option->SetDescription( description );
   parser->AddOption( option );
   }
-  
+
   {
   std::string description =
     std::string( "cluster threshold on view P" );
@@ -720,7 +705,7 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
   option->SetDescription( description );
   parser->AddOption( option );
   }
-  
+
   {
   std::string description =
     std::string( "Number of permutations to use in scca." );
@@ -731,7 +716,7 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
   option->SetDescription( description );
   parser->AddOption( option );
   }
-  
+
   {
   std::string description =
     std::string( "Choices for pscca: PQ, PminusRQ, PQminusR, PminusRQminusR " );
@@ -741,7 +726,7 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
   option->SetDescription( description );
   parser->AddOption( option );
   }
-  
+
   {
   std::string description =
     std::string( "takes a timeseries (4D) image " )
@@ -756,12 +741,12 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
   option->SetDescription( description );
   parser->AddOption( option );
   }
-  
+
   {
   std::string description =
     std::string( "takes a labeled (3D) image " )
     + std::string( "and converts it to a 2D matrix csv format as output." );
-  
+
   OptionType::Pointer option = OptionType::New();
   option->SetLongName( "labelsimage-to-matrix" );
   option->SetUsageOption(
@@ -786,10 +771,10 @@ void InitializeCommandLineOptions( itk::ants::CommandLineParser *parser )
   parser->AddOption( option );
   }
 }
-  
+
 // entry point for the library; parameter 'args' is equivalent to 'argv' in (argc,argv) of commandline parameters to
 // 'main()'
-int TimeSCCAN( std::vector<std::string> args, std::ostream* out_stream = NULL )
+int TimeSCCAN( std::vector<std::string> args, std::ostream* /*out_stream = NULL */ )
 {
   // put the arguments coming in as 'args' into standard (argc,argv) format;
   // 'args' doesn't have the command name as first, argument, so add it manually;
@@ -807,7 +792,7 @@ int TimeSCCAN( std::vector<std::string> args, std::ostream* out_stream = NULL )
     // place the null character in the end
     argv[i][args[i].length()] = '\0';
     }
-  argv[argc] = 0;
+  argv[argc] = ITK_NULLPTR;
   // class to automatically cleanup argv upon destruction
   class Cleanup_argv
   {
@@ -831,7 +816,7 @@ private:
   };
   Cleanup_argv cleanup_argv( argv, argc + 1 );
 
-  antscout->set_stream( out_stream );
+  // antscout->set_stream( out_stream );
 
   itk::ants::CommandLineParser::Pointer parser =
     itk::ants::CommandLineParser::New();
@@ -844,26 +829,29 @@ private:
   parser->SetCommandDescription( commandDescription );
   InitializeCommandLineOptions( parser );
 
-  parser->Parse( argc, argv );
+  if( parser->Parse( argc, argv ) == EXIT_FAILURE )
+    {
+    return EXIT_FAILURE;
+    }
 
   // Print the entire help menu
   itk::ants::CommandLineParser::OptionType::Pointer shortHelpOption =
     parser->GetOption( 'h' );
   itk::ants::CommandLineParser::OptionType::Pointer longHelpOption =
     parser->GetOption( "help" );
-  if( argc < 2 || ( shortHelpOption &&
+  if( argc < 2 || ( shortHelpOption->GetFunction() &&
                     parser->Convert<unsigned int>( shortHelpOption->GetFunction()->GetName() ) == 1 ) )
     {
-    parser->PrintMenu( antscout, 5, true );
+    parser->PrintMenu( std::cout, 5, true );
     if( argc < 2 )
       {
       return EXIT_FAILURE;
       }
     return EXIT_SUCCESS;
     }
-  if( longHelpOption && parser->Convert<unsigned int>( longHelpOption->GetFunction()->GetName() ) == 1 )
+  if( longHelpOption->GetFunction() && parser->Convert<unsigned int>( longHelpOption->GetFunction()->GetName() ) == 1 )
     {
-    parser->PrintMenu( antscout, 5, false );
+    parser->PrintMenu( std::cout, 5, false );
     return EXIT_SUCCESS;
     }
 
@@ -882,7 +870,7 @@ private:
         const char *longName = ( ( *it )->GetLongName() ).c_str();
         if( strstr( longName, value.c_str() ) == longName  )
           {
-          parser->PrintMenu( antscout, 5, false );
+          parser->PrintMenu( std::cout, 5, false );
           }
         }
       }
