@@ -87,6 +87,8 @@
 #include "itkSampleToHistogramFilter.h"
 #include "itkScalarImageKmeansImageFilter.h"
 #include "itkShrinkImageFilter.h"
+#include "itkSimilarity3DTransform.h"
+#include "itkSimilarity2DTransform.h"
 #include "itkSize.h"
 #include "itkSphereSpatialFunction.h"
 #include "itkSTAPLEImageFilter.h"
@@ -114,13 +116,52 @@
 #include <sstream>
 #include <string>
 
-#include "ReadWriteImage.h"
+#include "ReadWriteData.h"
 #include "TensorFunctions.h"
 #include "antsMatrixUtilities.h"
-#include "../Temporary/itkFastMarchingImageFilter.h"
 
 namespace ants
 {
+
+template <class TComputeType, unsigned int ImageDimension>
+class SimilarityTransformTraits
+{
+  // Don't worry about the fact that the default option is the
+  // affine Transform, that one will not actually be instantiated.
+public:
+  typedef itk::AffineTransform<TComputeType, ImageDimension> TransformType;
+};
+
+
+template <>
+class SimilarityTransformTraits<double, 2>
+{
+public:
+  typedef itk::Similarity2DTransform<double> TransformType;
+};
+
+template <>
+class SimilarityTransformTraits<float, 2>
+{
+public:
+  typedef itk::Similarity2DTransform<float> TransformType;
+};
+
+template <>
+class SimilarityTransformTraits<double, 3>
+{
+public:
+  typedef itk::Similarity3DTransform<double> TransformType;
+};
+
+template <>
+class SimilarityTransformTraits<float, 3>
+{
+public:
+  typedef itk::Similarity3DTransform<float> TransformType;
+};
+
+
 template <unsigned int ImageDimension>
 int antsAffineInitializerImp(int argc, char *argv[])
 {
@@ -132,29 +173,23 @@ int antsAffineInitializerImp(int argc, char *argv[])
   RealType     searchfactor = 10;                // in degrees, passed by user
   unsigned int mibins = 32;                      // for mattes MI metric
   RealType     degtorad = 0.0174532925;          // to convert degrees to radians
-  RealType     localoptimizerlearningrate = 0.1; // for local search via conjgrad
   unsigned int localoptimizeriterations = 20;    // for local search via conjgrad
   // piover4 is (+/-) for cross-section of the sphere to multi-start search in increments
   // of searchfactor ( converted from degrees to radians ).
   // the search is centered +/- from the principal axis alignment of the images.
   RealType piover4 = pi / 4; // works in preliminary practical examples in 3D, in 2D use pi.
   bool     useprincaxis = false;
-
+  typedef typename itk::ImageMaskSpatialObject<ImageDimension>::ImageType
+    maskimagetype;
+  std::string whichMetric=std::string("MI");
+  unsigned int localSearchIterations = 20;
   typedef itk::TransformFileWriter                                        TransformWriterType;
   typedef itk::Vector<float, ImageDimension>                              VectorType;
-  typedef itk::Image<VectorType, ImageDimension>                          FieldType;
   typedef itk::Image<PixelType, ImageDimension>                           ImageType;
-  typedef  typename ImageType::IndexType                                  IndexType;
-  typedef  typename ImageType::SizeType                                   SizeType;
-  typedef  typename ImageType::SpacingType                                SpacingType;
-  typedef itk::AffineTransform<double, ImageDimension>                    AffineTransformType;
-  typedef itk::LinearInterpolateImageFunction<ImageType, double>          InterpolatorType1;
-  typedef itk::NearestNeighborInterpolateImageFunction<ImageType, double> InterpolatorType2;
-  typedef itk::ImageRegionIteratorWithIndex<ImageType>                    Iterator;
   typedef typename itk::ImageMomentsCalculator<ImageType>                 ImageCalculatorType;
-  typedef itk::AffineTransform<RealType, ImageDimension>                  AffineType;
-  typedef itk::CompositeTransform<RealType, ImageDimension>               CompositeType;
-  typedef itk::AffineTransform<RealType>                                  EulerTransformType;
+  typedef itk::AffineTransform<RealType, ImageDimension> AffineType;
+  typedef typename SimilarityTransformTraits<RealType,
+    ImageDimension>::TransformType AffineTypeS;
   typedef typename ImageCalculatorType::MatrixType                        MatrixType;
   if( argc < 2 )
     {
@@ -189,16 +224,18 @@ int antsAffineInitializerImp(int argc, char *argv[])
     {
     localoptimizeriterations = atoi( argv[argct] );   argct++;
     }
+  typename ImageType::Pointer image1 = ITK_NULLPTR;
+  typename ImageType::Pointer image2 = ITK_NULLPTR;
+  typename maskimagetype::Pointer mask = ITK_NULLPTR;
+  ReadImage<ImageType>(image1, fn1.c_str() );
+  ReadImage<ImageType>(image2, fn2.c_str() );
   std::string maskfn = "";
   if(  argc > argct )
     {
     maskfn = std::string( argv[argct] );   argct++;
+    ReadImage<maskimagetype>(mask, maskfn.c_str() );
     }
   searchfactor *= degtorad; // convert degrees to radians
-  typename ImageType::Pointer image1 = NULL;
-  typename ImageType::Pointer image2 = NULL;
-  ReadImage<ImageType>(image1, fn1.c_str() );
-  ReadImage<ImageType>(image2, fn2.c_str() );
   VectorType ccg1;
   VectorType cpm1;
   MatrixType cpa1;
@@ -231,14 +268,19 @@ int antsAffineInitializerImp(int argc, char *argv[])
       }
     catch( ... )
       {
-      antscout << " zero image2 error ";
+      std::cerr << " zero image2 error ";
       fixed_center.Fill(0);
       }
     }
   catch( ... )
     {
-    antscout << " zero image1 error ";
+    std::cerr << " zero image1 error ";
     }
+  RealType bestscale =
+    calculator2->GetTotalMass() / calculator1->GetTotalMass();
+  RealType powlev = 1.0 / static_cast<RealType>(ImageDimension);
+  bestscale = vcl_pow( bestscale , powlev );
+  bestscale=1;
   unsigned int eigind1 = 1;
   unsigned int eigind2 = 1;
   if( ImageDimension == 3 )
@@ -262,7 +304,7 @@ int antsAffineInitializerImp(int argc, char *argv[])
   RealType det = vnl_determinant( A_solution  );
   if( det < 0 )
     {
-    antscout << " bad det " << det << " v " <<  vnl_determinant( wahba.V() ) << " u "
+    std::cerr << " bad det " << det << " v " <<  vnl_determinant( wahba.V() ) << " u "
              <<   vnl_determinant( wahba.U() )  << std::endl;
     vnl_matrix<RealType> id( A_solution );
     id.set_identity();
@@ -274,7 +316,7 @@ int antsAffineInitializerImp(int argc, char *argv[])
         }
       }
     A_solution =  A_solution * id.transpose();
-    antscout << " bad det " << det << " v " <<  vnl_determinant( wahba.V() ) << " u "
+    std::cerr << " bad det " << det << " v " <<  vnl_determinant( wahba.V() ) << " u "
              <<   vnl_determinant( wahba.U() )  << " new " << vnl_determinant( A_solution  ) << std::endl;
     }
   typename AffineType::Pointer affine1 = AffineType::New(); // translation to center
@@ -319,54 +361,123 @@ int antsAffineInitializerImp(int argc, char *argv[])
     axis1[d] = evec_tert[d];
     axis2[d] = evec1_2ndary[d];
     }
-  typename AffineType::Pointer affinesearch = AffineType::New();
-  affinesearch->SetIdentity();
-  affinesearch->SetCenter( trans2 );
-  typedef  itk::MultiStartOptimizerv4         OptimizerType;
-  typedef  typename OptimizerType::ScalesType ScalesType;
-  typename OptimizerType::Pointer  mstartOptimizer = OptimizerType::New();
-  typedef itk::MattesMutualInformationImageToImageMetricv4
+    typename AffineType::Pointer affinesearch = AffineType::New();
+    typedef  itk::MultiStartOptimizerv4         OptimizerType;
+    typename OptimizerType::MetricValuesListType metricvalues;
+    typename OptimizerType::Pointer  mstartOptimizer = OptimizerType::New();
+    typedef itk::CorrelationImageToImageMetricv4
+    <ImageType, ImageType, ImageType> GCMetricType;
+    typedef itk::MattesMutualInformationImageToImageMetricv4
     <ImageType, ImageType, ImageType> MetricType;
-  typename MetricType::ParametersType newparams(  affine1->GetParameters() );
-  typename MetricType::Pointer mimetric = MetricType::New();
-  mimetric->SetNumberOfHistogramBins( mibins );
-  mimetric->SetFixedImage( image1 );
-  mimetric->SetMovingImage( image2 );
-  mimetric->SetMovingTransform( affinesearch );
-  mimetric->SetParameters( newparams );
-  if( maskfn.length() > 3 )
+    typename MetricType::ParametersType newparams(  affine1->GetParameters() );
+    typename GCMetricType::Pointer gcmetric = GCMetricType::New();
+    gcmetric->SetFixedImage( image1 );
+    gcmetric->SetVirtualDomainFromImage( image1 );
+    gcmetric->SetMovingImage( image2 );
+    gcmetric->SetMovingTransform( affinesearch );
+    gcmetric->SetParameters( newparams );
+    typename MetricType::Pointer mimetric = MetricType::New();
+    mimetric->SetNumberOfHistogramBins( mibins );
+    mimetric->SetFixedImage( image1 );
+    mimetric->SetMovingImage( image2 );
+    mimetric->SetMovingTransform( affinesearch );
+    mimetric->SetParameters( newparams );
+    if( mask.IsNotNull() )
     {
-    typedef typename itk::ImageMaskSpatialObject<ImageDimension>::ImageType maskimagetype;
-    typename maskimagetype::Pointer mask;
-    ReadImage<maskimagetype>( mask, maskfn.c_str() );
-    typename itk::ImageMaskSpatialObject<ImageDimension>::Pointer so =
+      typename itk::ImageMaskSpatialObject<ImageDimension>::Pointer so =
       itk::ImageMaskSpatialObject<ImageDimension>::New();
-    so->SetImage( const_cast<maskimagetype *>(mask.GetPointer() ) );
-    mimetric->SetFixedImageMask( so );
+      so->SetImage( const_cast<maskimagetype *>( mask.GetPointer() ) );
+      mimetric->SetFixedImageMask( so );
+      gcmetric->SetFixedImageMask( so );
     }
-  mimetric->Initialize();
-  typedef itk::RegistrationParameterScalesFromPhysicalShift<MetricType>
-    RegistrationParameterScalesFromPhysicalShiftType;
-  typename RegistrationParameterScalesFromPhysicalShiftType::Pointer shiftScaleEstimator =
-    RegistrationParameterScalesFromPhysicalShiftType::New();
-  shiftScaleEstimator->SetMetric( mimetric );
-  shiftScaleEstimator->SetTransformForward( true ); // by default, scales for the moving transform
-  typename RegistrationParameterScalesFromPhysicalShiftType::ScalesType
-    movingScales( affinesearch->GetNumberOfParameters() );
-  shiftScaleEstimator->EstimateScales( movingScales );
-  mstartOptimizer->SetScales( movingScales );
-  antscout << " Scales: " << movingScales << std::endl;
-  mstartOptimizer->SetMetric( mimetric );
-  typename OptimizerType::ParametersListType parametersList = mstartOptimizer->GetParametersList();
-  affinesearch->SetIdentity();
-  affinesearch->SetCenter( trans2 );
-  affinesearch->SetOffset( trans );
-  parametersList.push_back( affinesearch->GetParameters() );
-  for( double ang1 = ( piover4 * (-1) ); ang1 <= ( piover4 + searchfactor ); ang1 = ang1 + searchfactor )
+    typedef  itk::ConjugateGradientLineSearchOptimizerv4 LocalOptimizerType;
+    typename LocalOptimizerType::Pointer  localoptimizer =
+    LocalOptimizerType::New();
+    RealType     localoptimizerlearningrate = 0.1;
+    localoptimizer->SetLearningRate( localoptimizerlearningrate );
+    localoptimizer->SetMaximumStepSizeInPhysicalUnits(
+    localoptimizerlearningrate );
+    localoptimizer->SetNumberOfIterations( localSearchIterations );
+    localoptimizer->SetLowerLimit( 0 );
+    localoptimizer->SetUpperLimit( 2 );
+    localoptimizer->SetEpsilon( 0.1 );
+    localoptimizer->SetMaximumLineSearchIterations( 10 );
+    localoptimizer->SetDoEstimateLearningRateOnce( true );
+    localoptimizer->SetMinimumConvergenceValue( 1.e-6 );
+    localoptimizer->SetConvergenceWindowSize( 5 );
+    if( true )
     {
-    if( ImageDimension == 3 )
+      typedef typename MetricType::FixedSampledPointSetType PointSetType;
+      typedef typename PointSetType::PointType              PointType;
+      typename PointSetType::Pointer      pset(PointSetType::New());
+      unsigned int ind=0;
+      unsigned int ct=0;
+      itk::ImageRegionIteratorWithIndex<ImageType> It(image1,
+      image1->GetLargestPossibleRegion() );
+      for( It.GoToBegin(); !It.IsAtEnd(); ++It )
       {
-      for( double ang2 = ( piover4 * (-1) ); ang2 <= ( piover4 + searchfactor ); ang2 = ang2 + searchfactor )
+        // take every N^th point
+        if ( ct % 10 == 0  )
+        {
+          PointType pt;
+          image1->TransformIndexToPhysicalPoint( It.GetIndex(), pt);
+          pset->SetPoint(ind, pt);
+          ind++;
+        }
+        ct++;
+      }
+      mimetric->SetFixedSampledPointSet( pset );
+      mimetric->SetUseFixedSampledPointSet( true );
+      gcmetric->SetFixedSampledPointSet( pset );
+      gcmetric->SetUseFixedSampledPointSet( true );
+    }
+    if ( whichMetric.compare("MI") == 0  ) {
+      mimetric->Initialize();
+      typedef itk::RegistrationParameterScalesFromPhysicalShift<MetricType>
+      RegistrationParameterScalesFromPhysicalShiftType;
+      typename RegistrationParameterScalesFromPhysicalShiftType::Pointer
+      shiftScaleEstimator =
+      RegistrationParameterScalesFromPhysicalShiftType::New();
+      shiftScaleEstimator->SetMetric( mimetric );
+      shiftScaleEstimator->SetTransformForward( true );
+      typename RegistrationParameterScalesFromPhysicalShiftType::ScalesType
+      movingScales( affinesearch->GetNumberOfParameters() );
+      shiftScaleEstimator->EstimateScales( movingScales );
+      mstartOptimizer->SetScales( movingScales );
+      mstartOptimizer->SetMetric( mimetric );
+      localoptimizer->SetMetric( mimetric );
+      localoptimizer->SetScales( movingScales );
+    }
+    if ( whichMetric.compare("MI") != 0  ) {
+      gcmetric->Initialize();
+      typedef itk::RegistrationParameterScalesFromPhysicalShift<GCMetricType>
+      RegistrationParameterScalesFromPhysicalShiftType;
+      typename RegistrationParameterScalesFromPhysicalShiftType::Pointer
+      shiftScaleEstimator =
+      RegistrationParameterScalesFromPhysicalShiftType::New();
+      shiftScaleEstimator->SetMetric( gcmetric );
+      shiftScaleEstimator->SetTransformForward( true );
+      typename RegistrationParameterScalesFromPhysicalShiftType::ScalesType
+      movingScales( affinesearch->GetNumberOfParameters() );
+      shiftScaleEstimator->EstimateScales( movingScales );
+      mstartOptimizer->SetScales( movingScales );
+      mstartOptimizer->SetMetric( gcmetric );
+      localoptimizer->SetMetric( gcmetric );
+      localoptimizer->SetScales( movingScales );
+    }
+    typename OptimizerType::ParametersListType parametersList =
+      mstartOptimizer->GetParametersList();
+   for( double ang1 = ( piover4 * (-1) ); ang1 <= ( piover4 + searchfactor ); ang1 = ang1 + searchfactor )
+      {
+      if( useprincaxis )
+      {
+        affinesearch->SetMatrix( A_solution );
+      }
+      if( ImageDimension == 3 )
+      {
+      for( double ang2 = ( piover4 * (-1) );
+                   ang2 <= ( piover4 + searchfactor );
+                   ang2 = ang2 + searchfactor )
         {
         affinesearch->SetIdentity();
         affinesearch->SetCenter( trans2 );
@@ -377,50 +488,34 @@ int antsAffineInitializerImp(int argc, char *argv[])
           }
         affinesearch->Rotate3D(axis1, ang1, 1);
         affinesearch->Rotate3D(axis2, ang2, 1);
+        affinesearch->Scale( bestscale );
         parametersList.push_back( affinesearch->GetParameters() );
         }
       }
-    if( ImageDimension == 2 )
+      if( ImageDimension == 2 )
       {
-      affinesearch->SetIdentity();
-      affinesearch->SetCenter( trans2 );
-      affinesearch->SetOffset( trans );
-      if( useprincaxis )
+        affinesearch->SetIdentity();
+        affinesearch->SetCenter( trans2 );
+        affinesearch->SetOffset( trans );
+        if( useprincaxis )
         {
         affinesearch->SetMatrix( A_solution );
         }
-      affinesearch->Rotate2D( ang1, 1);
-      parametersList.push_back( affinesearch->GetParameters() );
+        affinesearch->Rotate2D( ang1, 1);
+        affinesearch->Scale( bestscale );
+        parametersList.push_back( affinesearch->GetParameters() );
       }
     }
-  mstartOptimizer->SetParametersList( parametersList );
-
-  typedef  itk::ConjugateGradientLineSearchOptimizerv4 LocalOptimizerType;
-  typename LocalOptimizerType::Pointer  localoptimizer = LocalOptimizerType::New();
-  localoptimizer->SetMetric( mimetric );
-  localoptimizer->SetScales( movingScales );
-  localoptimizer->SetLearningRate( localoptimizerlearningrate );
-  localoptimizer->SetMaximumStepSizeInPhysicalUnits( localoptimizerlearningrate ); // * sqrt( small_step )
-  localoptimizer->SetNumberOfIterations( localoptimizeriterations );
-  localoptimizer->SetLowerLimit( 0 );
-  localoptimizer->SetUpperLimit( 2 );
-  localoptimizer->SetEpsilon( 0.1 );
-  localoptimizer->SetMaximumLineSearchIterations( 20 );
-  localoptimizer->SetDoEstimateLearningRateOnce( true );
-  localoptimizer->SetMinimumConvergenceValue( 1.e-6 );
-  localoptimizer->SetConvergenceWindowSize( 3 );
-
-  antscout << "Begin MultiStart: " << parametersList.size() << " searches between -/+ " << piover4 / pi
-           << " radians " << std::endl;
-  if( localoptimizeriterations > 0 )
+    mstartOptimizer->SetParametersList( parametersList );
+    if( localSearchIterations > 0 )
     {
-    mstartOptimizer->SetLocalOptimizer( localoptimizer );
+      mstartOptimizer->SetLocalOptimizer( localoptimizer );
     }
-  mstartOptimizer->StartOptimization();
-  antscout << "done" << std::endl;
-  typename AffineType::Pointer bestaffine = AffineType::New();
-  bestaffine->SetCenter( trans2 );
-  bestaffine->SetParameters( mstartOptimizer->GetBestParameters() );
+    mstartOptimizer->StartOptimization();
+    typename AffineType::Pointer bestaffine = AffineType::New();
+    bestaffine->SetCenter( trans2 );
+    bestaffine->SetParameters( mstartOptimizer->GetBestParameters() );
+
 
   typename TransformWriterType::Pointer transformWriter = TransformWriterType::New();
   transformWriter->SetInput( bestaffine );
@@ -431,7 +526,7 @@ int antsAffineInitializerImp(int argc, char *argv[])
 
 // entry point for the library; parameter 'args' is equivalent to 'argv' in (argc,argv) of commandline parameters to
 // 'main()'
-int antsAffineInitializer( std::vector<std::string> args, std::ostream* out_stream = NULL )
+int antsAffineInitializer( std::vector<std::string> args, std::ostream* /*out_stream = NULL */ )
 {
   // put the arguments coming in as 'args' into standard (argc,argv) format;
   // 'args' doesn't have the command name as first, argument, so add it manually;
@@ -449,7 +544,7 @@ int antsAffineInitializer( std::vector<std::string> args, std::ostream* out_stre
     // place the null character in the end
     argv[i][args[i].length()] = '\0';
     }
-  argv[argc] = 0;
+  argv[argc] = ITK_NULLPTR;
   // class to automatically cleanup argv upon destruction
   class Cleanup_argv
   {
@@ -473,22 +568,22 @@ private:
   };
   Cleanup_argv cleanup_argv( argv, argc + 1 );
 
-  antscout->set_stream( out_stream );
+  // antscout->set_stream( out_stream );
 
   if( argc < 3 )
     {
-    antscout << "\nUsage: " << argv[0]
+    std::cerr << "\nUsage: " << argv[0]
              <<
       " ImageDimension <Image1.ext> <Image2.ext> TransformOutput.mat Optional-SearchFactor Optional-Radian-Fraction Optional-bool-UsePrincipalAxes Optional-uint-UseLocalSearch Optional-Image1Mask "
              << std::endl;
-    antscout << " Optional-SearchFactor is in degrees --- e.g. 10 = search in 10 degree increments ." << std::endl;
-    antscout << " Radian-Fraction should be between 0 and 1 --- will search this arc +/- around principal axis."
+    std::cerr << " Optional-SearchFactor is in degrees --- e.g. 10 = search in 10 degree increments ." << std::endl;
+    std::cerr << " Radian-Fraction should be between 0 and 1 --- will search this arc +/- around principal axis."
              << std::endl;
-    antscout
+    std::cerr
       <<
       " Optional-bool-UsePrincipalAxes determines whether the rotation is searched around an initial principal axis alignment.  Default = false. "
       << std::endl;
-    antscout
+    std::cerr
       <<
       " Optional-uint-UseLocalSearch determines if a local optimization is run at each search point for the set number of iterations. Default = 20."
       << std::endl;
