@@ -6,7 +6,7 @@ namespace ants
 /** \class antsRegistrationOptimizerCommandIterationUpdate
  *  \brief observe the optimizer for traditional registration methods
  */
-template <unsigned VImageDimension, class TOptimizer>
+template <class ParametersValueType, unsigned VImageDimension, class TOptimizer>
 class antsRegistrationOptimizerCommandIterationUpdate : public itk::Command
 {
 public:
@@ -15,11 +15,14 @@ public:
   typedef itk::SmartPointer<Self>                         Pointer;
   itkNewMacro( Self );
 
-  typedef typename itk::Image<double, VImageDimension>     ImageType;
-  typedef itk::ImageToImageMetricv4<ImageType, ImageType>  MetricType;
-  typedef typename MetricType::MeasureType                 MeasureType;
-  typedef itk::CompositeTransform<double, VImageDimension> CompositeTransformType;
-  typedef typename CompositeTransformType::TransformType   TransformBaseType;
+  typedef ParametersValueType     RealType;
+  typedef ParametersValueType     PixelType;
+  typedef typename itk::Image<PixelType, VImageDimension>              ImageType;
+  typedef itk::ImageToImageMetricv4
+                <ImageType, ImageType, ImageType, RealType>            ImageMetricType;
+  typedef typename ImageMetricType::MeasureType                        MeasureType;
+  typedef itk::CompositeTransform<RealType, VImageDimension>           CompositeTransformType;
+  typedef typename CompositeTransformType::TransformType               TransformBaseType;
 protected:
   antsRegistrationOptimizerCommandIterationUpdate()
   {
@@ -28,23 +31,23 @@ protected:
     const itk::RealTimeClock::TimeStampType now = m_clock.GetTotal();
     this->m_lastTotalTime = now;
     m_clock.Start();
-    this->m_LogStream = &::ants::antscout;
+    this->m_LogStream = &std::cout;
     this->m_origFixedImage = ImageType::New();
     this->m_origMovingImage = ImageType::New();
     this->m_ComputeFullScaleCCInterval = 0;
     this->m_WriteInterationsOutputsInIntervals = 0;
     this->m_CurrentStageNumber = 0;
-    this->m_CurLevel = 0;
+    this->m_CurLevel = -1;
   }
 
 public:
 
-  void Execute(itk::Object *caller, const itk::EventObject & event)
+  void Execute(itk::Object *caller, const itk::EventObject & event) ITK_OVERRIDE
   {
     Execute( (const itk::Object *) caller, event);
   }
 
-  void Execute(const itk::Object *, const itk::EventObject & event)
+  void Execute(const itk::Object *, const itk::EventObject & event) ITK_OVERRIDE
   {
 #if 0
     if( typeid( event ) == typeid( itk::InitializeEvent ) )
@@ -79,19 +82,25 @@ public:
       this->m_lastTotalTime = now;
       m_clock.Start();
 
-      typedef itk::GradientDescentOptimizerv4 GradientDescentOptimizerType;
-      GradientDescentOptimizerType * optimizer = reinterpret_cast<GradientDescentOptimizerType *>(
-          const_cast<typename TOptimizer::OptimizerType *>( const_cast<TOptimizer *>( this->m_Optimizer )->GetOptimizer() ) );
+      typedef itk::GradientDescentOptimizerv4<ParametersValueType> GradientDescentOptimizerType;
+      GradientDescentOptimizerType * optimizer = reinterpret_cast<GradientDescentOptimizerType *>( this->m_Optimizer->GetModifiableOptimizer() );
 
-      // TODO:  This looks very wrong.  There is a const_cast above, and then the change
-      //       of the number of iterations here on what should be a const object.
       optimizer->SetNumberOfIterations( this->m_NumberOfIterations[currentLevel] );
       }
     else
 #endif
     if( typeid( event ) == typeid( itk::IterationEvent ) )
       {
+      // const unsigned int curLevel = this->m_Optimizer->GetCurrentLevel();
+      const unsigned int curIter = this->m_Optimizer->GetCurrentIteration() + 1;
+      if( curIter == 1 )
+        {
+        ++this->m_CurLevel;
+        }
+
       const unsigned int lCurrentIteration = this->m_Optimizer->GetCurrentIteration() + 1;
+
+
       if( lCurrentIteration  == 1 )
         {
         if( this->m_ComputeFullScaleCCInterval != 0 )
@@ -136,13 +145,13 @@ public:
         std::cout << " "; // if the output of current iteration is written to disk, and star
         }                 // will appear before line, else a free space will be printed to keep visual alignment.
 
-      this->Logger() << "DIAGNOSTIC, "
+      this->Logger() << "2DIAGNOSTIC, "
                      << std::setw(5) << lCurrentIteration << ", "
                      << std::scientific << std::setprecision(12) << this->m_Optimizer->GetValue() << ", "
                      << std::scientific << std::setprecision(12) << this->m_Optimizer->GetConvergenceValue() << ", "
                      << std::setprecision(4) << now << ", "
                      << std::setprecision(4) << (now - this->m_lastTotalTime)  << ", ";
-      if( ( this->m_ComputeFullScaleCCInterval != 0 ) &&  fabs(metricValue) > 1e-7 )
+      if( ( this->m_ComputeFullScaleCCInterval != 0 ) && vcl_fabs(metricValue) > 1e-7 )
         {
         this->Logger() << std::scientific << std::setprecision(12) << metricValue
                        << std::flush << std::endl;
@@ -152,6 +161,8 @@ public:
         this->Logger() << std::flush << std::endl;
         }
 
+      this->m_Optimizer->SetNumberOfIterations( this->m_NumberOfIterations[this->m_CurLevel] );
+
       this->m_lastTotalTime = now;
       m_clock.Start();
       }
@@ -206,22 +217,22 @@ public:
                                   MeasureType & metricValue ) const
   {
     // Get the registration metric from the optimizer
-    typename MetricType::ConstPointer inputMetric( dynamic_cast<MetricType const *>( myOptimizer->GetMetric() ) );
+    typename ImageMetricType::Pointer inputMetric( dynamic_cast<ImageMetricType *>( myOptimizer->GetModifiableMetric() ) );
 
     // Define the CC metric type
     // This metric type is used to measure the general similarity metric between the original input fixed and moving
     // images.
-    typedef itk::ANTSNeighborhoodCorrelationImageToImageMetricv4<ImageType, ImageType> CorrelationMetricType;
-    typename CorrelationMetricType::Pointer correlationMetric = CorrelationMetricType::New();
+    typedef itk::ANTSNeighborhoodCorrelationImageToImageMetricv4<ImageType, ImageType, ImageType, MeasureType> CorrelationImageMetricType;
+    typename CorrelationImageMetricType::Pointer correlationMetric = CorrelationImageMetricType::New();
       {
-      typename CorrelationMetricType::RadiusType radius;
+      typename CorrelationImageMetricType::RadiusType radius;
       radius.Fill( 4 );  // NOTE: This is just a common reference for fine-tuning parameters, so perhaps a smaller
                          // window would be sufficient.
       correlationMetric->SetRadius( radius );
       }
     correlationMetric->SetUseMovingImageGradientFilter( false );
     correlationMetric->SetUseFixedImageGradientFilter( false );
-    typename MetricType::Pointer metric = correlationMetric.GetPointer();
+    typename ImageMetricType::Pointer metric = correlationMetric.GetPointer();
 
     // We need to create an exact copy from the composite fixed and moving transforms returned from the metric
     // We should roll off the composite transform and create a new instance from each of its sub transforms
@@ -232,14 +243,11 @@ public:
       {
       typename CompositeTransformType::Pointer myFixedTransform = CompositeTransformType::New();
 
-      // Const_cast just makes it possible to cast the metric's transform to a composite transform, so we can copy each
+      // We cast the metric's transform to a composite transform, so we can copy each
       // of its sub transforms to a new instance.
       // Notice that the metric transform will not be changed inside this fuction.
-      // NOTE:  This will not be needed when ITKv4 is updated to include const versions of all get functions.
-      // TODO: Remove const_cast once ITKv4 is fixed to allow const Get Macro functions.
-      typedef typename MetricType::FixedTransformType FixedTransformType;
       typename CompositeTransformType::ConstPointer inputFixedTransform =
-        dynamic_cast<CompositeTransformType *>( const_cast<FixedTransformType *>( inputMetric->GetFixedTransform() ) );
+                                          dynamic_cast<CompositeTransformType *>( inputMetric->GetModifiableFixedTransform() );
       const unsigned int N = inputFixedTransform->GetNumberOfTransforms();
       for( unsigned int i = 0; i < N; i++ )
         {
@@ -260,7 +268,7 @@ public:
       }
     else if( strcmp( inputMetric->GetFixedTransform()->GetNameOfClass(), "IdentityTransform" ) == 0 )
       {
-      typedef typename itk::IdentityTransform<double, VImageDimension> IdentityTransformType;
+      typedef typename itk::IdentityTransform<RealType, VImageDimension>    IdentityTransformType;
       typename IdentityTransformType::Pointer myFixedTransform = IdentityTransformType::New();
       fixedTransform = myFixedTransform;
       }
@@ -270,11 +278,10 @@ public:
       }
 
     // Same procedure for the moving transform. Moving transform is always a Composite transform.
-    typedef typename MetricType::MovingTransformType MovingTransformType;
     typename CompositeTransformType::Pointer movingTransform = CompositeTransformType::New();
-    // TODO: Remove const_cast once ITKv4 is fixed to allow const Get Macro functions.
+
     typename CompositeTransformType::ConstPointer inputMovingTransform =
-      dynamic_cast<CompositeTransformType *>( const_cast<MovingTransformType *>( inputMetric->GetMovingTransform() ) );
+                                                      dynamic_cast<CompositeTransformType *>( inputMetric->GetModifiableMovingTransform() );
     const unsigned int N = inputMovingTransform->GetNumberOfTransforms();
     for( unsigned int i = 0; i < N; i++ )
       {
@@ -302,14 +309,13 @@ public:
   void WriteIntervalVolumes(itk::WeakPointer<OptimizerType> myOptimizer)
   {
     // Get the registration metric from the optimizer
-    typename MetricType::ConstPointer inputMetric( dynamic_cast<MetricType const *>( myOptimizer->GetMetric() ) );
+    typename ImageMetricType::Pointer inputMetric( dynamic_cast<ImageMetricType *>( myOptimizer->GetModifiableMetric() ) );
 
     // First, compute the moving transform
-    typedef typename MetricType::MovingTransformType MovingTransformType;
     typename CompositeTransformType::Pointer movingTransform = CompositeTransformType::New();
-    // TODO: Remove const_cast once ITKv4 is fixed to allow const Get Macro functions.
+
     typename CompositeTransformType::ConstPointer inputMovingTransform =
-      dynamic_cast<CompositeTransformType *>( const_cast<MovingTransformType *>( inputMetric->GetMovingTransform() ) );
+                                                        dynamic_cast<CompositeTransformType *>( inputMetric->GetModifiableMovingTransform() );
     const unsigned int N = inputMovingTransform->GetNumberOfTransforms();
     for( unsigned int i = 0; i < N; i++ )
       {
@@ -326,10 +332,10 @@ public:
     movingTransform->SetOnlyMostRecentTransformToOptimizeOn();
 
     // Now we apply this output transform to get warped image
-    typedef itk::LinearInterpolateImageFunction<ImageType, double> LinearInterpolatorType;
+    typedef itk::LinearInterpolateImageFunction<ImageType, RealType> LinearInterpolatorType;
     typename LinearInterpolatorType::Pointer linearInterpolator = LinearInterpolatorType::New();
 
-    typedef itk::ResampleImageFilter<ImageType, ImageType> ResampleFilterType;
+    typedef itk::ResampleImageFilter<ImageType, ImageType, RealType> ResampleFilterType;
     typename ResampleFilterType::Pointer resampler = ResampleFilterType::New();
     resampler->SetTransform( movingTransform );
     resampler->SetInput( this->m_origMovingImage );
@@ -339,12 +345,6 @@ public:
     resampler->Update();
 
     // write the results to the disk
-    // const unsigned int curLevel = this->m_Optimizer->GetCurrentLevel();
-    const unsigned int curIter = this->m_Optimizer->GetCurrentIteration() + 1;
-    if( curIter == 1 )
-      {
-      ++this->m_CurLevel;
-      }
     std::stringstream currentFileName;
     currentFileName << "Stage" << this->m_CurrentStageNumber + 1 << "_level" << this->m_CurLevel;
     /*
@@ -352,6 +352,9 @@ public:
     To prevent: "Iter1 Iter10 Iter2 Iter20" we use the following style.
     Then the order is: "Iter1 Iter2 ... Iters10 ... Itert20"
     */
+
+    const unsigned int curIter = this->m_Optimizer->GetCurrentIteration() + 1;
+
     if( curIter > 9 )
       {
       currentFileName << "_Iters" << curIter << ".nii.gz";
@@ -376,9 +379,9 @@ public:
       }
     catch( itk::ExceptionObject & err )
       {
-      antscout << "Can't write warped image " << currentFileName.str().c_str() << std::endl;
-      antscout << "Exception Object caught: " << std::endl;
-      antscout << err << std::endl;
+      std::cout << "Can't write warped image " << currentFileName.str().c_str() << std::endl;
+      std::cout << "Exception Object caught: " << std::endl;
+      std::cout << err << std::endl;
       }
   }
 
