@@ -18,7 +18,7 @@
 #ifndef __antsRegistrationHelper_h
 #define __antsRegistrationHelper_h
 
-#include "ReadWriteImage.h"
+#include "ReadWriteData.h"
 #include "itkANTSAffine3DTransform.h"
 #include "itkANTSCenteredAffine2DTransform.h"
 #include "itkANTSNeighborhoodCorrelationImageToImageMetricv4.h"
@@ -30,6 +30,7 @@
 #include "itkBSplineSyNImageRegistrationMethod.h"
 #include "itkBSplineTransform.h"
 #include "itkBSplineTransformParametersAdaptor.h"
+#include "itkCastImageFilter.h"
 #include "itkCenteredAffineTransform.h"
 #include "itkCenteredTransformInitializer.h"
 #include "itkCommand.h"
@@ -39,8 +40,10 @@
 #include "itkCorrelationImageToImageMetricv4.h"
 #include "itkDemonsImageToImageMetricv4.h"
 #include "itkDisplacementFieldTransform.h"
+#include "itkEuclideanDistancePointSetToPointSetMetricv4.h"
 #include "itkEuler2DTransform.h"
 #include "itkEuler3DTransform.h"
+#include "itkExpectationBasedPointSetToPointSetMetricv4.h"
 #include "itkGaussianExponentialDiffeomorphicTransform.h"
 #include "itkGaussianExponentialDiffeomorphicTransformParametersAdaptor.h"
 #include "itkGaussianSmoothingOnUpdateDisplacementFieldTransform.h"
@@ -55,13 +58,16 @@
 #include "itkImageToHistogramFilter.h"
 #include "itkImageToImageMetricv4.h"
 #include "itkIntensityWindowingImageFilter.h"
+#include "itkJensenHavrdaCharvatTsallisPointSetToPointSetMetricv4.h"
 #include "itkJointHistogramMutualInformationImageToImageMetricv4.h"
+#include "itkLabeledPointSetToPointSetMetricv4.h"
 #include "itkLinearInterpolateImageFunction.h"
 #include "itkMatrixOffsetTransformBase.h"
 #include "itkMattesMutualInformationImageToImageMetricv4.h"
 #include "itkMeanSquaresImageToImageMetricv4.h"
 #include "itkMultiGradientOptimizerv4.h"
 #include "itkObject.h"
+#include "itkObjectToObjectMetric.h"
 #include "itkObjectToObjectMultiMetricv4.h"
 #include "itkQuaternionRigidTransform.h"
 #include "itkRegistrationParameterScalesFromPhysicalShift.h"
@@ -95,7 +101,7 @@ namespace ants
 typedef itk::ants::CommandLineParser ParserType;
 typedef ParserType::OptionType       OptionType;
 
-template <unsigned VImageDimension>
+template <class TComputeType, unsigned VImageDimension>
 class RegistrationHelper : public itk::Object
 {
 public:
@@ -106,13 +112,16 @@ public:
   typedef itk::SmartPointer<const Self> ConstPointer;
   typedef itk::WeakPointer<const Self>  ConstWeakPointer;
 
-  typedef double                                 RealType;
-  typedef double                                 PixelType;
-  typedef itk::Image<PixelType, VImageDimension> ImageType;
-  typedef typename ImageType::Pointer            ImagePointer;
-  typedef itk::ImageBase<VImageDimension>        ImageBaseType;
+  typedef TComputeType                                                               RealType;
+  typedef TComputeType                                                               PixelType;
+  typedef itk::Image<PixelType, VImageDimension>                                     ImageType;
+  typedef typename ImageType::Pointer                                                ImagePointer;
+  typedef itk::ImageBase<VImageDimension>                                            ImageBaseType;
+  typedef typename ImageType::SpacingType                                            ImageSpacingType;
+  typedef itk::PointSet<unsigned int, VImageDimension>                               PointSetType;
+  typedef typename PointSetType::Pointer                                             PointSetPointer;
 
-  typedef itk::Transform<double, VImageDimension, VImageDimension>                   TransformType;
+  typedef itk::Transform<TComputeType, VImageDimension, VImageDimension>             TransformType;
   typedef itk::AffineTransform<RealType, VImageDimension>                            AffineTransformType;
   typedef itk::ImageRegistrationMethodv4<ImageType, ImageType, AffineTransformType>  AffineRegistrationType;
   typedef typename AffineRegistrationType::ShrinkFactorsPerDimensionContainerType    ShrinkFactorsPerDimensionContainerType;
@@ -124,8 +133,12 @@ public:
   typedef typename DisplacementFieldTransformType::Pointer                           DisplacementFieldTransformPointer;
   typedef typename DisplacementFieldTransformType::DisplacementFieldType             DisplacementFieldType;
   typedef itk::TimeVaryingVelocityFieldTransform<RealType, VImageDimension>          TimeVaryingVelocityFieldTransformType;
-  typedef itk::ImageToImageMetricv4<ImageType, ImageType>                            MetricType;
-  typedef itk::ObjectToObjectMultiMetricv4<VImageDimension, VImageDimension>         MultiMetricType;
+  typedef itk::ObjectToObjectMetric
+                     <VImageDimension, VImageDimension, ImageType, RealType>         ObjectMetricType;
+  typedef itk::ObjectToObjectMultiMetricv4
+                     <VImageDimension, VImageDimension, ImageType, RealType>         MultiMetricType;
+  typedef itk::ImageToImageMetricv4<ImageType, ImageType, ImageType, RealType>       ImageMetricType;
+  typedef itk::PointSetToPointSetMetricv4<PointSetType, PointSetType, RealType>      PointSetMetricType;
   typedef itk::ImageMaskSpatialObject<VImageDimension>                               ImageMaskSpatialObjectType;
   typedef typename ImageMaskSpatialObjectType::ImageType                             MaskImageType;
   typedef itk::InterpolateImageFunction<ImageType, RealType>                         InterpolatorType;
@@ -138,22 +151,43 @@ public:
     MeanSquares = 3,
     Demons = 4,
     GC = 5,
-    IllegalMetric = 6
+    ICP = 6,
+    PSE = 7,
+    JHCT = 8,
+    IllegalMetric = 9
     };
   enum SamplingStrategy
     {
-    none = 0,
-    regular = 1,
-    random = 2,
+    none = 0,     // aka dense
+    regular = 1,  // regularly spaced sub-sampling
+    random = 2,   // irregularly spaced sub-sampling
     invalid = 17
     };
+
+  bool IsPointSetMetric( const MetricEnumeration metricType ) const
+    {
+    if( metricType == ICP || metricType == PSE || metricType == JHCT )
+      {
+      return true;
+      }
+    else
+      {
+      return false;
+      }
+    }
+
   class Metric
   {
-public:
-    Metric( MetricEnumeration metricType, typename ImageType::Pointer & fixedImage,
-            typename ImageType::Pointer & movingImage, unsigned int stageID, double weighting,
-            SamplingStrategy samplingStrategy, int numberOfBins, unsigned int radius,
-            double samplingPercentage ) :
+  public:
+    Metric( MetricEnumeration metricType,
+            ImageType *fixedImage, ImageType *movingImage,
+            PointSetType *fixedPointSet, PointSetType *movingPointSet,
+            unsigned int stageID, RealType weighting,
+            SamplingStrategy samplingStrategy, int numberOfBins,
+            unsigned int radius, bool useBoundaryPointsOnly,
+            RealType pointSetSigma, unsigned int evaluationKNeighborhood,
+            RealType alpha, bool useAnisotropicCovariances,
+            RealType samplingPercentage ) :
       m_MetricType( metricType ),
       m_FixedImage( fixedImage ),
       m_MovingImage( movingImage ),
@@ -162,6 +196,13 @@ public:
       m_SamplingStrategy( samplingStrategy ),
       m_NumberOfBins( numberOfBins ),
       m_Radius( radius ),
+      m_FixedPointSet( fixedPointSet ),
+      m_MovingPointSet( movingPointSet ),
+      m_UseBoundaryPointsOnly( useBoundaryPointsOnly ),
+      m_PointSetSigma( pointSetSigma ),
+      m_EvaluationKNeighborhood( evaluationKNeighborhood ),
+      m_Alpha( alpha ),
+      m_UseAnisotropicCovariances( useAnisotropicCovariances ),
       m_SamplingPercentage( samplingPercentage )
     {
     }
@@ -172,45 +213,73 @@ public:
         {
         case CC:
           {
-          return "CC";
+          return std::string( "CC" );
           }
         case MI:
           {
-          return "MI";
+          return std::string( "MI" );
           }
         case Mattes:
           {
-          return "Mattes";;
+          return std::string( "Mattes" );
           }
         case MeanSquares:
           {
-          return "MeanSquares";
+          return std::string( "MeanSquares" );
           }
         case Demons:
           {
-          return "Demons";
+          return std::string( "Demons" );
           }
         case GC:
           {
-          return "GC";
+          return std::string( "GC" );
+          }
+        case ICP:
+          {
+          return std::string( "ICP" );
+          }
+        case PSE:
+          {
+          return std::string( "PSE" );
+          }
+        case JHCT:
+          {
+          return std::string( "JHCT" );
           }
         default:
           {
           }
           break;
         }
-      return "";
+      return std::string( "Illegal" );
     }
 
-    MetricEnumeration m_MetricType;
-    typename ImageType::Pointer m_FixedImage;
-    typename ImageType::Pointer m_MovingImage;
-    unsigned int     m_StageID;
-    double           m_Weighting;
-    SamplingStrategy m_SamplingStrategy;
-    int              m_NumberOfBins;
-    unsigned int     m_Radius;
-    double           m_SamplingPercentage;
+    MetricEnumeration   m_MetricType;
+
+    // Variables for image metrics
+
+    ImagePointer        m_FixedImage;
+    ImagePointer        m_MovingImage;
+    unsigned int        m_StageID;
+    RealType            m_Weighting;
+    SamplingStrategy    m_SamplingStrategy;
+    int                 m_NumberOfBins;
+    unsigned int        m_Radius;                    // Only for CC metric
+
+    // Variables for point-set metrics
+
+    PointSetPointer     m_FixedPointSet;
+    PointSetPointer     m_MovingPointSet;
+    bool                m_UseBoundaryPointsOnly;
+    RealType            m_PointSetSigma;             // Only for PSE,JHCT metrics
+    RealType            m_EvaluationKNeighborhood;   // Only for PSE,JHCT metrics
+    RealType            m_Alpha;                     // Only for JHCT metric
+    bool                m_UseAnisotropicCovariances; // Only for JHCT metric
+
+    // Variables for both
+
+    RealType            m_SamplingPercentage;
   };
 
   typedef std::deque<Metric> MetricListType;
@@ -236,7 +305,7 @@ public:
 
   class TransformMethod
   {
-public:
+  public:
     TransformMethod() : m_XfrmMethod( Rigid ),
       m_GradientStep( 0 ),
       m_UpdateFieldVarianceInVarianceSpace( 0.0 ),
@@ -256,89 +325,90 @@ public:
         {
         case Rigid:
           {
-          return std::string("Rigid");
+          return std::string( "Rigid" );
           }
         case Affine:
           {
-          return std::string("Affine");
+          return std::string( "Affine" );
           }
         case CompositeAffine:
           {
-          return std::string("CompositeAffine");
+          return std::string( "CompositeAffine" );
           }
         case Similarity:
           {
-          return std::string("Similarity");
+          return std::string( "Similarity" );
           }
         case Translation:
           {
-          return std::string("Translation");
+          return std::string( "Translation" );
           }
         case BSpline:
           {
-          return std::string("BSpline");
+          return std::string( "BSpline" );
           }
         case GaussianDisplacementField:
           {
-          return std::string("GaussianDisplacementField");
+          return std::string( "GaussianDisplacementField" );
           }
         case BSplineDisplacementField:
           {
-          return std::string("BSplineDisplacementField");
+          return std::string( "BSplineDisplacementField" );
           }
         case TimeVaryingVelocityField:
           {
-          return std::string("TimeVaryingVelocityField");
+          return std::string( "TimeVaryingVelocityField" );
           }
         case TimeVaryingBSplineVelocityField:
           {
-          return std::string("TimeVaryingBSplineVelocityField");
+          return std::string( "TimeVaryingBSplineVelocityField" );
           }
         case SyN:
           {
-          return std::string("SyN");
+          return std::string( "SyN" );
           }
         case BSplineSyN:
           {
-          return std::string("BSplineSyN");
+          return std::string( "BSplineSyN" );
           }
         case Exponential:
           {
-          return std::string("Exponential");
+          return std::string( "Exponential" );
           }
         case BSplineExponential:
           {
-          return std::string("BSplineExponential");
+          return std::string( "BSplineExponential" );
           }
-        case UnknownXfrm: return std::string("UnknownXfrm");
+        case UnknownXfrm: return std::string( "UnknownXfrm" );
         }
-      return std::string("Impossible");
+      return std::string( "Impossible" );
     }
 
     XfrmMethod m_XfrmMethod;
     // all transforms
-    double m_GradientStep;
-    // BSPline
+    RealType m_GradientStep;
+    // BSpline
     std::vector<unsigned int> m_MeshSizeAtBaseLevel;
     // GaussianDisplacementField
-    double m_UpdateFieldVarianceInVarianceSpace;
-    double m_TotalFieldVarianceInVarianceSpace;
+    RealType m_UpdateFieldVarianceInVarianceSpace;
+    RealType m_TotalFieldVarianceInVarianceSpace;
     // BSplineDisplacementField
     std::vector<unsigned int> m_TotalFieldMeshSizeAtBaseLevel;
     std::vector<unsigned int> m_UpdateFieldMeshSizeAtBaseLevel;
     unsigned int              m_SplineOrder; // also anything B-spline
     // TimeVaryingVelocityField
-    double       m_UpdateFieldTimeSigma;
-    double       m_TotalFieldTimeSigma;
-    unsigned int m_NumberOfTimeIndices;
+    RealType       m_UpdateFieldTimeSigma;
+    RealType       m_TotalFieldTimeSigma;
+    unsigned int   m_NumberOfTimeIndices;
     // TimeVaryingBSplineVelocityField
     std::vector<unsigned int> m_VelocityFieldMeshSize;
     unsigned int              m_NumberOfTimePointSamples;
     // Exponential
-    double m_VelocityFieldVarianceInVarianceSpace;
+    RealType m_VelocityFieldVarianceInVarianceSpace;
     // BSplineExponential
     std::vector<unsigned int> m_VelocityFieldMeshSizeAtBaseLevel;
   };
+
   typedef std::deque<TransformMethod> TransformMethodListType;
 
   /** Method for creation through the object factory. */
@@ -357,14 +427,38 @@ public:
    * add a metric, corresponding to the registration stage
    */
   void AddMetric( MetricEnumeration metricType,
-                  typename ImageType::Pointer & fixedImage,
-                  typename ImageType::Pointer & movingImage,
+                  ImageType *fixedImage,
+                  ImageType *movingImage,
+                  PointSetType *fixedPointSet,
+                  PointSetType *movingPointSet,
                   unsigned int stageID,
-                  double weighting,
+                  RealType weighting,
                   SamplingStrategy samplingStrategy,
                   int numberOfBins,
                   unsigned int radius,
-                  double samplingPercentage );
+                  bool useBoundaryPointsOnly,
+                  RealType pointSetSigma,
+                  unsigned int evaluationKNeighborhood,
+                  RealType alpha,
+                  bool useAnisotropicCovariances,
+                  RealType samplingPercentage );
+
+  /** For backwards compatibility */
+  inline void AddMetric( MetricEnumeration metricType,
+                  ImageType *fixedImage,
+                  ImageType *movingImage,
+                  unsigned int stageID,
+                  RealType weighting,
+                  SamplingStrategy samplingStrategy,
+                  int numberOfBins,
+                  unsigned int radius,
+                  RealType samplingPercentage )
+    {
+    this->AddMetric( metricType, fixedImage, movingImage, ITK_NULLPTR, ITK_NULLPTR,
+      stageID, weighting, samplingStrategy, numberOfBins, radius,
+      false, 1.0, 50, 1.1, false, samplingPercentage );
+    }
+
 
   /**
    * Get set of metrics per stage.  If we have more than one, we have
@@ -392,46 +486,51 @@ public:
    */
   void SetMovingInitialTransform( const TransformType *initialTransform );
 
+  /**
+   * restore the state transform and set that as an initial transform.
+   */
+  void SetRestoreStateTransform( const TransformType *initialTransform );
+
   /**
    * add a rigid transform
    */
-  void AddRigidTransform( double GradientStep );
+  void AddRigidTransform( RealType GradientStep );
 
   /**
    * add an affine transform
    */
-  void AddAffineTransform( double GradientStep );
+  void AddAffineTransform( RealType GradientStep );
 
   /**
    * add a composite affine transform
    */
-  void AddCompositeAffineTransform( double GradientStep );
+  void AddCompositeAffineTransform( RealType GradientStep );
 
   /**
    * add a similarity transform
    */
-  void AddSimilarityTransform( double GradientStep );
+  void AddSimilarityTransform( RealType GradientStep );
 
   /**
    * add a translation transform
    */
-  void AddTranslationTransform( double GradientStep );
+  void AddTranslationTransform( RealType GradientStep );
 
   /**
    * add a spline transform
    */
-  void AddBSplineTransform( double GradientStep, std::vector<unsigned int> & MeshSizeAtBaseLevel );
+  void AddBSplineTransform( RealType GradientStep, std::vector<unsigned int> & MeshSizeAtBaseLevel );
 
   /**
    * add gaussian displacement transform
    */
-  void AddGaussianDisplacementFieldTransform( double GradientStep, double UpdateFieldVarianceInVarianceSpace,
-                                              double TotalFieldVarianceInVarianceSpace );
+  void AddGaussianDisplacementFieldTransform( RealType GradientStep, RealType UpdateFieldVarianceInVarianceSpace,
+                                              RealType TotalFieldVarianceInVarianceSpace );
 
   /**
    * add bspline displacement transform
    */
-  void AddBSplineDisplacementFieldTransform( double GradientStep,
+  void AddBSplineDisplacementFieldTransform( RealType GradientStep,
                                              std::vector<unsigned int> & UpdateFieldMeshSizeAtBaseLevel,
                                              std::vector<unsigned int> & TotalFieldMeshSizeAtBaseLevel,
                                              unsigned int SplineOrder );
@@ -439,51 +538,51 @@ public:
   /**
    * add a time varying velocity field transform
    */
-  void AddTimeVaryingVelocityFieldTransform( double GradientStep, unsigned int NumberOfTimeIndices,
-                                             double UpdateFieldVarianceInVarianceSpace, double UpdateFieldTimeSigma,
-                                             double TotalFieldVarianceInVarianceSpace, double TotalFieldTimeSigma );
+  void AddTimeVaryingVelocityFieldTransform( RealType GradientStep, unsigned int NumberOfTimeIndices,
+                                             RealType UpdateFieldVarianceInVarianceSpace, RealType UpdateFieldTimeSigma,
+                                             RealType TotalFieldVarianceInVarianceSpace, RealType TotalFieldTimeSigma );
 
   /**
    * add a time varying b spline velocity field transform
    */
-  void AddTimeVaryingBSplineVelocityFieldTransform( double GradientStep,
+  void AddTimeVaryingBSplineVelocityFieldTransform( RealType GradientStep,
                                                     std::vector<unsigned int> VelocityFieldMeshSize,
                                                     unsigned int NumberOfTimePointSamples, unsigned int SplineOrder );
 
   /**
    * add a SyN transform
    */
-  void AddSyNTransform( double GradientStep, double UpdateFieldVarianceInVarianceSpace,
-                        double TotalFieldVarianceInVarianceSpace );
+  void AddSyNTransform( RealType GradientStep, RealType UpdateFieldVarianceInVarianceSpace,
+                        RealType TotalFieldVarianceInVarianceSpace );
 
   /**
    * add a B-spline SyN transform
    */
-  void AddBSplineSyNTransform( double GradientStep, std::vector<unsigned int> & UpdateFieldMeshSizeAtBaseLevel,
+  void AddBSplineSyNTransform( RealType GradientStep, std::vector<unsigned int> & UpdateFieldMeshSizeAtBaseLevel,
                                std::vector<unsigned int> & TotalFieldMeshSizeAtBaseLevel, unsigned int SplineOrder );
 
   /**
    * add an exponential transform
    */
-  void AddExponentialTransform( double GradientStep, double UpdateFieldVarianceInVarianceSpace,
-                                double VelocityFieldVarianceInVarianceSpace, unsigned int NumberOfIntegrationSteps );
+  void AddExponentialTransform( RealType GradientStep, RealType UpdateFieldVarianceInVarianceSpace,
+                                RealType VelocityFieldVarianceInVarianceSpace, unsigned int NumberOfIntegrationSteps );
 
   /**
    * add a B-spline exponential transform
    */
-  void AddBSplineExponentialTransform( double GradientStep, std::vector<unsigned int> & UpdateFieldMeshSizeAtBaseLevel,
+  void AddBSplineExponentialTransform( RealType GradientStep, std::vector<unsigned int> & UpdateFieldMeshSizeAtBaseLevel,
                                        std::vector<unsigned int> & VelocityFieldMeshSizeAtBaseLevel,
                                        unsigned int NumberOfIntegrationSteps, unsigned int SplineOrder );
 
   /**
    * Add the collected iterations list
    */
-  void SetIterations(const std::vector<std::vector<unsigned int> > & Iterations);
+  void SetIterations( const std::vector<std::vector<unsigned int> > & Iterations );
 
   /**
    * Add the collected convergence thresholds
    */
-  void SetConvergenceThresholds( const std::vector<double> & thresholds );
+  void SetConvergenceThresholds( const std::vector<RealType> & thresholds );
 
   /**
    * Add the collected convergence window sizes
@@ -495,6 +594,11 @@ public:
    */
   void SetSmoothingSigmas( const std::vector<std::vector<float> > & SmoothingSigmas );
 
+  /**
+   * Add the restrict deformation optimizer weights
+   */
+  void SetRestrictDeformationOptimizerWeights( const std::vector<std::vector<RealType> > & restrictDeformationWeights );
+
   /**
    * Add the collected bool smoothing sigmas in voxel units list
    */
@@ -512,7 +616,7 @@ public:
    * Then, for each other dimension, we find the factor ( < specified factor ) which
    * makes the subsampled image as close to isotropic (in terms of spacing) as possible.
    */
-  ShrinkFactorsPerDimensionContainerType CalculateShrinkFactorsPerDimension( unsigned int, ImagePointer );
+  ShrinkFactorsPerDimensionContainerType CalculateShrinkFactorsPerDimension( unsigned int, ImageSpacingType );
 
   /**
    * turn on histogram matching of the input images
@@ -550,13 +654,20 @@ public:
   itkSetMacro( WriteIntervalVolumes, unsigned int );
   itkGetConstMacro( WriteIntervalVolumes, unsigned int );
 
+  /**
+   * turn on the option that cause the direct initialization of the linear transforms at each stage.
+   */
+  itkSetMacro( InitializeTransformsPerStage, bool );
+  itkGetConstMacro( InitializeTransformsPerStage, bool );
+  itkBooleanMacro( InitializeTransformsPerStage );
+
   /**
    * turn on winsorize image intensity normalization
    */
   void SetWinsorizeImageIntensities( bool Winsorize, float LowerQuantile = 0.0, float UpperQuantile = 1.0 );
 
   itkGetModifiableObjectMacro( CompositeTransform, CompositeTransformType );
-
+  itkGetModifiableObjectMacro( RegistrationState, CompositeTransformType );
   /**
    * Set/Get the interpolator.  Linear is default.
    */
@@ -595,6 +706,34 @@ public:
    */
   CompositeTransformPointer CollapseCompositeTransform( const CompositeTransformType * );
 
+  void ApplyCompositeLinearTransformToImageHeader( const CompositeTransformType *, ImageBaseType * const,
+                                                   const bool applyInverse );
+
+  /**
+   * Collapse a composite transform composed of displacement field transforms to a single displacement field transform.
+   */
+  DisplacementFieldTransformPointer CollapseDisplacementFieldTransforms( const CompositeTransformType * );
+
+  /**
+   * Collapse a composite linear transform to a generic affine transform.
+   */
+  typename AffineTransformType::Pointer  CollapseLinearTransforms( const CompositeTransformType * );
+
+  /**
+   *
+   */
+  template<class TTransformType>
+  bool InitializeWithPreviousLinearTransform(const CompositeTransformType *,
+                                             const std::string,
+                                             typename TTransformType::Pointer &);
+
+  /**
+   * Compute approximate mesh size for a specified isotropic knot spacing
+   */
+  std::vector<unsigned int> CalculateMeshSizeForSpecifiedKnotSpacing( ImageBaseType * const,
+                                                                       const RealType,
+                                                                       const unsigned int );
+
   /**
    * Do the registration. Will return EXIT_FAILURE if there is any
    * problem completing the registration.
@@ -623,6 +762,7 @@ private:
   }
 
   typename CompositeTransformType::Pointer         m_CompositeTransform;
+  typename CompositeTransformType::Pointer         m_RegistrationState;
   typename CompositeTransformType::Pointer         m_FixedInitialTransform;
   typename ImageMaskSpatialObjectType::Pointer     m_FixedImageMask;
   typename ImageMaskSpatialObjectType::Pointer     m_MovingImageMask;
@@ -633,51 +773,165 @@ private:
   MetricListType                          m_Metrics;
   TransformMethodListType                 m_TransformMethods;
   std::vector<std::vector<unsigned int> > m_Iterations;
-  std::vector<double>                     m_ConvergenceThresholds;
+  std::vector<RealType>                   m_ConvergenceThresholds;
   std::vector<unsigned int>               m_ConvergenceWindowSizes;
   std::vector<std::vector<float> >        m_SmoothingSigmas;
   std::vector<bool>                       m_SmoothingSigmasAreInPhysicalUnits;
+  std::vector<std::vector<RealType> >     m_RestrictDeformationOptimizerWeights;
   std::vector<std::vector<unsigned int> > m_ShrinkFactors;
   bool                                    m_UseHistogramMatching;
   bool                                    m_WinsorizeImageIntensities;
   bool                                    m_DoEstimateLearningRateAtEachIteration;
-  double                                  m_LowerQuantile;
-  double                                  m_UpperQuantile;
+  RealType                                m_LowerQuantile;
+  RealType                                m_UpperQuantile;
   std::ostream *                          m_LogStream;
 
-  void ApplyCompositeLinearTransformToImageHeader( const CompositeTransformType *, ImageBaseType * const,
-                                                   const bool applyInverse );
-
-  DisplacementFieldTransformPointer CollapseDisplacementFieldTransforms( const CompositeTransformType * );
-
-  typename AffineTransformType::Pointer  CollapseLinearTransforms( const CompositeTransformType * );
-
   bool         m_ApplyLinearTransformsToFixedImageHeader;
   unsigned int m_PrintSimilarityMeasureInterval;
   unsigned int m_WriteIntervalVolumes;
+  bool         m_InitializeTransformsPerStage;
   bool         m_AllPreviousTransformsAreLinear;
   typename CompositeTransformType::Pointer m_CompositeLinearTransformForFixedImageHeader;
 };
 
 // ##########################################################################
 // ##########################################################################
+
+/**
+ * Transform traits to generalize the rigid transform
+ */
+template <class TComputeType, unsigned int ImageDimension>
+class RigidTransformTraits
+{
+  // Don't worry about the fact that the default option is the
+  // affine Transform, that one will not actually be instantiated.
+public:
+typedef itk::AffineTransform<TComputeType, ImageDimension> TransformType;
+};
+
+template <>
+class RigidTransformTraits<double, 2>
+{
+public:
+typedef itk::Euler2DTransform<double> TransformType;
+};
+
+template <>
+class RigidTransformTraits<float, 2>
+{
+public:
+typedef itk::Euler2DTransform<float> TransformType;
+};
+
+template <>
+class RigidTransformTraits<double, 3>
+{
+public:
+  // typedef itk::VersorRigid3DTransform<double>    TransformType;
+  // typedef itk::QuaternionRigidTransform<double>  TransformType;
+typedef itk::Euler3DTransform<double> TransformType;
+};
+
+template <>
+class RigidTransformTraits<float, 3>
+{
+public:
+  // typedef itk::VersorRigid3DTransform<float>    TransformType;
+  // typedef itk::QuaternionRigidTransform<float>  TransformType;
+typedef itk::Euler3DTransform<float> TransformType;
+};
+
+template <class TComputeType, unsigned int ImageDimension>
+class SimilarityTransformTraits
+{
+// Don't worry about the fact that the default option is the
+// affine Transform, that one will not actually be instantiated.
+public:
+typedef itk::AffineTransform<TComputeType, ImageDimension> TransformType;
+};
+
+template <>
+class SimilarityTransformTraits<double, 2>
+{
+public:
+typedef itk::Similarity2DTransform<double> TransformType;
+};
+
+template <>
+class SimilarityTransformTraits<float, 2>
+{
+public:
+typedef itk::Similarity2DTransform<float> TransformType;
+};
+
+template <>
+class SimilarityTransformTraits<double, 3>
+{
+public:
+typedef itk::Similarity3DTransform<double> TransformType;
+};
+
+template <>
+class SimilarityTransformTraits<float, 3>
+{
+public:
+typedef itk::Similarity3DTransform<float> TransformType;
+};
+
+template <class TComputeType, unsigned int ImageDimension>
+class CompositeAffineTransformTraits
+{
+// Don't worry about the fact that the default option is the
+// affine Transform, that one will not actually be instantiated.
+public:
+typedef itk::AffineTransform<TComputeType, ImageDimension> TransformType;
+};
+
+template <>
+class CompositeAffineTransformTraits<double, 2>
+{
+public:
+typedef itk::ANTSCenteredAffine2DTransform<double> TransformType;
+};
+
+template <>
+class CompositeAffineTransformTraits<float, 2>
+{
+public:
+typedef itk::ANTSCenteredAffine2DTransform<float> TransformType;
+};
+
+template <>
+class CompositeAffineTransformTraits<double, 3>
+{
+public:
+typedef itk::ANTSAffine3DTransform<double> TransformType;
+};
+
+template <>
+class CompositeAffineTransformTraits<float, 3>
+{
+public:
+typedef itk::ANTSAffine3DTransform<float> TransformType;
+};
+
 // ##########################################################################
 // ##########################################################################
 
 // Provide common way of reading transforms.
-template <unsigned VImageDimension>
-typename ants::RegistrationHelper<VImageDimension>::CompositeTransformType::Pointer
+template <class TComputeType, unsigned VImageDimension>
+typename ants::RegistrationHelper<TComputeType, VImageDimension>::CompositeTransformType::Pointer
 GetCompositeTransformFromParserOption( typename ParserType::Pointer & parser,
                                        typename ParserType::OptionType::Pointer initialTransformOption,
                                        std::vector<bool> & derivedTransforms, bool useStaticCastForR = false )
 {
-  typedef typename ants::RegistrationHelper<VImageDimension>      RegistrationHelperType;
+  typedef typename ants::RegistrationHelper<TComputeType, VImageDimension>      RegistrationHelperType;
   typedef typename RegistrationHelperType::CompositeTransformType CompositeTransformType;
   typename CompositeTransformType::Pointer compositeTransform = CompositeTransformType::New();
 
   typedef typename RegistrationHelperType::ImageType ImageType;
-  typename ImageType::Pointer fixedImage = NULL;
-  typename ImageType::Pointer movingImage = NULL;
+  typename ImageType::Pointer fixedImage = ITK_NULLPTR;
+  typename ImageType::Pointer movingImage = ITK_NULLPTR;
 
   std::deque<std::string> transformNames;
   std::deque<std::string> transformTypes;
@@ -697,7 +951,7 @@ GetCompositeTransformFromParserOption( typename ParserType::Pointer & parser,
     else if( initialTransformOption->GetFunction( n )->GetNumberOfParameters() > 2 )
       {
       std::string fixedImageFileName = initialTransformOption->GetFunction( n )->GetParameter( 0 );
-      ReadImage<ImageType>( fixedImage,  fixedImageFileName.c_str() );
+      ReadImage<ImageType>( fixedImage, fixedImageFileName.c_str() );
       if( fixedImage )
         {
         std::string movingImageFileName = initialTransformOption->GetFunction( n )->GetParameter( 1 );
@@ -712,7 +966,8 @@ GetCompositeTransformFromParserOption( typename ParserType::Pointer & parser,
       unsigned short initializationFeature = parser->Convert<unsigned short>(
         initialTransformOption->GetFunction( n )->GetParameter( 2 ) );
 
-      typedef itk::AffineTransform<double, VImageDimension> TransformType;
+      typedef typename RigidTransformTraits<TComputeType, VImageDimension>::TransformType  TransformType;
+
       typename TransformType::Pointer transform = TransformType::New();
 
       if( initializationFeature == 0 || initializationFeature == 1 )
@@ -759,17 +1014,13 @@ GetCompositeTransformFromParserOption( typename ParserType::Pointer & parser,
       initialTransformName += std::string( "fixed image: " ) + initialTransformOption->GetFunction( n )->GetParameter( 0 )
         + std::string( " and moving image: " ) + initialTransformOption->GetFunction( n )->GetParameter( 1 );
 
-      typedef itk::TranslationTransform<double, VImageDimension> TranslationTransformType;
-      typename TranslationTransformType::Pointer translationTransform = TranslationTransformType::New();
-      translationTransform->SetOffset( transform->GetTranslation() );
-
-      compositeTransform->AddTransform( translationTransform );
+      compositeTransform->AddTransform( transform );
 
       calculatedTransformFromImages = true;
       derivedTransforms[n] = true;
 
       transformNames.push_back( initialTransformName );
-      transformTypes.push_back( translationTransform->GetNameOfClass() );
+      transformTypes.push_back( transform->GetNameOfClass() );
       }
 
     if( !calculatedTransformFromImages )
@@ -795,20 +1046,17 @@ GetCompositeTransformFromParserOption( typename ParserType::Pointer & parser,
       MatOffRegistered = true;
       // Register the matrix offset transform base class to the
       // transform factory for compatibility with the current ANTs.
-      typedef itk::MatrixOffsetTransformBase<double, VImageDimension, VImageDimension> MatrixOffsetTransformType;
+      typedef itk::MatrixOffsetTransformBase<TComputeType, VImageDimension, VImageDimension> MatrixOffsetTransformType;
       itk::TransformFactory<MatrixOffsetTransformType>::RegisterTransform();
       }
 
     if( !calculatedTransformFromImages )
       {
-      typedef ants::RegistrationHelper<VImageDimension>                       RegistrationHelperType;
-      typedef typename RegistrationHelperType::DisplacementFieldTransformType DisplacementFieldTransformType;
-
       typedef typename RegistrationHelperType::TransformType TransformType;
       typename TransformType::Pointer initialTransform;
       if( std::strcmp( initialTransformName.c_str(), "identity" ) == 0 || std::strcmp( initialTransformName.c_str(), "Identity" ) == 0 )
         {
-        typedef itk::MatrixOffsetTransformBase<double, VImageDimension, VImageDimension> MatrixOffsetTransformType;
+        typedef itk::MatrixOffsetTransformBase<TComputeType, VImageDimension, VImageDimension> MatrixOffsetTransformType;
         typename MatrixOffsetTransformType::Pointer identityTransform = MatrixOffsetTransformType::New();
         identityTransform->SetIdentity();
 
@@ -816,28 +1064,28 @@ GetCompositeTransformFromParserOption( typename ParserType::Pointer & parser,
         }
       else
         {
-        initialTransform = itk::ants::ReadTransform<VImageDimension>( initialTransformName, useStaticCastForR );
+        initialTransform = itk::ants::ReadTransform<TComputeType, VImageDimension>( initialTransformName, useStaticCastForR );
         }
       if( initialTransform.IsNull() )
         {
-        ::ants::antscout << "Can't read initial transform " << initialTransformName << std::endl;
-        return NULL;
+        std::cout << "Can't read initial transform " << initialTransformName << std::endl;
+        return ITK_NULLPTR;
         }
       if( useInverse )
         {
         initialTransform = dynamic_cast<TransformType *>( initialTransform->GetInverseTransform().GetPointer() );
         if( initialTransform.IsNull() )
           {
-          ::ants::antscout << "Inverse does not exist for " << initialTransformName << std::endl;
-          return NULL;
+          std::cout << "Inverse does not exist for " << initialTransformName << std::endl;
+          return ITK_NULLPTR;
           }
         initialTransformName = std::string( "inverse of " ) + initialTransformName;
         }
       static const std::string CompositeTransformID("CompositeTransform");
       if( initialTransform->GetNameOfClass() == CompositeTransformID )
         {
-        const typename itk::CompositeTransform<double, VImageDimension>::ConstPointer tempComp =
-          dynamic_cast<const itk::CompositeTransform<double, VImageDimension> *>( initialTransform.GetPointer() );
+        const typename itk::CompositeTransform<TComputeType, VImageDimension>::ConstPointer tempComp =
+          dynamic_cast<const itk::CompositeTransform<TComputeType, VImageDimension> *>( initialTransform.GetPointer() );
         for( unsigned int i = 0; i < tempComp->GetNumberOfTransforms(); ++i )
           {
           std::stringstream tempstream;
@@ -856,13 +1104,13 @@ GetCompositeTransformFromParserOption( typename ParserType::Pointer & parser,
         }
       }
     }
-  antscout << "=============================================================================" << std::endl;
-  antscout << "The composite transform is comprised of the following transforms (in order): " << std::endl;
+  std::cout << "=============================================================================" << std::endl;
+  std::cout << "The composite transform comprises the following transforms (in order): " << std::endl;
   for( unsigned int n = 0; n < transformNames.size(); n++ )
     {
-    antscout << "  " << n + 1 << ". " << transformNames[n] << " (type = " << transformTypes[n] << ")" << std::endl;
+    std::cout << "  " << n + 1 << ". " << transformNames[n] << " (type = " << transformTypes[n] << ")" << std::endl;
     }
-  antscout << "=============================================================================" << std::endl;
+  std::cout << "=============================================================================" << std::endl;
   return compositeTransform;
 }
 
