@@ -28,7 +28,7 @@
 #include "itkMinimumMaximumImageFilter.h"
 #include "itkImage.h"
 #include "itkMacro.h"
-#include "ReadWriteImage.h"
+#include "ReadWriteData.h"
 #include "itkCenteredEuler3DTransform.h"
 #include "itkQuaternionRigidTransform.h"
 #include "itkANTSAffine3DTransform.h"
@@ -368,7 +368,7 @@ public:
         }
       if( this->m_Debug )
         {
-        ::ants::antscout << " ExpFac " << expandFactors[idim] << " curdsz " << this->m_CurrentDomainSize[idim]
+        std::cout << " ExpFac " << expandFactors[idim] << " curdsz " << this->m_CurrentDomainSize[idim]
                          << std::endl;
         }
       }
@@ -395,7 +395,7 @@ public:
         {
         expandFactors[idim] = 1;
         }
-      //             if (this->m_Debug)  ::ants::antscout << " ExpFac " << expandFactors[idim] << " curdsz " <<
+      //             if (this->m_Debug)  std::cout << " ExpFac " << expandFactors[idim] << " curdsz " <<
       // this->m_CurrentDomainSize[idim] << std::endl;
       }
 
@@ -414,7 +414,7 @@ public:
     fieldout->SetOrigin(field->GetOrigin() );
     if( this->m_Debug )
       {
-      ::ants::antscout << " Field size " << fieldout->GetLargestPossibleRegion().GetSize() << std::endl;
+      std::cout << " Field size " << fieldout->GetLargestPossibleRegion().GetSize() << std::endl;
       }
     // this->m_Debug=false;
 
@@ -446,11 +446,11 @@ public:
   DisplacementFieldPointer SubsampleField( DisplacementFieldPointer field, typename ImageType::SizeType
                                            targetSize, typename ImageType::SpacingType targetSpacing )
   {
-    ::ants::antscout << "FIXME -- NOT DONE CORRECTLY " << std::endl;
-    ::ants::antscout << "FIXME -- NOT DONE CORRECTLY " << std::endl;
-    ::ants::antscout << "FIXME -- NOT DONE CORRECTLY " << std::endl;
-    ::ants::antscout << "FIXME -- NOT DONE CORRECTLY " << std::endl;
-    ::ants::antscout << " SUBSAM FIELD SUBSAM FIELD SUBSAM FIELD " << std::endl;
+    std::cout << "FIXME -- NOT DONE CORRECTLY " << std::endl;
+    std::cout << "FIXME -- NOT DONE CORRECTLY " << std::endl;
+    std::cout << "FIXME -- NOT DONE CORRECTLY " << std::endl;
+    std::cout << "FIXME -- NOT DONE CORRECTLY " << std::endl;
+    std::cout << " SUBSAM FIELD SUBSAM FIELD SUBSAM FIELD " << std::endl;
 
     typename DisplacementFieldType::Pointer sfield;
     for( unsigned int i = 0; i < ImageDimension; i++ )
@@ -486,16 +486,16 @@ public:
   {
     if( !movingpoints )
       {
-      ::ants::antscout << " NULL POINTS " << std::endl;  return NULL;
+      std::cout << " NULL POINTS " << std::endl;  return ITK_NULLPTR;
       }
 
-    AffineTransformPointer affinverse = NULL;
+    AffineTransformPointer affinverse = ITK_NULLPTR;
     if( aff )
       {
       affinverse = AffineTransformType::New();
       aff->GetInverse(affinverse);
       }
-    AffineTransformPointer fixedaffinverse = NULL;
+    AffineTransformPointer fixedaffinverse = ITK_NULLPTR;
     if( fixedaff )
       {
       fixedaffinverse = AffineTransformType::New();
@@ -556,13 +556,13 @@ public:
     totalField->SetDirection(referenceimage->GetDirection() );
 
     // warper->Update();
-//      ::ants::antscout << " updated in point warp " << std::endl;
+//      std::cout << " updated in point warp " << std::endl;
     PointSetPointer     outputMesh = PointSetType::New();
     unsigned long       count = 0;
     const unsigned long sz1 = movingpoints->GetNumberOfPoints();
     if( this->m_Debug )
       {
-      ::ants::antscout << " BEFORE #points " << sz1 << std::endl;
+      std::cout << " BEFORE #points " << sz1 << std::endl;
       }
     for( unsigned long ii = 0; ii < sz1; ii++ )
       {
@@ -593,16 +593,16 @@ public:
             }
           outputMesh->SetPointData( count, label );
           outputMesh->SetPoint( count, wpoint );
-//      if (ii % 100 == 0) ::ants::antscout << " pt " << pt << " wpt " << wpt << std::endl;
+//      if (ii % 100 == 0) std::cout << " pt " << pt << " wpt " << wpt << std::endl;
           count++;
           }
         }
       }
     if( this->m_Debug )
       {
-      ::ants::antscout << " AFTER #points " << count << std::endl;
+      std::cout << " AFTER #points " << count << std::endl;
       }
-//      if (count != sz1 ) ::ants::antscout << " WARNING:  POINTS ARE MAPPING OUT OF IMAGE DOMAIN " << 1.0 - (TReal)
+//      if (count != sz1 ) std::cout << " WARNING:  POINTS ARE MAPPING OUT OF IMAGE DOMAIN " << 1.0 - (TReal)
 // count/(TReal)(sz1+1) << std::endl;
     return outputMesh;
   }
@@ -615,13 +615,13 @@ public:
     DirectionType rdirection = referenceimage->GetDirection();
     DirectionType mdirection = movingImage->GetDirection();
 
-    AffineTransformPointer affinverse = NULL;
+    AffineTransformPointer affinverse = ITK_NULLPTR;
     if( aff )
       {
       affinverse = AffineTransformType::New();
       aff->GetInverse(affinverse);
       }
-    AffineTransformPointer fixedaffinverse = NULL;
+    AffineTransformPointer fixedaffinverse = ITK_NULLPTR;
     if( fixedaff )
       {
       fixedaffinverse = AffineTransformType::New();
@@ -703,7 +703,7 @@ public:
     warper->Update();
     if( this->m_Debug )
       {
-      ::ants::antscout << " updated ok -- warped image output size "
+      std::cout << " updated ok -- warped image output size "
                        << warper->GetOutput()->GetLargestPossibleRegion().GetSize() << " requested size "
                        <<  totalField->GetLargestPossibleRegion().GetSize() <<  std::endl;
       }
@@ -784,25 +784,25 @@ public:
   void SetTransformationModel( std::string  s)
   {
     this->m_TransformationModel = s;
-    ::ants::antscout << " Requested Transformation Model:  " << this->m_TransformationModel << " : Using " << std::endl;
+    std::cout << " Requested Transformation Model:  " << this->m_TransformationModel << " : Using " << std::endl;
     if( this->m_TransformationModel  == std::string("Elast") )
       {
-      ::ants::antscout << "Elastic model for transformation. " << std::endl;
+      std::cout << "Elastic model for transformation. " << std::endl;
       }
     else if( this->m_TransformationModel  == std::string("SyN") )
       {
-      ::ants::antscout << "SyN diffeomorphic model for transformation. " << std::endl;
+      std::cout << "SyN diffeomorphic model for transformation. " << std::endl;
       }
     else if( this->m_TransformationModel  == std::string("GreedyExp") )
       {
-      ::ants::antscout
+      std::cout
         << "Greedy Exp Diff model for transformation.   Similar to Diffeomorphic Demons.  Params same as Exp model. "
         << std::endl;
       this->m_TransformationModel = std::string("GreedyExp");
       }
     else
       {
-      ::ants::antscout << "Exp Diff model for transformation. " << std::endl;
+      std::cout << "Exp Diff model for transformation. " << std::endl;
       this->m_TransformationModel = std::string("Exp");
       }
   }
@@ -821,7 +821,7 @@ public:
       this->m_RestrictDeformation = this->m_Parser->template ConvertVector<TReal>( temp );
       if( this->m_RestrictDeformation.size() != ImageDimension )
         {
-        ::ants::antscout << " You input a vector of size :  "  << this->m_RestrictDeformation.size()
+        std::cout << " You input a vector of size :  "  << this->m_RestrictDeformation.size()
                          <<
           " for --Restrict-Deformation.  The vector length does not match the image dimension.  Ignoring.  "
                          << std::endl;
@@ -916,7 +916,7 @@ public:
         {
         this->m_DeltaTime = 0.001;
         }
-      ::ants::antscout << " set DT " << this->m_DeltaTime << std::endl;
+      std::cout << " set DT " << this->m_DeltaTime << std::endl;
       this->m_SyNType = 1;
       }
     else
@@ -969,7 +969,7 @@ public:
         {
         this->m_GaussianTruncation = 256;
         }
-      ::ants::antscout << "  Grad Step " << this->m_Gradstep << " total-smoothing " << this->m_TotalSmoothingparam
+      std::cout << "  Grad Step " << this->m_Gradstep << " total-smoothing " << this->m_TotalSmoothingparam
                        << " gradient-smoothing " << this->m_GradSmoothingparam << std::endl;
       }
     else if( ( regularizationOption->GetFunction( 0 )->GetName() ).find( "DMFFD" )
@@ -1029,7 +1029,7 @@ public:
         {
         this->m_BSplineFieldOrder = 3;
         }
-      ::ants::antscout << "  Grad Step " << this->m_Gradstep
+      std::cout << "  Grad Step " << this->m_Gradstep
                        << " total-smoothing " << this->m_TotalSmoothingparam
                        << " gradient-smoothing " << this->m_GradSmoothingparam
                        << " bspline-field-order " << this->m_BSplineFieldOrder
@@ -1039,7 +1039,7 @@ public:
       {
       this->m_GradSmoothingparam = 3;
       this->m_TotalSmoothingparam = 0.5;
-      ::ants::antscout << " Default Regularization is Gaussian smoothing with : " << this->m_GradSmoothingparam
+      std::cout << " Default Regularization is Gaussian smoothing with : " << this->m_GradSmoothingparam
                        << " & "
                        << this->m_TotalSmoothingparam << std::endl;
 //      itkExceptionMacro( "Invalid regularization: " << regularizationOption->GetFunction( 0 )->GetName() );
@@ -1068,7 +1068,7 @@ public:
           (typename ImageType::SizeType::SizeValueType) this->m_RoiNumbers[ii + ImageDimension];
         this->m_FullDomainOrigin[ii] = this->m_RoiNumbers[ii];
         }
-      ::ants::antscout << " ROI #s : size " << this->m_FullDomainSize << " orig " <<   this->m_FullDomainOrigin
+      std::cout << " ROI #s : size " << this->m_FullDomainSize << " orig " <<   this->m_FullDomainOrigin
                        << std::endl;
       }
 
@@ -1104,7 +1104,7 @@ public:
 //            this->m_Debug=true;
     if( this->m_Debug )
       {
-      ::ants::antscout << " outsize " << this->m_CurrentDomainSize <<  " curspc " << this->m_CurrentDomainSpacing
+      std::cout << " outsize " << this->m_CurrentDomainSize <<  " curspc " << this->m_CurrentDomainSpacing
                        << " fullspc " << this->m_FullDomainSpacing << " fullsz " <<  this->m_FullDomainSize
                        << std::endl;
       }
@@ -1120,7 +1120,7 @@ public:
                                           fixedImage->GetOrigin(),
                                           fixedImage->GetDirection(),
                                           zero);
-      ::ants::antscout <<  " allocated def field " << this->m_DisplacementField->GetDirection() << std::endl;
+      std::cout <<  " allocated def field " << this->m_DisplacementField->GetDirection() << std::endl;
       // std::exception();
       }
     else
@@ -1160,13 +1160,13 @@ public:
 
   void DeformableOptimization()
   {
-    DisplacementFieldPointer updateField = NULL;
+    DisplacementFieldPointer updateField = ITK_NULLPTR;
 
     this->SetUpParameters();
     typename ImageType::SpacingType spacing;
     VectorType zero;
     zero.Fill(0);
-    ::ants::antscout << " setting N-TimeSteps = "
+    std::cout << " setting N-TimeSteps = "
                      << this->m_NTimeSteps << " trunc " << this->m_GaussianTruncation << std::endl;
 
     // Get subsample factors and gaussian smoothing sigmas if specified
@@ -1226,8 +1226,8 @@ public:
       }
     if( maxits == 0 )
       {
-      this->m_DisplacementField = NULL;
-      this->m_InverseDisplacementField = NULL;
+      this->m_DisplacementField = ITK_NULLPTR;
+      this->m_InverseDisplacementField = ITK_NULLPTR;
       //    this->ComputeMultiResolutionParameters(this->m_SimilarityMetrics[0]->GetFixedImage());
       return;
       }
@@ -1264,8 +1264,8 @@ public:
           }
         }
       }
-    this->m_SmoothFixedImages.resize(numberOfMetrics, NULL);
-    this->m_SmoothMovingImages.resize(numberOfMetrics, NULL);
+    this->m_SmoothFixedImages.resize(numberOfMetrics, ITK_NULLPTR);
+    this->m_SmoothMovingImages.resize(numberOfMetrics, ITK_NULLPTR);
     for( unsigned int currentLevel = 0; currentLevel < this->m_NumberOfLevels; currentLevel++ )
       {
       this->m_CurrentLevel = currentLevel;
@@ -1294,12 +1294,12 @@ public:
         {
         this->m_ScaleFactor = this->m_SubsamplingFactors[currentLevel];
         }
-      ::ants::antscout << " ScaleFactor " << this->m_ScaleFactor;
+      std::cout << " ScaleFactor " << this->m_ScaleFactor;
       if( this->m_GaussianSmoothingSigmas.size() > 0 )
         {
-        ::ants::antscout << " smoothing sigma " << this->m_GaussianSmoothingSigmas[currentLevel];
+        std::cout << " smoothing sigma " << this->m_GaussianSmoothingSigmas[currentLevel];
         }
-      ::ants::antscout << " nlev " << this->m_NumberOfLevels << " curl " << currentLevel << std::endl;
+      std::cout << " nlev " << this->m_NumberOfLevels << " curl " << currentLevel << std::endl;
 
       /** FIXME -- here we assume the metrics all have the same image */
       fixedImage = this->m_SimilarityMetrics[0]->GetFixedImage();
@@ -1309,7 +1309,7 @@ public:
         this->m_ReferenceSpaceImage = fixedImage;
         }
       this->ComputeMultiResolutionParameters(this->m_ReferenceSpaceImage);
-      ::ants::antscout << " Its at this level " << this->m_Iterations[currentLevel] << std::endl;
+      std::cout << " Its at this level " << this->m_Iterations[currentLevel] << std::endl;
       /*  generate smoothed images for all metrics */
       for( unsigned int metricCount = 0;  metricCount < numberOfMetrics;  metricCount++ )
         {
@@ -1342,7 +1342,7 @@ public:
 
       if( this->GetTransformationModel() != std::string("SyN") )
         {
-        this->m_FixedImageAffineTransform = NULL;
+        this->m_FixedImageAffineTransform = ITK_NULLPTR;
         }
       while( !converged )
         {
@@ -1497,7 +1497,7 @@ public:
             energyProfileWindow->SetPoint( qq - windowBegin, point );
             energyProfileWindow->SetPointData( qq - windowBegin, energy );
             }
-//      ::ants::antscout <<" totale " << totale << std::endl;
+//      std::cout <<" totale " << totale << std::endl;
           if( totale > 0 )
             {
             totale *= (-1.0);
@@ -1554,16 +1554,16 @@ public:
             {
             converged = true;
             }
-          ::ants::antscout << " E-Slope " <<  this->m_ESlope; // << std::endl;
+          std::cout << " E-Slope " <<  this->m_ESlope; // << std::endl;
           }
         for( unsigned int qq = 0; qq < this->m_Energy.size(); qq++ )
           {
           if( qq == 0 )
             {
-            ::ants::antscout << " iteration " << this->m_CurrentIteration;
+            std::cout << " iteration " << this->m_CurrentIteration;
             }
 
-          ::ants::antscout << " energy " << qq << " : " << this->m_Energy[qq]; //  << " Last " <<
+          std::cout << " energy " << qq << " : " << this->m_Energy[qq]; //  << " Last " <<
                                                                                // this->m_LastEnergy[qq];
           if( this->m_LastEnergy[qq] < this->m_Energy[qq] )
             {
@@ -1581,10 +1581,10 @@ public:
         // if ( this->m_EnergyBad[0] > 2)
         //         {
         //          this->m_GradstepAltered*=0.8;
-        //        ::ants::antscout <<" reducing gradstep " <<  this->m_GradstepAltered;
+        //        std::cout <<" reducing gradstep " <<  this->m_GradstepAltered;
         // this->m_EnergyBad[this->m_Energy.size()-1]=0;
         // }
-        ::ants::antscout << std::endl;
+        std::cout << std::endl;
 
         if( this->m_CurrentIteration >= this->m_Iterations[currentLevel] )
           {
@@ -1594,16 +1594,16 @@ public:
         //
         if( converged && this->m_CurrentIteration >= this->m_Iterations[currentLevel] )
           {
-          ::ants::antscout << " tired convergence: reached max iterations " << std::endl;
+          std::cout << " tired convergence: reached max iterations " << std::endl;
           }
         else if( converged )
           {
-          ::ants::antscout << " Converged due to oscillation in optimization ";
+          std::cout << " Converged due to oscillation in optimization ";
           for( unsigned int qq = 0; qq < this->m_Energy.size(); qq++ )
             {
-            ::ants::antscout << " metric " << qq << " bad " << this->m_EnergyBad[qq] << "  ";
+            std::cout << " metric " << qq << " bad " << this->m_EnergyBad[qq] << "  ";
             }
-          ::ants::antscout << std::endl;
+          std::cout << std::endl;
           }
         }
       }
@@ -1648,38 +1648,38 @@ public:
       // -1.0/(TReal)this->m_NTimeSteps);
       this->m_InverseDisplacementField = invdiffmap;
       this->m_DisplacementField = diffmap;
-      AffineTransformPointer invaff = NULL;
+      AffineTransformPointer invaff = ITK_NULLPTR;
       if( this->m_AffineTransform )
         {
         invaff = AffineTransformType::New();
         this->m_AffineTransform->GetInverse(invaff);
         if( this->m_Debug )
           {
-          ::ants::antscout << " ??????invaff " << this->m_AffineTransform << std::endl << std::endl;
+          std::cout << " ??????invaff " << this->m_AffineTransform << std::endl << std::endl;
           }
         if( this->m_Debug )
           {
-          ::ants::antscout << " invaff?????? " << invaff << std::endl << std::endl;
+          std::cout << " invaff?????? " << invaff << std::endl << std::endl;
           }
         }
       }
     else if( this->GetTransformationModel() == std::string("GreedyExp") )
       {
       DisplacementFieldPointer diffmap = this->m_DisplacementField;
-      this->m_InverseDisplacementField = NULL;
+      this->m_InverseDisplacementField = ITK_NULLPTR;
       this->m_DisplacementField = diffmap;
-      AffineTransformPointer invaff = NULL;
+      AffineTransformPointer invaff = ITK_NULLPTR;
       if( this->m_AffineTransform )
         {
         invaff = AffineTransformType::New();
         this->m_AffineTransform->GetInverse(invaff);
         if( this->m_Debug )
           {
-          ::ants::antscout << " ??????invaff " << this->m_AffineTransform << std::endl << std::endl;
+          std::cout << " ??????invaff " << this->m_AffineTransform << std::endl << std::endl;
           }
         if( this->m_Debug )
           {
-          ::ants::antscout << " invaff?????? " << invaff << std::endl << std::endl;
+          std::cout << " invaff?????? " << invaff << std::endl << std::endl;
           }
         }
       }
@@ -1702,7 +1702,7 @@ public:
       writer->SetInput( this->m_TimeVaryingVelocity);
       writer->UpdateLargestPossibleRegion();
       //    writer->Write();
-      ::ants::antscout << " write tv field " << outname << std::endl;
+      std::cout << " write tv field " << outname << std::endl;
       //        WriteImage<TimeVaryingVelocityFieldType>( this->m_TimeVaryingVelocity , outname.c_str());
       }
   }
@@ -1743,7 +1743,7 @@ public:
     zero.Fill(0);
     DisplacementFieldPointer updateField;
 
-    updateField = this->ComputeUpdateField(this->m_DisplacementField, NULL, NULL, NULL, NULL);
+    updateField = this->ComputeUpdateField(this->m_DisplacementField, ITK_NULLPTR, ITK_NULLPTR, ITK_NULLPTR, ITK_NULLPTR);
 
     typedef ImageRegionIteratorWithIndex<DisplacementFieldType> Iterator;
     Iterator dIter(this->m_DisplacementField, this->m_DisplacementField->GetLargestPossibleRegion() );
@@ -1756,8 +1756,8 @@ public:
 
     if( this->m_Debug )
       {
-      ::ants::antscout << " updated elast " << " up-sz " << updateField->GetLargestPossibleRegion() <<  std::endl;
-      ::ants::antscout <<  " t-sz " << this->m_DisplacementField->GetLargestPossibleRegion() <<  std::endl;
+      std::cout << " updated elast " << " up-sz " << updateField->GetLargestPossibleRegion() <<  std::endl;
+      std::cout <<  " t-sz " << this->m_DisplacementField->GetLargestPossibleRegion() <<  std::endl;
       }
     this->SmoothDisplacementField(this->m_DisplacementField, false);
 
@@ -1768,8 +1768,6 @@ public:
   {
     typedef WarpImageFilter<ImageType, ImageType, DisplacementFieldType> WarperType;
     typename WarperType::Pointer  warper = WarperType::New();
-    typedef NearestNeighborInterpolateImageFunction<ImageType, TReal>
-      InterpolatorType;
     warper->SetInput(image);
     warper->SetDisplacementField( field );
     warper->SetEdgePaddingValue( 0);
@@ -1823,7 +1821,6 @@ public:
 
     typedef typename DisplacementFieldType::PixelType           DispVectorType;
     typedef typename DisplacementFieldType::IndexType           DispIndexType;
-    typedef typename DispVectorType::ValueType                  ScalarType;
     typedef ImageRegionIteratorWithIndex<DisplacementFieldType> Iterator;
 
     DisplacementFieldPointer lagrangianInitCond =
@@ -1941,7 +1938,7 @@ public:
       ct++;
       }
 
-    // ::ants::antscout <<" difmag " << difmag << ": its " << ct <<  std::endl;
+    // std::cout <<" difmag " << difmag << ": its " << ct <<  std::endl;
 
     return difmag;
   }
@@ -1991,7 +1988,7 @@ protected:
         }
       cornerind[ii] = (unsigned long) diff;
       }
-    //  ::ants::antscout << " corner index " << cornerind << std::endl;
+    //  std::cout << " corner index " << cornerind << std::endl;
     Iterator vfIter2( bigimage,  bigimage->GetLargestPossibleRegion() );
     for(  vfIter2.GoToBegin(); !vfIter2.IsAtEnd(); ++vfIter2 )
       {
@@ -2010,12 +2007,12 @@ protected:
         }
       if( oktosample )
         {
-        //      ::ants::antscout << " index " << index <<  " origindex " << origindex << " ok? " << oktosample <<
+        //      std::cout << " index " << index <<  " origindex " << origindex << " ok? " << oktosample <<
         // std::endl;
         varimage->SetPixel(_index, bigimage->GetPixel(origindex) );
         }
       }
-    // ::ants::antscout << " sizes " << varimage->GetLargestPossibleRegion().GetSize() << " bigimage " <<
+    // std::cout << " sizes " << varimage->GetLargestPossibleRegion().GetSize() << " bigimage " <<
     // bigimage->GetLargestPossibleRegion().GetSize() << std::endl;
     return varimage;
   }
@@ -2025,7 +2022,6 @@ protected:
     typedef typename DisplacementFieldType::PixelType           DispVectorType;
     typedef typename DisplacementFieldType::IndexType           DispIndexType;
     typedef typename DisplacementFieldType::SizeType            SizeType;
-    typedef typename DispVectorType::ValueType                  ScalarType;
     typedef ImageRegionIteratorWithIndex<DisplacementFieldType> Iterator;
     // all we have to do here is add the local field to the global field.
     Iterator      vfIter( field,  field->GetLargestPossibleRegion() );
@@ -2078,7 +2074,7 @@ protected:
     // this->m_EuclideanNorm/=ct;
     // this->m_ElasticPathLength = totalmag/ct;
     // this->m_LinftyNorm = maxstep;
-//  ::ants::antscout << " Elast path length " << this->m_ElasticPathLength <<  " L inf norm " << this->m_LinftyNorm <<
+//  std::cout << " Elast path length " << this->m_ElasticPathLength <<  " L inf norm " << this->m_LinftyNorm <<
 // std::endl;
 // if (this->m_ElasticPathLength >= this->m_ArcLengthGoal)
 //  if (maxstep >= this->m_ArcLengthGoal)
@@ -2103,7 +2099,7 @@ protected:
   {
   }
 
-  void PrintSelf( std::ostream& os, Indent indent ) const;
+  void PrintSelf( std::ostream& os, Indent indent ) const ITK_OVERRIDE;
 
 private:
   ANTSImageRegistrationOptimizer( const Self & ); // purposely not implemented
