@@ -196,14 +196,14 @@ public:
   }
 
   /** This class uses a constant timestep of 1. */
-  virtual TimeStepType ComputeGlobalTimeStep(void *itkNotUsed(GlobalData) ) const
+  virtual TimeStepType ComputeGlobalTimeStep(void *itkNotUsed(GlobalData) ) const ITK_OVERRIDE
   {
     return 1;
   }
 
   /** Return a pointer to a global data structure that is passed to
    * this object from the solver at each calculation.  */
-  virtual void * GetGlobalDataPointer() const
+  virtual void * GetGlobalDataPointer() const ITK_OVERRIDE
   {
     GlobalDataStruct *global = new GlobalDataStruct();
 
@@ -214,13 +214,13 @@ public:
   }
 
   /** Release memory for global data structure. */
-  virtual void ReleaseGlobalDataPointer( void *GlobalData ) const
+  virtual void ReleaseGlobalDataPointer( void *GlobalData ) const ITK_OVERRIDE
   {
     delete (GlobalDataStruct *) GlobalData;
   }
 
   /** Set the object's state before each iteration. */
-  virtual void InitializeIteration();
+  virtual void InitializeIteration() ITK_OVERRIDE;
 
   typedef double CoordinateRepresentationType;
 
@@ -488,7 +488,7 @@ public:
 
         mival += mi;
         }
-      //      ::ants::antscout << " II " << ii << " JJ " << ii << " pxy " << pxy << " px " << px << std::endl;
+      //      std::cout << " II " << ii << " JJ " << ii << " pxy " << pxy << " px " << px << std::endl;
       }
     // GS: temp edit to make sure if this is decreasing (should be )
     // this->m_Energy = -1.0*mival/vcl_log((double)2.0);
@@ -498,7 +498,7 @@ public:
 
   virtual VectorType ComputeUpdateInv(const NeighborhoodType & neighborhood,
                                       void * /* globalData */,
-                                      const FloatOffsetType & /* offset */ = FloatOffsetType(0.0) )
+                                      const FloatOffsetType & /* offset */ = FloatOffsetType(0.0) ) ITK_OVERRIDE
   {
     VectorType update;
 
@@ -529,7 +529,7 @@ public:
     fixedGradient = m_FixedImageGradientCalculator->EvaluateAtIndex( oindex );
     double nccm1 = 0;
     const double loce = this->GetValueAndDerivative(oindex, nccm1, fdvec1, fdvec2);
-    //    if ( loce > 1.5 ) ::ants::antscout << " loce " << loce << " ind " << oindex << std::endl;
+    //    if ( loce > 1.5 ) std::cout << " loce " << loce << " ind " << oindex << std::endl;
     for( int imd = 0; imd < ImageDimension; imd++ )
       {
       update[imd] = loce * fixedGradient[imd] * spacing[imd] * (1);
@@ -588,7 +588,7 @@ public:
 
   virtual VectorType ComputeUpdate(const NeighborhoodType & neighborhood,
                                    void * /* globalData */,
-                                   const FloatOffsetType & /* offset */ = FloatOffsetType(0.0) )
+                                   const FloatOffsetType & /* offset */ = FloatOffsetType(0.0) ) ITK_OVERRIDE
   {
     VectorType update;
 
@@ -693,7 +693,7 @@ protected:
   virtual ~AvantsMutualInformationRegistrationFunction()
   {
   };
-  void PrintSelf(std::ostream& os, Indent indent) const;
+  void PrintSelf(std::ostream& os, Indent indent) const ITK_OVERRIDE;
 
 private:
 
