@@ -47,7 +47,7 @@ SpatialMutualInformationRegistrationFunction<TFixedImage, TMovingImage, TDisplac
   this->m_InterpolatorIsBSpline = false;
 
   // Initialize PDFs to NULL
-  m_JointPDF = NULL;
+  m_JointPDF = ITK_NULLPTR;
 
   m_OpticalFlow = false;
   typename TransformType::Pointer transformer = TransformType::New();
@@ -56,8 +56,8 @@ SpatialMutualInformationRegistrationFunction<TFixedImage, TMovingImage, TDisplac
   typename BSplineInterpolatorType::Pointer interpolator = BSplineInterpolatorType::New();
   this->SetInterpolator(interpolator);
 
-  m_FixedImageMask = NULL;
-  m_MovingImageMask = NULL;
+  m_FixedImageMask = ITK_NULLPTR;
+  m_MovingImageMask = ITK_NULLPTR;
 
   // Initialize memory
   m_MovingImageNormalizedMin = 0.0;
@@ -66,7 +66,7 @@ SpatialMutualInformationRegistrationFunction<TFixedImage, TMovingImage, TDisplac
   m_MovingImageTrueMax = 0.0;
   m_FixedImageBinSize = 0.0;
   m_MovingImageBinSize = 0.0;
-  m_BSplineInterpolator = NULL;
+  m_BSplineInterpolator = ITK_NULLPTR;
   m_NumberOfParameters = ImageDimension;
 
   m_FixedImageGradientCalculator = GradientCalculatorType::New();
@@ -144,10 +144,9 @@ SpatialMutualInformationRegistrationFunction<TFixedImage, TMovingImage, TDisplac
   pdfinterpolator3 = pdfintType2::New();
 
 //  this->ComputeMetricImage();
-//  ::ants::antscout << " A " << std::endl;
+//  std::cout << " A " << std::endl;
 //    bool makenewimage=false;
-  typedef ImageRegionIteratorWithIndex<TFixedImage> ittype;
-//  ::ants::antscout << " B " << std::endl;
+//  std::cout << " B " << std::endl;
 
   /*
   if (!this->m_MetricImage )makenewimage=true;
@@ -283,9 +282,9 @@ SpatialMutualInformationRegistrationFunction<TFixedImage, TMovingImage, TDisplac
   m_FixedImageMarginalPDF->SetSpacing(mPDFspacing);
   m_MovingImageMarginalPDF = AllocImage<MarginalPDFType>( mPDFRegion );
   m_MovingImageMarginalPDF->SetSpacing(mPDFspacing);
-  // ::ants::antscout << " C " << std::endl;
+  // std::cout << " C " << std::endl;
 
-  // ::ants::antscout << " D " << std::endl;
+  // std::cout << " D " << std::endl;
 
   // Instantiate a region, index, size
   JointPDFRegionType jointPDFRegion;
@@ -334,7 +333,7 @@ SpatialMutualInformationRegistrationFunction<TFixedImage, TMovingImage, TDisplac
   this->m_JointPDFXuYr = AllocImage<JointPDFType>( jointPDFRegion );
   this->m_JointPDFXuYr->SetSpacing(jspacing);
 
-//    ::ants::antscout << " E " << std::endl;
+//    std::cout << " E " << std::endl;
 
   m_NormalizeMetric = 1.0;
   for( int i = 0; i < ImageDimension; i++ )
@@ -342,7 +341,7 @@ SpatialMutualInformationRegistrationFunction<TFixedImage, TMovingImage, TDisplac
     m_NormalizeMetric *= this->m_FixedImage->GetLargestPossibleRegion().GetSize()[i];
     }
 
-//  ::ants::antscout << " F " << std::endl;
+//  std::cout << " F " << std::endl;
   pdfinterpolator->SetInputImage(m_JointPDF);
   pdfinterpolator->SetSplineOrder(3);
   this->pdfinterpolatorXuY->SetInputImage(this->m_JointPDFXuY);
@@ -366,12 +365,12 @@ SpatialMutualInformationRegistrationFunction<TFixedImage, TMovingImage, TDisplac
   pdfinterpolator2->SetSplineOrder(3);
   pdfinterpolator3->SetSplineOrder(3);
 
-//  ::ants::antscout << " Ga " << std::endl;
+//  std::cout << " Ga " << std::endl;
 
   this->GetProbabilities();
-//  ::ants::antscout << " G " << std::endl;
+//  std::cout << " G " << std::endl;
   this->ComputeSpatialMutualInformation();
-  // ::ants::antscout << " H " << std::endl;
+  // std::cout << " H " << std::endl;
 }
 
 /**
@@ -436,7 +435,7 @@ SpatialMutualInformationRegistrationFunction<TFixedImage, TMovingImage, TDisplac
           }
         }
 
-//            ::ants::antscout << " Image size? " << imagesize << std::endl;
+//            std::cout << " Image size? " << imagesize << std::endl;
 
       if( inimage )
         {
@@ -539,7 +538,7 @@ SpatialMutualInformationRegistrationFunction<TFixedImage, TMovingImage, TDisplac
         }
       }
     }
-//    ::ants::antscout << " Image Rotation Number " << nSamples << std::endl;
+//    std::cout << " Image Rotation Number " << nSamples << std::endl;
 
   /**
    * Normalize the PDFs, compute moving image marginal PDF
@@ -567,7 +566,7 @@ SpatialMutualInformationRegistrationFunction<TFixedImage, TMovingImage, TDisplac
     ++jointPDFIterator;
     }
 
-//    ::ants::antscout << " Joint PDF Summation? " << jointPDFSum << std::endl;
+//    std::cout << " Joint PDF Summation? " << jointPDFSum << std::endl;
 
   // of derivatives
   if( jointPDFSum == 0.0 )
