@@ -195,14 +195,14 @@ public:
   }
 
   /** This class uses a constant timestep of 1. */
-  virtual TimeStepType ComputeGlobalTimeStep(void *itkNotUsed(GlobalData) ) const
+  virtual TimeStepType ComputeGlobalTimeStep(void *itkNotUsed(GlobalData) ) const ITK_OVERRIDE
   {
     return 1;
   }
 
   /** Return a pointer to a global data structure that is passed to
    * this object from the solver at each calculation.  */
-  virtual void * GetGlobalDataPointer() const
+  virtual void * GetGlobalDataPointer() const ITK_OVERRIDE
   {
     GlobalDataStruct *global = new GlobalDataStruct();
 
@@ -213,13 +213,13 @@ public:
   }
 
   /** Release memory for global data structure. */
-  virtual void ReleaseGlobalDataPointer( void *GlobalData ) const
+  virtual void ReleaseGlobalDataPointer( void *GlobalData ) const ITK_OVERRIDE
   {
     delete (GlobalDataStruct *) GlobalData;
   }
 
   /** Set the object's state before each iteration. */
-  virtual void InitializeIteration();
+  virtual void InitializeIteration() ITK_OVERRIDE;
 
   typedef double CoordinateRepresentationType;
 
@@ -362,7 +362,7 @@ public:
 
         mival += mi;
         }
-      //      ::ants::antscout << " II " << ii << " JJ " << ii << " pxy " << pxy << " px " << px << std::endl;
+      //      std::cout << " II " << ii << " JJ " << ii << " pxy " << pxy << " px " << px << std::endl;
       }
     this->m_Energy = (-1.0) * mival / log(2);
     return this->m_Energy;
@@ -447,7 +447,7 @@ public:
     SMI = (0.5) * (JointEntropyXuY + JointEntropyXYu + JointEntropyXlY + JointEntropyXYl)
       - (0.25) * (4 * JointEntropy + JointEntropyXuYr + JointEntropyXrYu + JointEntropyXlYu + JointEntropyXuYl);
 
-    //    ::ants::antscout << " JE " << JointEntropy << " JEXuY " << JointEntropyXuY << " JEXYu " << JointEntropyXYu <<
+    //    std::cout << " JE " << JointEntropy << " JEXuY " << JointEntropyXuY << " JEXYu " << JointEntropyXYu <<
     // "
     // JEXuYr " << JointEntropyXuYr << std::endl;
 
@@ -457,7 +457,7 @@ public:
 
   virtual VectorType ComputeUpdateInv(const NeighborhoodType & neighborhood,
                                       void * /* globalData */,
-                                      const FloatOffsetType & /* offset */ = FloatOffsetType(0.0) )
+                                      const FloatOffsetType & /* offset */ = FloatOffsetType(0.0) ) ITK_OVERRIDE
   {
     VectorType update;
 
@@ -554,7 +554,7 @@ public:
 
   virtual VectorType ComputeUpdate(const NeighborhoodType & neighborhood,
                                    void * /* globalData */,
-                                   const FloatOffsetType & /* offset */ = FloatOffsetType(0.0) )
+                                   const FloatOffsetType & /* offset */ = FloatOffsetType(0.0) ) ITK_OVERRIDE
   {
     VectorType update;
 
@@ -673,7 +673,7 @@ protected:
   virtual ~SpatialMutualInformationRegistrationFunction()
   {
   };
-  void PrintSelf(std::ostream& os, Indent indent) const;
+  void PrintSelf(std::ostream& os, Indent indent) const ITK_OVERRIDE;
 
 private:
 
