@@ -133,6 +133,7 @@ public:
   /** Randomizer typedefs */
   typedef itk::Statistics::
     MersenneTwisterRandomVariateGenerator             RandomizerType;
+  typedef RandomizerType::IntegerType                 RandomizerSeedType;
 
   /** B-spline fitting typedefs */
   typedef Vector<RealType, 1>                  ScalarType;
@@ -336,6 +337,18 @@ public:
    */
   itkGetConstMacro( AnnealingRate, RealType );
 
+  /**
+   * Set initialization unsigned integer for random number generator.  Default is to
+   * initialize randomly using the system clock.
+   */
+  void SetRandomizerInitializationSeed( const RandomizerSeedType );
+
+  /**
+   * Set initialization unsigned integer for random number generator.  Default is to
+   * initialize randomly using the system clock.
+   */
+  itkGetConstMacro( RandomizerInitializationSeed, RandomizerSeedType );
+
   /**
    * Set the initialization strategy.  Initialization can occur without prior
    * information using kmeans or otsu thresholding or with prior information
@@ -461,8 +474,8 @@ public:
    */
   void SetAdaptiveSmoothingWeight( unsigned int idx, RealType weight )
   {
-    RealType clampedWeight = vnl_math_min( NumericTraits<RealType>::One,
-                                           vnl_math_max( NumericTraits<RealType>::Zero, weight ) );
+    RealType clampedWeight = vnl_math_min( NumericTraits<RealType>::OneValue(),
+                                           vnl_math_max( NumericTraits<RealType>::ZeroValue(), weight ) );
 
     if( idx >= this->m_AdaptiveSmoothingWeights.size() )
       {
@@ -652,7 +665,7 @@ public:
       }
     else
       {
-      return NULL;
+      return ITK_NULLPTR;
       }
   }
 
@@ -742,9 +755,9 @@ protected:
   AtroposSegmentationImageFilter();
   ~AtroposSegmentationImageFilter();
 
-  void PrintSelf( std::ostream& os, Indent indent ) const;
+  void PrintSelf( std::ostream& os, Indent indent ) const ITK_OVERRIDE;
 
-  void GenerateData();
+  void GenerateData() ITK_OVERRIDE;
 
 private:
   AtroposSegmentationImageFilter( const Self & ); // purposely not implemented
@@ -842,6 +855,7 @@ private:
   ClassifiedImagePointer m_ICMCodeImage;
   bool                   m_UseAsynchronousUpdating;
   unsigned int           m_MaximumNumberOfICMIterations;
+  RandomizerSeedType     m_RandomizerInitializationSeed;
 
   std::vector<RealType>           m_AdaptiveSmoothingWeights;
   RealType                        m_PriorProbabilityWeight;
