@@ -1,6 +1,6 @@
 #!/bin/bash
 
-VERSION="0.0.15 test"
+VERSION="0.0.0"
 
 # trap keyboard interrupt (control-c)
 trap control_c SIGINT
@@ -28,41 +28,34 @@ SETPATH
 # Uncomment the line below in case you have not set the ANTSPATH variable in your environment.
 # export ANTSPATH=${ANTSPATH:="$HOME/bin/ants/"} # EDIT THIS
 
-#ANTSPATH=YOURANTSPATH
 if [[ ${#ANTSPATH} -le 3 ]];
-    then
+  then
     setPath >&2
-fi
-
-if [[ ! -s ${ANTSPATH}/ANTS ]];
-    then
-    echo "ANTS program can't be found. Please (re)define \$ANTSPATH in your environment."
-    exit
-fi
+  fi
 
 # Test availability of helper scripts.
 # No need to test this more than once. Can reside outside of the main loop.
-ANTS=${ANTSPATH}ANTS
+ANTS=${ANTSPATH}/ANTS
 WARP=${ANTSPATH}/WarpImageMultiTransform
-N4=${ANTSPATH}N4BiasFieldCorrection
-PEXEC=${ANTSPATH}ANTSpexec.sh
-SGE=${ANTSPATH}waitForSGEQJobs.pl
-PBS=${ANTSPATH}waitForPBSQJobs.pl
-XGRID=${ANTSPATH}waitForXGridJobs.pl
+N4=${ANTSPATH}/N4BiasFieldCorrection
+PEXEC=${ANTSPATH}/ANTSpexec.sh
+SGE=${ANTSPATH}/waitForSGEQJobs.pl
+PBS=${ANTSPATH}/waitForPBSQJobs.pl
+XGRID=${ANTSPATH}/waitForXGridJobs.pl
 
 fle_error=0
-for FLE in $N4 $PEXEC $SGE $XGRID $PBS
+for FLE in $ANTS $WARP $N4 $PEXEC $SGE $XGRID $PBS
   do
-  if [[ ! -x $FLE ]];
+    if [[ ! -x $FLE ]];
       then
-      echo
-      echo "--------------------------------------------------------------------------------------"
-      echo " FILE $FLE DOES NOT EXIST -- OR -- IS NOT EXECUTABLE !!! $0 will terminate."
-      echo "--------------------------------------------------------------------------------------"
-      echo " if the file is not executable, please change its permissions. "
-      fle_error=1
-  fi
-done
+        echo
+        echo "--------------------------------------------------------------------------------------"
+        echo " FILE $FLE DOES NOT EXIST -- OR -- IS NOT EXECUTABLE !!! $0 will terminate."
+        echo "--------------------------------------------------------------------------------------"
+        echo " if the file is not executable, please change its permissions. "
+        fle_error=1
+      fi
+  done
 
 if [[ $fle_error = 1 ]];
     then
@@ -70,9 +63,6 @@ if [[ $fle_error = 1 ]];
     exit 1
 fi
 
-
-#assuming .nii.gz as default file type. This is the case for ANTS 1.7 and up
-
 function Usage {
     cat <<USAGE
 
@@ -83,7 +73,7 @@ Usage:
 Compulsory arguments (minimal command line requires SGE cluster, otherwise use -c & -j options):
 
      -d:  ImageDimension: 2 or 3 (for 2 or 3 dimensional registration of single volume)
-	  ImageDimension: 4 (for template generation of time-series data)
+   ImageDimension: 4 (for template generation of time-series data)
 
      -o:  OUTPREFIX; A prefix that is prepended to all output files.
 
@@ -100,7 +90,7 @@ should be invoked from that directory.
 Optional arguments:
 
      -c:  Control for parallel computation (default 1) -- 0 == run serially,  1 == SGE qsub,
-	         2 == use PEXEC (localhost), 3 == Apple XGrid, 4 == PBS qsub
+          2 == use PEXEC (localhost), 3 == Apple XGrid, 4 == PBS qsub
 
      -g:  Gradient step size (default 0.25) -- smaller in magnitude results in more cautious steps
 
@@ -127,6 +117,10 @@ Optional arguments:
 
      -x:  XGrid arguments (e.g., -x "-p password -h controlhost")
 
+     -y:  Update the template with the full affine transform (default 1). If 0, the rigid
+          component of the affine transform will not be used to update the template. If your
+          template drifts in translation or orientation try -y 0.
+
      -z:  Use this this volume as the target of all inputs. When not used, the script
           will create an unbiased starting point by averaging all inputs. Use the full path!
 
@@ -170,173 +164,6 @@ USAGE
     exit 1
 }
 
-function Help {
-    cat <<HELP
-
-`basename $0` will make a template out of the input files using an elastic
-or diffeomorphic transformation. This script builds a template iteratively from the input
-images and uses Sun Grid Engine (SGE) or multiple cpu cores on the localhost (min 2) to
-parallelize the registration of each subject to the template.
-
-Usage:
-
-`basename $0` -d ImageDimension -o OUTPREFIX <other options> <images>
-
-Example Case:
-
- bash `basename $0` -d 3 -m 30x50x20 -t GR  -s CC -c 1 -o MY -z InitialTemplate.nii.gz  *RF*T1x.nii.gz
-
- - In this case you use 30x50x20 iterations per registration
- - 4 iterations over template creation (that is the default)
- - With Greedy-SyN and CC metrics to guide the mapping.
- - Output is prepended with MY and the initial template is InitialTemplate.nii.gz (optional).
- - The -c option is set to 1 which will try to use SGE to distribute the computation.
- - If you do not have SGE, use -c 0 or -c 2 combined with -j.
-
- - Continue reading this help file if things are not yet clear.
-
-Compulsory arguments (minimal command line requires SGE cluster, otherwise use -c & -j options):
-
-     -d:  ImageDimension: 2 or 3 (for 2 or 3 dimensional registration of single volume)
-	  ImageDimension: 4 (for template generation of time-series data)
-
-     -o:  OUTPREFIX; A prefix that is prepended to all output files.
-
-<images>  List of images in the current directory, eg *_t1.nii.gz. Should be at the end
-          of the command.  Optionally, one can specify a .csv or .txt file where each
-          line is the location of the input image.  One can also specify more than
-          one file for each image for multi-modal template construction (e.g. t1 and t2).
-          For the multi-modal case, the templates will be consecutively numbered (e.g.
-          ${OUTPUTPREFIX}template0.nii.gz, ${OUTPUTPREFIX}template1.nii.gz, ...).
-
-NB: All files to be added to the template should be in the same directory.
-
-Optional arguments:
-
-     -c:  Control for parallel computation (default 1) -- 0 == run serially,  1 == SGE qsub,
-	         2 == use PEXEC (localhost), 3 == Apple XGrid, 4 == PBS qsub
-
-     -g:  Gradient step size; smaller in magnitude results in more cautious steps (default 0.25)
-
-     -i:  Iteration limit (default = 4) for template construction. requires 4*NumImages registrations.
-
-     -j:  Number of cpu cores to use (default: 2; --- set -c option to 2 to use this.
-
-     -k:  Number of modalities used to construct the template.
-
-     -w:  Modality weights used in the similarity metric (default = 1) --- specified as e.g. 1x0.5x0.75
-
-	  The optimal number of cpu cores to use for template generation depends on the availability of cores, the amount of
-	  free working memory (RAM) and the resolution of the data. High resolution datasets typically require more RAM during
-	  processing. Running out of RAM during a calculation will slow down all processing on your computer.
-
-     -m:  Max-iterations
-
-          Max-Iterations in form: JxKxL where
-	     J = max iterations at coarsest resolution (here, reduce by power of 2^2)
-	     K = middle resolution iterations (here,reduce by power of 2)
-	     L = fine resolution iterations (here, full resolution) !!this level takes much
-                 more time per iteration!!
-
-	  Adding an extra value before JxKxL (i.e. resulting in IxJxKxL) would add another
-	  iteration level.
-
-     -n:  N4BiasFieldCorrection of moving image ( 0 = off; 1 = on (default) )
-
-     -p:  Commands to prepend to job scripts (e.g., change into appropriate directory, set paths, etc)
-
-     -r:  Do rigid-body registration of inputs before creating template (default 0) -- 0 == off 1 == on. Only useful when
-          you do not have an initial template
-
-          In case a template is specified (-z option), all inputs are registered to that template. If
-          no template is specified, the inputs will be registered to the averaged input.
-
-     -s:  Type of similarity metric used for registration (can specify a metric per modality).
-
-	     For intramodal image registration, use:
-	     CC = cross-correlation (default)
-	     MI = mutual information
-	     PR = probability mapping
-	     MSQ = mean square difference (Demons-like)
-	     SSD = sum of squared differences
-
-	     For intermodal image registration, use:
-	     MI = mutual information
-	     PR = probability mapping (default)
-
-     -t:  Type of transformation model used for registration.
-
-	     For rigid image registration, use:
-	     RI = Purely rigid
-	     RA = Affine rigid
-
-	     For elastic image registration, use:
-	     EL = elastic transformation model (less deformation possible)
-
-	     For diffeomorphic image registration, use:
-	     SY = SyN with time (default) with arbitrary number of time points in time discretization
-	     S2 = SyN with time optimized specifically for 2 time points in the time discretization
-	     GR = Greedy SyN
-	     EX = Exponential
-      DD = Diffeomorphic Demons style exponential mapping
-
-     -x:  XGrid arguments (e.g., -x "-p password -h controlhost")
-
-     -z:  Use this this volume as the target of all inputs. When not used, the script
-          will create an unbiased starting point by averaging all inputs. Use the full path!
-
-     -b:  Save output files for each iteration to a separate directory (e.g. GR_iteration_0/).
-          Creates a large amount of data (default = 0).
-
-Requirements:
-
-This scripts relies on the following scripts in your $ANTSPATH directory. The script
-will terminate prematurely if these files are not present or are not executable.
-- antsIntroduction.sh
-- pexec.sh
-- waitForSGEQJobs.pl (only for use with Sun Grid Engine)
-- waitForPBSQJobs.pl  (only for use with Portable Batch System)
-- ANTSpexec.sh (only for use with localhost parallel execution)
-- waitForXGridJobs.pl (only for use with Apple XGrid)
-
---------------------------------------------------------------------------------------
-Get the latest ANTS version at:
---------------------------------------------------------------------------------------
-http://sourceforge.net/projects/advants/
-
---------------------------------------------------------------------------------------
-Read the ANTS documentation at:
---------------------------------------------------------------------------------------
-http://picsl.upenn.edu/ANTS/
-
---------------------------------------------------------------------------------------
-ANTS was created by:
---------------------------------------------------------------------------------------
-Brian B. Avants, Nick Tustison and Gang Song
-Penn Image Computing And Science Laboratory
-University of Pennsylvania
-
-Please reference http://www.ncbi.nlm.nih.gov/pubmed/20851191 when employing this script
-in your studies. A reproducible evaluation of ANTs similarity metric performance in
-brain image registration:
-
-* Avants BB, Tustison NJ, Song G, Cook PA, Klein A, Gee JC. Neuroimage, 2011.
-
-Also see http://www.ncbi.nlm.nih.gov/pubmed/19818860 for more details.
-
-The script has been updated and improved since this publication.
-
---------------------------------------------------------------------------------------
-script adapted by N.M. van Strien, http://www.mri-tutorial.com | NTNU MR-Center
-multivariate template adaption by Nick Tustison
---------------------------------------------------------------------------------------
-Apple XGrid support by Craig Stark
---------------------------------------------------------------------------------------
-
-HELP
-    exit 1
-}
-
 function reportMappingParameters {
     cat <<REPORTMAPPINGPARAMETERS
 
@@ -345,25 +172,28 @@ function reportMappingParameters {
 --------------------------------------------------------------------------------------
  ANTSPATH is $ANTSPATH
 
- Dimensionality:			$DIM
- N4BiasFieldCorrection:			$N4CORRECT
- Similarity Metric:			$METRICTYPE
- Transformation:			$TRANSFORMATIONTYPE
- Regularization:			$REGULARIZATION
- MaxIterations:				$MAXITERATIONS
- Number Of MultiResolution Levels:	$NUMLEVELS
- OutputName prefix:			$OUTPUTNAME
- Template:  				$TEMPLATENAME
- Template Update Steps:			$ITERATIONLIMIT
- Template population:	   		$IMAGESETVARIABLE
- Number of Modalities:     $NUMBEROFMODALITIES
- Madality weights:         $MODALITYWEIGHTSTRING
+ Dimensionality:                    $DIM
+ N4BiasFieldCorrection:             $N4CORRECT
+ Similarity Metric:                 $METRICTYPE
+ Transformation:                    $TRANSFORMATIONTYPE
+ Regularization:                    $REGULARIZATION
+ MaxIterations:                     $MAXITERATIONS
+ Number Of MultiResolution Levels:  $NUMLEVELS
+ OutputName prefix:                 $OUTPUTNAME
+ Template:                          $TEMPLATENAME
+ Template Update Steps:             $ITERATIONLIMIT
+ Template population:               $IMAGESETVARIABLE
+ Number of Modalities:              $NUMBEROFMODALITIES
+ Modality weights:                  $MODALITYWEIGHTSTRING
+ Shape update with full affine:     $AFFINE_UPDATE_FULL
 --------------------------------------------------------------------------------------
 REPORTMAPPINGPARAMETERS
 }
 
 function shapeupdatetotemplate() {
 
+   echo "shapeupdatetotemplate()"
+
     # local declaration of values
     dim=$1
     template=$2
@@ -386,47 +216,47 @@ function shapeupdatetotemplate() {
     echo
     echo "--------------------------------------------------------------------------------------"
     echo " shapeupdatetotemplate---voxel-wise averaging of the warped images to the current template"
-    echo "   ${ANTSPATH}AverageImages $dim ${template} 1 ${templatename}${whichtemplate}*WarpedToTemplate.nii.gz    "
+    echo "   ${ANTSPATH}/AverageImages $dim ${template} 1 ${templatename}${whichtemplate}*WarpedToTemplate.nii.gz    "
     echo "--------------------------------------------------------------------------------------"
-	   ${ANTSPATH}AverageImages $dim ${template} 1 ${templatename}${whichtemplate}*WarpedToTemplate.nii.gz
+    ${ANTSPATH}/AverageImages $dim ${template} 1 ${templatename}${whichtemplate}*WarpedToTemplate.nii.gz
 
     if [[ $whichtemplate -eq 0 ]] ;
+      then
         echo
         echo "--------------------------------------------------------------------------------------"
         echo " shapeupdatetotemplate---voxel-wise averaging of the inverse warp fields (from subject to template)"
-        echo	"   ${ANTSPATH}AverageImages $dim ${templatename}${whichtemplate}warp.nii.gz 0 `ls ${outputname}*Warp.nii.gz | grep -v "InverseWarp"`"
+        echo "   ${ANTSPATH}/AverageImages $dim ${templatename}${whichtemplate}warp.nii.gz 0 `ls ${outputname}*Warp.nii.gz | grep -v "InverseWarp"`"
         echo "--------------------------------------------------------------------------------------"
 
-        ${ANTSPATH}AverageImages $dim ${templatename}${whichtemplate}warp.nii.gz 0 `ls ${outputname}*Warp.nii.gz | grep -v "InverseWarp"`
+        ${ANTSPATH}/AverageImages $dim ${templatename}${whichtemplate}warp.nii.gz 0 `ls ${outputname}*Warp.nii.gz | grep -v "InverseWarp"`
 
         echo
         echo "--------------------------------------------------------------------------------------"
         echo " shapeupdatetotemplate---scale the averaged inverse warp field by the gradient step"
-        echo "   ${ANTSPATH}MultiplyImages $dim ${templatename}${whichtemplate}warp.nii.gz ${gradientstep} ${templatename}${whichtemplate}warp.nii.gz"
+        echo "   ${ANTSPATH}/MultiplyImages $dim ${templatename}${whichtemplate}warp.nii.gz ${gradientstep} ${templatename}${whichtemplate}warp.nii.gz"
         echo "--------------------------------------------------------------------------------------"
 
-        ${ANTSPATH}MultiplyImages $dim ${templatename}${whichtemplate}warp.nii.gz ${gradientstep} ${templatename}${whichtemplate}warp.nii.gz
+        ${ANTSPATH}/MultiplyImages $dim ${templatename}${whichtemplate}warp.nii.gz ${gradientstep} ${templatename}${whichtemplate}warp.nii.gz
 
-        then
         echo
         echo "--------------------------------------------------------------------------------------"
         echo " shapeupdatetotemplate---average the affine transforms (template <-> subject)"
         echo "                      ---transform the inverse field by the resulting average affine transform"
-        echo "   ${ANTSPATH}AverageAffineTransform ${dim} ${templatename}0Affine.txt ${outputname}*Affine.txt"
-        echo "   ${ANTSPATH}WarpImageMultiTransform ${dim} ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz -i  ${templatename}0Affine.txt -R ${template}"
+        echo "   ${ANTSPATH}/${AVERAGE_AFFINE_PROGRAM} ${dim} ${templatename}0Affine.txt ${outputname}*Affine.txt"
+        echo "   ${ANTSPATH}/WarpImageMultiTransform ${dim} ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz -i  ${templatename}0Affine.txt -R ${template}"
         echo "--------------------------------------------------------------------------------------"
 
-        ${ANTSPATH}AverageAffineTransform ${dim} ${templatename}0Affine.txt ${outputname}*Affine.txt
-        ${ANTSPATH}WarpImageMultiTransform ${dim} ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz -i  ${templatename}0Affine.txt -R ${template}
+        ${ANTSPATH}/${AVERAGE_AFFINE_PROGRAM} ${dim} ${templatename}0Affine.txt ${outputname}*Affine.txt
+        ${ANTSPATH}/WarpImageMultiTransform ${dim} ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz -i  ${templatename}0Affine.txt -R ${template}
 
-        ${ANTSPATH}MeasureMinMaxMean ${dim} ${templatename}0warp.nii.gz ${templatename}warplog.txt 1
-    fi
+        ${ANTSPATH}/MeasureMinMaxMean ${dim} ${templatename}0warp.nii.gz ${templatename}warplog.txt 1
+      fi
 
     echo "--------------------------------------------------------------------------------------"
     echo " shapeupdatetotemplate---warp each template by the resulting transforms"
-    echo "   ${ANTSPATH}WarpImageMultiTransform ${dim} ${template} ${template} -i ${templatename}0Affine.txt ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz -R ${template}"
+    echo "   ${ANTSPATH}/WarpImageMultiTransform ${dim} ${template} ${template} -i ${templatename}0Affine.txt ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz -R ${template}"
     echo "--------------------------------------------------------------------------------------"
-    ${ANTSPATH}WarpImageMultiTransform ${dim} ${template} ${template} -i ${templatename}0Affine.txt ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz -R ${template}
+    ${ANTSPATH}/WarpImageMultiTransform ${dim} ${template} ${template} -i ${templatename}0Affine.txt ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz ${templatename}0warp.nii.gz -R ${template}
 }
 
 function jobfnamepadding {
@@ -545,93 +375,98 @@ OUTPUTNAME=antsBTP
 
 BACKUP_EACH_ITERATION=0
 
+AFFINE_UPDATE_FULL=1
+
 ##Getting system info from linux can be done with these variables.
 # RAM=`cat /proc/meminfo | sed -n -e '/MemTotal/p' | awk '{ printf "%s %s\n", $2, $3 ; }' | cut -d " " -f 1`
 # RAMfree=`cat /proc/meminfo | sed -n -e '/MemFree/p' | awk '{ printf "%s %s\n", $2, $3 ; }' | cut -d " " -f 1`
 # cpu_free_ram=$((${RAMfree}/${cpu_count}))
 
 if [[ ${OSTYPE:0:6} == 'darwin' ]];
-	then
-	cpu_count=`sysctl -n hw.physicalcpu`
+ then
+ cpu_count=`sysctl -n hw.physicalcpu`
 else
-	cpu_count=`cat /proc/cpuinfo | grep processor | wc -l`
+ cpu_count=`cat /proc/cpuinfo | grep processor | wc -l`
 fi
 
 # Provide output for Help
 if [[ "$1" == "-h" ]];
     then
-    Help >&2
+    Usage >&2
 
 fi
 
 # reading command line arguments
-while getopts "b:c:d:g:h:i:j:k:m:n:o:p:s:r:t:w:x:z:" OPT
+while getopts "b:c:d:g:h:i:j:k:m:n:o:p:s:r:t:w:x:y:z:" OPT
   do
   case $OPT in
       h) #help
-	  echo "$USAGE"
-	  exit 0
-	  ;;
+   echo "$USAGE"
+   exit 0
+   ;;
       b) #backup each iteration (default = 0)
-	  BACKUP_EACH_ITERATION=$OPTARG
-	  ;;
+   BACKUP_EACH_ITERATION=$OPTARG
+   ;;
       c) #use SGE cluster
-	  DOQSUB=$OPTARG
-	  if [[ ${#DOQSUB} -gt 2 ]]; then
-	      echo " DOQSUB must be an integer value (0=serial, 1=SGE qsub, 2=try pexec, 3=XGrid, 4=PBS qsub ) you passed  -c $DOQSUB "
-	      exit 1
-	  fi
-	  ;;
+   DOQSUB=$OPTARG
+   if [[ ${#DOQSUB} -gt 2 ]]; then
+       echo " DOQSUB must be an integer value (0=serial, 1=SGE qsub, 2=try pexec, 3=XGrid, 4=PBS qsub ) you passed  -c $DOQSUB "
+       exit 1
+   fi
+   ;;
       d) #dimensions
-	  DIM=$OPTARG
-	  if [[ ${DIM} -eq 4 ]]; then
-	      DIM=3
-	      TDIM=4
-	  fi
-	  ;;
+   DIM=$OPTARG
+   if [[ ${DIM} -eq 4 ]]; then
+       DIM=3
+       TDIM=4
+   fi
+   ;;
       g) #gradient stepsize (default = 0.25)
-	  GRADIENTSTEP=$OPTARG
-	  ;;
+   GRADIENTSTEP=$OPTARG
+   ;;
       i) #iteration limit (default = 3)
-	  ITERATIONLIMIT=$OPTARG
-	  ;;
+   ITERATIONLIMIT=$OPTARG
+   ;;
       j) #number of cpu cores to use (default = 2)
-	  CORES=$OPTARG
-	  ;;
+   CORES=$OPTARG
+   ;;
       k) #number of modalities used to construct the template (default = 1)
-	  NUMBEROFMODALITIES=$OPTARG
-	  ;;
+   NUMBEROFMODALITIES=$OPTARG
+   ;;
       w) #modality weights (default = 1)
-	  MODALITYWEIGHTSTRING=$OPTARG
-	  ;;
+   MODALITYWEIGHTSTRING=$OPTARG
+   ;;
       m) #max iterations other than default
-	  MAXITERATIONS=$OPTARG
-	  ;;
+   MAXITERATIONS=$OPTARG
+   ;;
       n) #apply bias field correction
-	  N4CORRECT=$OPTARG
-	  ;;
+   N4CORRECT=$OPTARG
+   ;;
       o) #output name prefix
-	  OUTPUTNAME=$OPTARG
-	  TEMPLATENAME=${OUTPUTNAME}template
-	  ;;
+   OUTPUTNAME=$OPTARG
+   TEMPLATENAME=${OUTPUTNAME}template
+   ;;
       p) #Script prepend
-	  SCRIPTPREPEND=$OPTARG
-	  ;;
+   SCRIPTPREPEND=$OPTARG
+   ;;
       s) #similarity model
-	  METRICTYPE[${#METRICTYPE[@]}]=$OPTARG
-	  ;;
+   METRICTYPE[${#METRICTYPE[@]}]=$OPTARG
+   ;;
       r) #start with rigid-body registration
-	  RIGID=$OPTARG
-	  ;;
+   RIGID=$OPTARG
+   ;;
       t) #transformation model
-	  TRANSFORMATIONTYPE=$OPTARG
-	  ;;
+   TRANSFORMATIONTYPE=$OPTARG
+   ;;
       x) #initialization template
-	  XGRIDOPTS=$XGRIDOPTS
-	  ;;
+   XGRIDOPTS=$XGRIDOPTS
+   ;;
+      y) # update with full affine, 0 for no rigid (default = 1)
+   AFFINE_UPDATE_FULL=$OPTARG
+   ;;
       z) #initialization template
-	  REGTEMPLATES[${#REGTEMPLATES[@]}]=$OPTARG
-	  ;;
+   REGTEMPLATES[${#REGTEMPLATES[@]}]=$OPTARG
+   ;;
       \?) # getopts issues an error message
       echo "$USAGE" >&2
       exit 1
@@ -652,6 +487,13 @@ elif [[ $nargs -lt 6 ]]
     Usage >&2
 fi
 
+OUTPUT_DIR=${OUTPUTNAME%\/*}
+if [[ ! -d $OUTPUT_DIR ]];
+  then
+    echo "The output directory \"$OUTPUT_DIR\" does not exist. Making it."
+    mkdir -p $OUTPUT_DIR
+  fi
+
 if [[ $DOQSUB -eq 1 || $DOQSUB -eq 4 ]];
   then
     qq=`which  qsub`
@@ -664,7 +506,7 @@ if [[ $DOQSUB -eq 1 || $DOQSUB -eq 4 ]];
 
 for (( i = 0; i < $NUMBEROFMODALITIES; i++ ))
   do
-	   TEMPLATES[$i]=${TEMPLATENAME}${i}.nii.gz
+    TEMPLATES[$i]=${TEMPLATENAME}${i}.nii.gz
   done
 
 if [[ ${#METRICTYPE[@]} -eq 0 ]];
@@ -701,6 +543,7 @@ else
     fi
   fi
 
+
 # Creating the file list of images to make a template from.
 # Shiftsize is calculated because a variable amount of arguments can be used on the command line.
 # The shiftsize variable will give the correct number of arguments to skip. Issuing shift $shiftsize will
@@ -712,6 +555,13 @@ IMAGESETVARIABLE=$*
 NINFILES=$(($nargs - $shiftsize))
 IMAGESETARRAY=()
 
+AVERAGE_AFFINE_PROGRAM="AverageAffineTransform"
+
+if [[ $AFFINE_UPDATE_FULL -eq 0 ]];
+  then
+    AVERAGE_AFFINE_PROGRAM="AverageAffineTransformNoRigid"
+  fi
+
 # FSL not needed anymore, all dependent on ImageMath
 # #test if FSL is available in case of 4D, exit if not
 # if [[  ${TDIM} -eq 4 && ${#FSLDIR} -le 0 ]];
@@ -720,11 +570,11 @@ IMAGESETARRAY=()
 # fi
 
 if [[ ${NINFILES} -eq 0 ]];
-    then
+  then
     echo "Please provide at least 2 filenames for the template."
     echo "Use `basename $0` -h for help"
     exit 1
-elif [[ ${NINFILES} -eq 1 ]];
+  elif [[ ${NINFILES} -eq 1 ]];
     then
     extension=`echo ${IMAGESETVARIABLE#*.}`
     if [[ $extension = 'csv' || $extension = 'txt' ]];
@@ -747,7 +597,7 @@ elif [[ ${NINFILES} -eq 1 ]];
             done
          done < $IMAGESFILE
     else
-        range=`${ANTSPATH}ImageMath $TDIM abs nvols ${IMAGESETVARIABLE} | tail -1 | cut -d "," -f 4 | cut -d " " -f 2 | cut -d "]" -f 1 `
+        range=`${ANTSPATH}/ImageMath $TDIM abs nvols ${IMAGESETVARIABLE} | tail -1 | cut -d "," -f 4 | cut -d " " -f 2 | cut -d "]" -f 1 `
         if [[ ${range} -eq 1 && ${TDIM} -ne 4 ]];
             then
             echo "Please provide at least 2 filenames for the template."
@@ -778,8 +628,8 @@ elif [[ ${NINFILES} -eq 1 ]];
              #split the 4D file into 3D elements
              cp ${IMAGESETVARIABLE} ${tmpdir}/
              cd ${tmpdir}/
-             # ${ANTSPATH}ImageMath $TDIM vol0.nii.gz TimeSeriesSubset ${IMAGESETVARIABLE} ${range}
-             #	rm -f ${IMAGESETVARIABLE}
+             # ${ANTSPATH}/ImageMath $TDIM vol0.nii.gz TimeSeriesSubset ${IMAGESETVARIABLE} ${range}
+             # rm -f ${IMAGESETVARIABLE}
 
              # selecting 16 volumes randomly from the timeseries for averaging, placing them in tmp/selection folder.
              # the script will automatically divide timeseries into $total_volumes/16 bins from wich to take the random volumes;
@@ -810,20 +660,20 @@ elif [[ ${NINFILES} -eq 1 ]];
                     #debug only
                     echo
                     echo "Random number between $FLOOR and $BINrange ---  $number"
-                    #			echo "Random number between $FLOOR and $range ---  $number"
+                    #   echo "Random number between $FLOOR and $range ---  $number"
 
                     if [[ ${number} -lt 10 ]];
                         then
-                        ${ANTSPATH}ImageMath $TDIM selection/vol000${number}.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
-                        #					cp vol000${number}.nii.gz selection/
+                        ${ANTSPATH}/ImageMath $TDIM selection/vol000${number}.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
+                        #     cp vol000${number}.nii.gz selection/
                     elif [[ ${number} -ge 10 && ${number} -lt 100 ]];
                         then
-                        ${ANTSPATH}ImageMath $TDIM selection/vol00${number}.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
-                        #					cp vol00${number}.nii.gz selection/
+                        ${ANTSPATH}/ImageMath $TDIM selection/vol00${number}.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
+                        #     cp vol00${number}.nii.gz selection/
                     elif [[ ${number} -ge 100 && ${number} -lt 1000 ]];
                         then
-                        ${ANTSPATH}ImageMath $TDIM selection/vol0${number}.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
-                        #					cp vol0${number}.nii.gz selection/
+                        ${ANTSPATH}/ImageMath $TDIM selection/vol0${number}.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
+                        #     cp vol0${number}.nii.gz selection/
                     fi
                     let j++
                 done
@@ -836,18 +686,18 @@ elif [[ ${NINFILES} -eq 1 ]];
                 let "number %= $range"
                 if [[ ${number} -lt 10 ]];
                     then
-                    ${ANTSPATH}ImageMath $TDIM selection/vol0.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
-                    #					cp vol000${number}.nii.gz selection/
+                    ${ANTSPATH}/ImageMath $TDIM selection/vol0.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
+                    #     cp vol000${number}.nii.gz selection/
                 elif [[ ${number} -ge 10 && ${number} -lt 100 ]];
                     then
-                    ${ANTSPATH}ImageMath $TDIM selection/vol0.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
-                    #					cp vol00${number}.nii.gz selection/
+                    ${ANTSPATH}/ImageMath $TDIM selection/vol0.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
+                    #     cp vol00${number}.nii.gz selection/
                 fi
             done
         elif [[ ${range} -le ${nfmribins} ]];
             then
-            ${ANTSPATH}ImageMath selection/$TDIM vol0.nii.gz TimeSeriesSubset ${IMAGESETVARIABLE} ${range}
-            #		cp *.nii.gz selection/
+            ${ANTSPATH}/ImageMath selection/$TDIM vol0.nii.gz TimeSeriesSubset ${IMAGESETVARIABLE} ${range}
+            #  cp *.nii.gz selection/
         fi
         # set filelist variable
         rm -f ${IMAGESETVARIABLE}
@@ -906,7 +756,7 @@ for (( i = 0; i < $NUMBEROFMODALITIES; i++ ))
         echo " Creating template ${TEMPLATES[$i]} from a population average image from the inputs."
         echo "   ${CURRENTIMAGESET[@]}"
         echo "--------------------------------------------------------------------------------------"
-        ${ANTSPATH}AverageImages $DIM ${TEMPLATES[$i]} 1 ${CURRENTIMAGESET[@]}
+        ${ANTSPATH}/AverageImages $DIM ${TEMPLATES[$i]} 1 ${CURRENTIMAGESET[@]}
     fi
 
     if [[ ! -s ${TEMPLATES[$i]} ]];
@@ -1007,7 +857,7 @@ if [[ "$RIGID" -eq 1 ]];
         echo " Starting ANTS rigid registration on SGE cluster. Submitted $count jobs "
         echo "--------------------------------------------------------------------------------------"
         # now wait for the jobs to finish. Rigid registration is quick, so poll queue every 60 seconds
-	${ANTSPATH}waitForSGEQJobs.pl 1 60 $jobIDs
+ ${ANTSPATH}/waitForSGEQJobs.pl 1 60 $jobIDs
         # Returns 1 if there are errors
         if [[ ! $? -eq 0 ]];
             then
@@ -1023,7 +873,7 @@ if [[ "$RIGID" -eq 1 ]];
         echo " Starting ANTS rigid registration on PBS cluster. Submitted $count jobs "
         echo "--------------------------------------------------------------------------------------"
                # now wait for the jobs to finish. Rigid registration is quick, so poll queue every 60 seconds
-        ${ANTSPATH}waitForPBSQJobs.pl 1 60 $jobIDs
+        ${ANTSPATH}/waitForPBSQJobs.pl 1 60 $jobIDs
         # Returns 1 if there are errors
         if [[ ! $? -eq 0 ]];
             then
@@ -1051,7 +901,7 @@ if [[ "$RIGID" -eq 1 ]];
         echo " Starting ANTS rigid registration on XGrid cluster. Submitted $count jobs "
         echo "--------------------------------------------------------------------------------------"
         # now wait for the jobs to finish. Rigid registration is quick, so poll queue every 60 seconds
-        ${ANTSPATH}waitForXGridJobs.pl -xgridflags "$XGRIDOPTS" -verbose -delay 30 $jobIDs
+        ${ANTSPATH}/waitForXGridJobs.pl -xgridflags "$XGRIDOPTS" -verbose -delay 30 $jobIDs
         # Returns 1 if there are errors
         if [[ ! $? -eq 0 ]];
             then
@@ -1061,7 +911,7 @@ if [[ "$RIGID" -eq 1 ]];
     fi
 
     for (( j = 0; j < $NUMBEROFMODALITIES; j++ ))
-        do
+      do
         IMAGERIGIDSET=()
         for (( i = $j; i < ${#IMAGESETARRAY[@]}; i+=$NUMBEROFMODALITIES ))
             do
@@ -1074,32 +924,43 @@ if [[ "$RIGID" -eq 1 ]];
             IMAGERIGIDSET[${#IMAGERIGIDSET[@]}]=$RIGID
         done
         echo
-        echo  "${ANTSPATH}AverageImages $DIM ${TEMPLATES[$j]} 1 ${IMAGERIGIDSET[@]}"
+        echo  "${ANTSPATH}/AverageImages $DIM ${TEMPLATES[$j]} 1 ${IMAGERIGIDSET[@]}"
 
-	   ${ANTSPATH}AverageImages $DIM ${TEMPLATES[$j]} 1 ${IMAGERIGIDSET[@]}
+    ${ANTSPATH}/AverageImages $DIM ${TEMPLATES[$j]} 1 ${IMAGERIGIDSET[@]}
     done
 
     # cleanup and save output in seperate folder
-    mkdir ${outdir}/rigid
-    mv ${outdir}/*.cfg ${outdir}/rigid*.nii.gz ${outdir}/*Affine.txt ${outdir}/rigid/
-    # backup logs
-    if [[ $DOQSUB -eq 1 ]];
-	       then
-	       mv ${outdir}/antsBuildTemplate_rigid* ${outdir}/rigid/
-        # Remove qsub scripts
-	rm -f ${outdir}/job_${count}_qsub.sh
-    elif [[ $DOQSUB -eq 4 ]];
-        then
-	       mv ${outdir}/antsrigid* ${outdir}/rigid/
-        # Remove qsub scripts
-	  rm -f ${outdir}/job_${count}_qsub.sh
-    elif [[ $DOQSUB -eq 2 ]];
-	       then
-	       mv ${outdir}/job*.txt ${outdir}/rigid/
-    elif [[ $DOQSUB -eq 3 ]];
-	       then
-	       rm -f ${outdir}/job_*_qsub.sh
-    fi
+    if [[ BACKUP_EACH_ITERATION -eq 1 ]];
+      then
+
+        echo
+        echo "--------------------------------------------------------------------------------------"
+        echo " Backing up results from rigid iteration"
+        echo "--------------------------------------------------------------------------------------"
+
+        mkdir ${outdir}/rigid
+        mv ${outdir}/rigid*.nii.gz ${outdir}/*GenericAffine.mat ${outdir}/rigid/
+        # backup logs
+        if [[ $DOQSUB -eq 1 ]];
+          then
+            mv ${outdir}/antsBuildTemplate_rigid* ${outdir}/rigid/
+            # Remove qsub scripts
+            rm -f ${outdir}/job_${count}_qsub.sh
+        elif [[ $DOQSUB -eq 4 ]];
+          then
+            mv ${outdir}/antsrigid* ${outdir}/rigid/
+            # Remove qsub scripts
+            rm -f ${outdir}/job_${count}_qsub.sh
+        elif [[ $DOQSUB -eq 2 ]];
+          then
+            mv ${outdir}/job*.txt ${outdir}/rigid/
+        elif [[ $DOQSUB -eq 3 ]];
+          then
+            rm -f ${outdir}/job_*_qsub.sh
+        fi
+      else
+        rm -f  ${outdir}/rigid*.* ${outdir}/job*.txt
+      fi
 fi # endif RIGID
 
 ##########################################################################
@@ -1273,18 +1134,18 @@ while [[ $i -lt ${ITERATIONLIMIT} ]];
             OUTWARPFN="${OUTWARPFN}${j}"
 
             if [[ $N4CORRECT -eq 1 ]];
-                then
+              then
                 REPAIRED="${outdir}/${OUTFN}Repaired.nii.gz"
-                exe=" $exe $N4 -d ${DIM} -b [200] -c [50x50x40x30,0.00000001] -i ${IMAGESETARRAY[$l]} -o ${REPAIRED} -s 2\n"
-                pexe=" $pexe $N4 -d ${DIM} -b [200] -c [50x50x40x30,0.00000001] -i ${IMAGESETARRAY[$l]} -o ${REPAIRED} -s 2  >> ${outdir}/job_${count}_metriclog.txt\n"
+                exe=" $exe $N4 -d ${DIM} -b [200] -c [50x50x40x30,0.00000001] -i ${IMAGESETARRAY[$l]} -o ${REPAIRED} -r 0 -s 2\n"
+                pexe=" $pexe $N4 -d ${DIM} -b [200] -c [50x50x40x30,0.00000001] -i ${IMAGESETARRAY[$l]} -o ${REPAIRED} -r 0 -s 2  >> ${outdir}/job_${count}_metriclog.txt\n"
                 IMAGEMETRICSET="$IMAGEMETRICSET -m ${METRIC}${TEMPLATES[$k]},${REPAIRED},${METRICPARAMS}"
                 warpexe=" $warpexe ${WARP} ${DIM} ${REPAIRED} ${DEFORMED} -R ${TEMPLATES[$k]} ${outdir}/${OUTWARPFN}Warp.nii.gz ${outdir}/${OUTWARPFN}Affine.txt\n"
                 warppexe=" $warppexe ${WARP} ${DIM} ${REPAIRED} ${DEFORMED} -R ${TEMPLATES[$k]} ${outdir}/${OUTWARPFN}Warp.nii.gz ${outdir}/${OUTWARPFN}Affine.txt >> ${outdir}/job_${count}_metriclog.txt\n"
-            else
+              else
                 IMAGEMETRICSET="$IMAGEMETRICSET -m ${METRIC}${TEMPLATES[$k]},${IMAGESETARRAY[$l]},${METRICPARAMS}";
                 warpexe=" $warpexe ${WARP} ${DIM} ${IMAGESETARRAY[$l]} ${DEFORMED} -R ${TEMPLATES[$k]} ${outdir}/${OUTWARPFN}Warp.nii.gz ${outdir}/${OUTWARPFN}Affine.txt\n"
                 warppexe=" $warppexe ${WARP} ${DIM} ${IMAGESETARRAY[$l]} ${DEFORMED} -R ${TEMPLATES[$k]} ${outdir}/${OUTWARPFN}Warp.nii.gz ${outdir}/${OUTWARPFN}Affine.txt >> ${outdir}/job_${count}_metriclog.txt\n"
-            fi
+              fi
 
         done
 
@@ -1335,7 +1196,7 @@ while [[ $i -lt ${ITERATIONLIMIT} ]];
 
         # counter updated, but not directly used in this loop
         count=`expr $count + 1`;
-    #		echo " submitting job number $count " # for debugging only
+    #  echo " submitting job number $count " # for debugging only
     done
     # SGE wait for script to finish
     if [[ $DOQSUB -eq 1 ]];
@@ -1345,7 +1206,7 @@ while [[ $i -lt ${ITERATIONLIMIT} ]];
         echo " Starting ANTS registration on SGE cluster. Iteration: $itdisplay of $ITERATIONLIMIT"
         echo "--------------------------------------------------------------------------------------"
         # now wait for the stuff to finish - this will take a while so poll queue every 10 mins
-        ${ANTSPATH}waitForSGEQJobs.pl 1 600 $jobIDs
+        ${ANTSPATH}/waitForSGEQJobs.pl 1 600 $jobIDs
         if [[ ! $? -eq 0 ]];
             then
             echo "qsub submission failed - jobs went into error state"
@@ -1358,7 +1219,7 @@ while [[ $i -lt ${ITERATIONLIMIT} ]];
         echo " Starting ANTS registration on PBS cluster. Iteration: $itdisplay of $ITERATIONLIMIT"
         echo "--------------------------------------------------------------------------------------"
         # now wait for the stuff to finish - this will take a while so poll queue every 10 mins
-        ${ANTSPATH}waitForPBSQJobs.pl 1 600 $jobIDs
+        ${ANTSPATH}/waitForPBSQJobs.pl 1 600 $jobIDs
         if [[ ! $? -eq 0 ]];
             then
             echo "qsub submission failed - jobs went into error state"
@@ -1385,7 +1246,7 @@ while [[ $i -lt ${ITERATIONLIMIT} ]];
         echo " Starting ANTS registration on XGrid cluster. Submitted $count jobs "
         echo "--------------------------------------------------------------------------------------"
         # now wait for the jobs to finish. This is slow, so poll less often
-        ${ANTSPATH}waitForXGridJobs.pl -xgridflags "$XGRIDOPTS" -verbose -delay 300 $jobIDs
+        ${ANTSPATH}/waitForXGridJobs.pl -xgridflags "$XGRIDOPTS" -verbose -delay 300 $jobIDs
         # Returns 1 if there are errors
         if [[ ! $? -eq 0 ]];
             then
@@ -1422,7 +1283,7 @@ while [[ $i -lt ${ITERATIONLIMIT} ]];
       fi
     ((i++))
 done
-end main loop
+# end main loop
 rm -f job*.sh
 #cleanup of 4D files
 if [[ "${range}" -gt 1 && "${TDIM}" -eq 4 ]];
