@@ -41,11 +41,11 @@ fi
 
 # Test availability of helper scripts.
 # No need to test this more than once. Can reside outside of the main loop.
-ANTSSCRIPTNAME=${ANTSPATH}antsIntroduction.sh
-PEXEC=${ANTSPATH}ANTSpexec.sh
-SGE=${ANTSPATH}waitForSGEQJobs.pl
-PBS=${ANTSPATH}waitForPBSQJobs.pl
-XGRID=${ANTSPATH}waitForXGridJobs.pl
+ANTSSCRIPTNAME=${ANTSPATH}/antsIntroduction.sh
+PEXEC=${ANTSPATH}/ANTSpexec.sh
+SGE=${ANTSPATH}/waitForSGEQJobs.pl
+PBS=${ANTSPATH}/waitForPBSQJobs.pl
+XGRID=${ANTSPATH}/waitForXGridJobs.pl
 
 fle_error=0
 for FLE in $ANTSSCRIPTNAME $PEXEC $SGE $XGRID
@@ -368,21 +368,21 @@ function shapeupdatetotemplate {
     echo "--------------------------------------------------------------------------------------"
     echo " shapeupdatetotemplate 1"
     echo "--------------------------------------------------------------------------------------"
-	${ANTSPATH}AverageImages $dim ${template} 1 ${outputname}*formed.nii.gz
+	${ANTSPATH}/AverageImages $dim ${template} 1 ${outputname}*formed.nii.gz
 
     echo
     echo "--------------------------------------------------------------------------------------"
     echo " shapeupdatetotemplate 2"
     echo "--------------------------------------------------------------------------------------"
 
-	${ANTSPATH}AverageImages $dim ${templatename}warp.nii.gz 0 `ls ${outputname}*Warp.nii.gz | grep -v "InverseWarp"`
+	${ANTSPATH}/AverageImages $dim ${templatename}warp.nii.gz 0 `ls ${outputname}*Warp.nii.gz | grep -v "InverseWarp"`
 
     echo
     echo "--------------------------------------------------------------------------------------"
     echo " shapeupdatetotemplate 3"
     echo "--------------------------------------------------------------------------------------"
 
-	${ANTSPATH}MultiplyImages $dim ${templatename}warp.nii.gz ${gradientstep} ${templatename}warp.nii.gz
+	${ANTSPATH}/MultiplyImages $dim ${templatename}warp.nii.gz ${gradientstep} ${templatename}warp.nii.gz
 
 
     echo
@@ -404,16 +404,16 @@ function shapeupdatetotemplate {
 #      ANTSAverage3DAffine ${templatename}Affine${afftype} ${outputname}*Affine${afftype}
 #    fi
 
-    ${ANTSPATH}AverageAffineTransform ${dim} ${templatename}Affine${afftype} ${outputname}*Affine${afftype}
-    ${ANTSPATH}WarpImageMultiTransform ${dim} ${templatename}warp.nii.gz ${templatename}warp.nii.gz -i  ${templatename}Affine${afftype} -R ${template}
-    ${ANTSPATH}WarpImageMultiTransform ${dim} ${template} ${template} -i ${templatename}Affine${afftype} ${templatename}warp.nii.gz ${templatename}warp.nii.gz ${templatename}warp.nii.gz ${templatename}warp.nii.gz -R ${template}
+    ${ANTSPATH}/AverageAffineTransform ${dim} ${templatename}Affine${afftype} ${outputname}*Affine${afftype}
+    ${ANTSPATH}/WarpImageMultiTransform ${dim} ${templatename}warp.nii.gz ${templatename}warp.nii.gz -i  ${templatename}Affine${afftype} -R ${template}
+    ${ANTSPATH}/WarpImageMultiTransform ${dim} ${template} ${template} -i ${templatename}Affine${afftype} ${templatename}warp.nii.gz ${templatename}warp.nii.gz ${templatename}warp.nii.gz ${templatename}warp.nii.gz -R ${template}
 
     echo
     echo "--------------------------------------------------------------------------------------"
     echo " shapeupdatetotemplate 6"
     echo "--------------------------------------------------------------------------------------"
     echo
-    ${ANTSPATH}MeasureMinMaxMean ${dim} ${templatename}warp.nii.gz ${templatename}warplog.txt 1
+    ${ANTSPATH}/MeasureMinMaxMean ${dim} ${templatename}warp.nii.gz ${templatename}warplog.txt 1
 
 
 }
@@ -788,7 +788,7 @@ if [ ${NINFILES} -eq 0 ]
 elif [[ ${NINFILES} -eq 1 ]]
     then
 
-    range=`${ANTSPATH}ImageMath $TDIM abs nvols ${IMAGESETVARIABLE} | tail -1 | cut -d "," -f 4 | cut -d " " -f 2 | cut -d "]" -f 1 `
+    range=`${ANTSPATH}/ImageMath $TDIM abs nvols ${IMAGESETVARIABLE} | tail -1 | cut -d "," -f 4 | cut -d " " -f 2 | cut -d "]" -f 1 `
 
     if [ ${range} -eq 1 ] && [ ${TDIM} -ne 4 ]
 	then
@@ -820,7 +820,7 @@ elif [[ ${NINFILES} -eq 1 ]]
 	#split the 4D file into 3D elements
 	cp ${IMAGESETVARIABLE} ${tmpdir}/
 	cd ${tmpdir}/
- #       ${ANTSPATH}ImageMath $TDIM vol0.nii.gz TimeSeriesSubset ${IMAGESETVARIABLE} ${range}
+ #       ${ANTSPATH}/ImageMath $TDIM vol0.nii.gz TimeSeriesSubset ${IMAGESETVARIABLE} ${range}
 #	rm -f ${IMAGESETVARIABLE}
 
 	# selecting 16 volumes randomly from the timeseries for averaging, placing them in tmp/selection folder.
@@ -857,15 +857,15 @@ elif [[ ${NINFILES} -eq 1 ]]
 #			echo "Random number between $FLOOR and $range ---  $number"
 				if [ ${number} -lt 10 ]
 					then
-					${ANTSPATH}ImageMath $TDIM selection/vol000${number}.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
+					${ANTSPATH}/ImageMath $TDIM selection/vol000${number}.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
 #					cp vol000${number}.nii.gz selection/
 				elif [ ${number} -ge 10 ] && [ ${number} -lt 100 ]
 					then
-					${ANTSPATH}ImageMath $TDIM selection/vol00${number}.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
+					${ANTSPATH}/ImageMath $TDIM selection/vol00${number}.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
 #					cp vol00${number}.nii.gz selection/
 				elif [ ${number} -ge 100 ] && [ ${number} -lt 1000 ]
 					then
-					${ANTSPATH}ImageMath $TDIM selection/vol0${number}.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
+					${ANTSPATH}/ImageMath $TDIM selection/vol0${number}.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
 #					cp vol0${number}.nii.gz selection/
 				fi
 
@@ -882,11 +882,11 @@ elif [[ ${NINFILES} -eq 1 ]]
 
 				if [ ${number} -lt 10 ]
 					then
-					${ANTSPATH}ImageMath $TDIM selection/vol0.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
+					${ANTSPATH}/ImageMath $TDIM selection/vol0.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
 #					cp vol000${number}.nii.gz selection/
 				elif [ ${number} -ge 10 ] && [ ${number} -lt 100 ]
 					then
-					${ANTSPATH}ImageMath $TDIM selection/vol0.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
+					${ANTSPATH}/ImageMath $TDIM selection/vol0.nii.gz ExtractSlice ${IMAGESETVARIABLE} ${number}
 #					cp vol00${number}.nii.gz selection/
 				fi
 			done
@@ -894,7 +894,7 @@ elif [[ ${NINFILES} -eq 1 ]]
 	elif [ ${range} -le ${nfmribins}  ]
 		then
 
-		${ANTSPATH}ImageMath selection/$TDIM vol0.nii.gz TimeSeriesSubset ${IMAGESETVARIABLE} ${range}
+		${ANTSPATH}/ImageMath selection/$TDIM vol0.nii.gz TimeSeriesSubset ${IMAGESETVARIABLE} ${range}
 #		cp *.nii.gz selection/
 
 	fi
@@ -915,7 +915,7 @@ if [ ! -s $REGTEMPLATE ]
     echo "--------------------------------------------------------------------------------------"
     echo " No initial template exists. Creating a population average image from the inputs."
     echo "--------------------------------------------------------------------------------------"
-    ${ANTSPATH}AverageImages $DIM $TEMPLATE 1 $IMAGESETVARIABLE
+    ${ANTSPATH}/AverageImages $DIM $TEMPLATE 1 $IMAGESETVARIABLE
 else
     echo
     echo "--------------------------------------------------------------------------------------"
@@ -949,8 +949,8 @@ if [ "$RIGID" -eq 1 ] ;
 
       BASENAME=` echo ${IMG} | cut -d '.' -f 1 `
 
-      exe=" ${ANTSPATH}ANTS $DIM -m MI[${TEMPLATE},${IMG},1,32] -o rigid_${IMG} -i 0 --use-Histogram-Matching --number-of-affine-iterations 10000x10000x10000x10000x10000 $RIGIDTYPE"
-      exe2="${ANTSPATH}WarpImageMultiTransform $DIM ${IMG} rigid_${IMG} rigid_${BASENAME}Affine${afftype} -R ${TEMPLATE}"
+      exe=" ${ANTSPATH}/ANTS $DIM -m MI[${TEMPLATE},${IMG},1,32] -o rigid_${IMG} -i 0 --use-Histogram-Matching --number-of-affine-iterations 10000x10000x10000x10000x10000 $RIGIDTYPE"
+      exe2="${ANTSPATH}/WarpImageMultiTransform $DIM ${IMG} rigid_${IMG} rigid_${BASENAME}Affine${afftype} -R ${TEMPLATE}"
       pexe=" $exe >> job_${count}_metriclog.txt "
 
       qscript="job_${count}_qsub.sh"
@@ -996,7 +996,7 @@ if [ "$RIGID" -eq 1 ] ;
 	echo " Starting ANTS rigid registration on SGE cluster. Submitted $count jobs "
 	echo "--------------------------------------------------------------------------------------"
         # now wait for the jobs to finish. Rigid registration is quick, so poll queue every 60 seconds
-	${ANTSPATH}waitForSGEQJobs.pl 1 60 $jobIDs
+	${ANTSPATH}/waitForSGEQJobs.pl 1 60 $jobIDs
 
 	# Returns 1 if there are errors
 	if [ ! $? -eq 0 ]; then
@@ -1013,7 +1013,7 @@ if [ "$RIGID" -eq 1 ] ;
 	echo " Starting ANTS rigid registration on PBS cluster. Submitted $count jobs "
 	echo "--------------------------------------------------------------------------------------"
         # now wait for the jobs to finish. Rigid registration is quick, so poll queue every 60 seconds
-	${ANTSPATH}waitForPBSQJobs.pl 1 60 $jobIDs
+	${ANTSPATH}/waitForPBSQJobs.pl 1 60 $jobIDs
 
 	# Returns 1 if there are errors
 	if [ ! $? -eq 0 ]; then
@@ -1043,7 +1043,7 @@ if [ "$RIGID" -eq 1 ] ;
 	echo " Starting ANTS rigid registration on XGrid cluster. Submitted $count jobs "
 	echo "--------------------------------------------------------------------------------------"
         # now wait for the jobs to finish. Rigid registration is quick, so poll queue every 60 seconds
-	${ANTSPATH}waitForXGridJobs.pl -xgridflags "$XGRIDOPTS" -verbose -delay 30 $jobIDs
+	${ANTSPATH}/waitForXGridJobs.pl -xgridflags "$XGRIDOPTS" -verbose -delay 30 $jobIDs
 	# Returns 1 if there are errors
 	if [ ! $? -eq 0 ]; then
 	    echo "XGrid submission failed - jobs went into error state"
@@ -1053,7 +1053,7 @@ if [ "$RIGID" -eq 1 ] ;
 
 
     # Update template
-    ${ANTSPATH}AverageImages $DIM $TEMPLATE 1 $RIGID_IMAGESET
+    ${ANTSPATH}/AverageImages $DIM $TEMPLATE 1 $RIGID_IMAGESET
 
     # cleanup and save output in seperate folder
 
@@ -1157,7 +1157,7 @@ while [  $i -lt ${ITERATIONLIMIT} ]
     fi
 
     # 5 prepare registration command
-    exe="${ANTSSCRIPTNAME} -d ${DIM} -r ${dir}/${TEMPLATE} -i ${dir}/${IMG} -o ${dir}/${OUTFN} -m ${MAXITERATIONS} -n ${N4CORRECT} -s ${METRICTYPE} -t ${TRANSFORMATIONTYPE} "
+    exe="${ANTSSCRIPTNAME} -d ${DIM} -r ${dir}/${TEMPLATE} -i ${dir}/${IMG} -o ${dir}/${OUTFN} -m ${MAXITERATIONS} -n ${N4CORRECT} -s ${METRICTYPE} -t ${TRANSFORMATIONTYPE} -f 1 "
     pexe=" $exe >> job_${count}_${i}_metriclog.txt "
 
     # 6 submit to SGE (DOQSUB=1), PBS (DOQSUB=4), PEXEC (DOQSUB=2), XGrid (DOQSUB=3) or else run locally (DOQSUB=0)
@@ -1202,7 +1202,7 @@ while [  $i -lt ${ITERATIONLIMIT} ]
       echo "--------------------------------------------------------------------------------------"
 
       # now wait for the stuff to finish - this will take a while so poll queue every 10 mins
-      ${ANTSPATH}waitForSGEQJobs.pl 1 600 $jobIDs
+      ${ANTSPATH}/waitForSGEQJobs.pl 1 600 $jobIDs
 
       if [ ! $? -eq 0 ]; then
         echo "qsub submission failed - jobs went into error state"
@@ -1218,7 +1218,7 @@ while [  $i -lt ${ITERATIONLIMIT} ]
       echo "--------------------------------------------------------------------------------------"
 
       # now wait for the stuff to finish - this will take a while so poll queue every 10 mins
-      ${ANTSPATH}waitForPBSQJobs.pl 1 600 $jobIDs
+      ${ANTSPATH}/waitForPBSQJobs.pl 1 600 $jobIDs
 
       if [ ! $? -eq 0 ]; then
         echo "qsub submission failed - jobs went into error state"
@@ -1249,7 +1249,7 @@ while [  $i -lt ${ITERATIONLIMIT} ]
     echo " Starting ANTS registration on XGrid cluster. Submitted $count jobs "
     echo "--------------------------------------------------------------------------------------"
            # now wait for the jobs to finish. This is slow, so poll less often
-    ${ANTSPATH}waitForXGridJobs.pl -xgridflags "$XGRIDOPTS" -verbose -delay 300 $jobIDs
+    ${ANTSPATH}/waitForXGridJobs.pl -xgridflags "$XGRIDOPTS" -verbose -delay 300 $jobIDs
     # Returns 1 if there are errors
     if [ ! $? -eq 0 ]; then
         echo "XGrid submission failed - jobs went into error state"
