@@ -82,9 +82,9 @@ bool FEMConformalMap<TSurface, TImage, TDimension>
 {
   if( !m_VtkSurfaceMesh )
     {
-    ::::ants::antscout << " NO MESH"; return false;
+    ::std::cout << " NO MESH"; return false;
     }
-  ::::ants::antscout << " Generate system from surface mesh " << std::endl;
+  ::std::cout << " Generate system from surface mesh " << std::endl;
 
   vtkTriangleFilter* fltTriangle = vtkTriangleFilter::New();
   fltTriangle->SetInput(m_VtkSurfaceMesh);
@@ -138,7 +138,7 @@ bool FEMConformalMap<TSurface, TImage, TDimension>
     foundnum++;
     }
 
-  ::::ants::antscout << " foundnum " << foundnum << std::endl;
+  ::std::cout << " foundnum " << foundnum << std::endl;
 
   typename NodeType::Pointer * narr = new NodeType::Pointer[numPoints];
   for( int i = 0; i < numPoints; i++ )
@@ -152,8 +152,8 @@ bool FEMConformalMap<TSurface, TImage, TDimension>
   vtkIdType*    pts;
   unsigned long i = 0;
   unsigned long toti = vtkcells->GetNumberOfCells();
-  //  ::::ants::antscout << " progress ";
-  ::::ants::antscout << " DONE: NUMBER OF CELLS start " << toti << std::endl;
+  //  ::std::cout << " progress ";
+  ::std::cout << " DONE: NUMBER OF CELLS start " << toti << std::endl;
   for( vtkcells->InitTraversal(); vtkcells->GetNextCell(npts, pts); )
     {
     ElementType::Pointer e;
@@ -168,7 +168,7 @@ bool FEMConformalMap<TSurface, TImage, TDimension>
     i++;
     }
 
-  ::::ants::antscout << " DONE: NUMBER OF CELLS " << i << std::endl;
+  ::std::cout << " DONE: NUMBER OF CELLS " << i << std::endl;
 
   return true;
 }
@@ -194,7 +194,7 @@ bool  FEMConformalMap<TSurface, TImage, TDimension>
   m->nu = 0.;     // .0;    // poissons -- DONT CHOOSE 1.0!!///
   m->RhoC = 0.0;
   // 3.e-4 prolly good
-//  ::::ants::antscout << " input E ";  std::cin >> m->E;
+//  ::std::cout << " input E ";  std::cin >> m->E;
 
   // Create the element type
   ElementType::Pointer e1 = ElementType::New();
@@ -208,7 +208,7 @@ bool  FEMConformalMap<TSurface, TImage, TDimension>
     m_SurfaceMesh->GetPoint(i, pt_ptr);
     if( m_Debug )
       {
-      ::::ants::antscout << "Point: "  << i << " coords " << pt[0] << ", " << pt[1] << ", " << pt[2] << std::endl;
+      ::std::cout << "Point: "  << i << " coords " << pt[0] << ", " << pt[1] << ", " << pt[2] << std::endl;
       }
 
     // turn the point into a node
@@ -230,7 +230,7 @@ bool  FEMConformalMap<TSurface, TImage, TDimension>
     tp = cellPtr->GetPointIds();
     if( m_Debug )
       {
-      ::::ants::antscout << " pt 1 id " << tp[0] << " pt 2 id " << tp[1] << " pt 3 id " << tp[2] << std::endl;
+      ::std::cout << " pt 1 id " << tp[0] << " pt 2 id " << tp[1] << " pt 3 id " << tp[2] << std::endl;
       }
     cells++;
 
@@ -401,7 +401,7 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
 
   typename ImageType::SpacingType spacing = m_Image->GetSpacing();
   typename ImageType::SizeType imageSize = m_Image->GetLargestPossibleRegion().GetSize();
-  ::::ants::antscout << " size " << imageSize << std::endl;
+  ::std::cout << " size " << imageSize << std::endl;
   VectorType disp;
   disp.set_size(3);
   disp.fill(0.0);
@@ -592,14 +592,14 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
         float x = ( (*elt)->GetNode(nd)->GetCoordinates()[dd]);
         if( x <= minx[dd] )
           {
-//      ::::ants::antscout << " x " << x << " minx " << minx << std::endl;
+//      ::std::cout << " x " << x << " minx " << minx << std::endl;
           m_PoleElementsGN[dd * 2] = (*elt)->GN;
           minv = (*elt)->GetNode(nd)->GetCoordinates();
           minx[dd] = x;
           }
         else if( x >= maxx[dd] )
           {
-//      ::::ants::antscout << " x " << x << " maxx " << maxx << std::endl;
+//      ::std::cout << " x " << x << " maxx " << maxx << std::endl;
           m_PoleElementsGN[dd * 2 + 1] = (*elt)->GN;
           maxv = (*elt)->GetNode(nd)->GetCoordinates();
           maxx[dd] = x;
@@ -609,8 +609,8 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
     }
   for( int jj = 0; jj < 3; jj++ )
     {
-    ::::ants::antscout << " Element " <<  m_PoleElementsGN[jj * 2] << " is north " << jj << std::endl;
-    ::::ants::antscout << " Element " <<  m_PoleElementsGN[jj * 2 + 1] << " is south " << jj << std::endl;
+    ::std::cout << " Element " <<  m_PoleElementsGN[jj * 2] << " is north " << jj << std::endl;
+    ::std::cout << " Element " <<  m_PoleElementsGN[jj * 2 + 1] << " is south " << jj << std::endl;
     }
 }
 
@@ -639,7 +639,7 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
 
     int   absdim = abs(dim);
     float oc = 2.0;
-    ::::ants::antscout << " Fixing BC  " << absdim << std::endl;
+    ::std::cout << " Fixing BC  " << absdim << std::endl;
 
     switch( absdim )
       {
@@ -807,7 +807,7 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
     float theta = (CA[0] * BA[0] + CA[1] * BA[1] + CA[2] * BA[2]) / bamag * bamag;
     if( theta > 1 )
       {
-      ::::ants::antscout << " theta " << theta << std::endl;
+      ::std::cout << " theta " << theta << std::endl;
       }
 
     VectorType E = A + BA * theta;
@@ -857,7 +857,7 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
     float bamag=BA.magnitude();
 
     float theta=(CA[0]*BA[0]+CA[1]*BA[1]+CA[2]*BA[2])/bamag*bamag;
-    if (theta > 1) ::::ants::antscout << " theta " << theta << std::endl;
+    if (theta > 1) ::std::cout << " theta " << theta << std::endl;
 
     VectorType E = A+BA*theta;
     VectorType CE =C-E;
@@ -904,7 +904,7 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
     float theta = (CA[0] * BA[0] + CA[1] * BA[1] + CA[2] * BA[2]) / bamag * bamag;
     if( theta > 1 || theta < 0 )
       {
-      //      ::::ants::antscout << " ERROR : theta from non-acute angle  " << theta << std::endl;
+      //      ::std::cout << " ERROR : theta from non-acute angle  " << theta << std::endl;
       //      throw;
       //      return;
       }
@@ -949,7 +949,7 @@ template <typename TSurface, typename TImage, unsigned int TDimension>
 void  FEMConformalMap<TSurface, TImage, TDimension>
 ::ComputeStereographicCoordinates()
 {
-  ::::ants::antscout << " coords on unit sphere : " << std::endl;
+  ::std::cout << " coords on unit sphere : " << std::endl;
   float radsq;      // radius squared
   float c1, c2, c3; // stereographic coordinates
 
@@ -964,7 +964,7 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
     c1 = 2.0 * x / (1.0 + radsq);
     c2 = 2.0 * y / (1.0 + radsq);
     c3 = 2.0 * radsq / (1.0 + radsq) - 1.0;
-    //      ::::ants::antscout << c1 << "   " << c2 << "   " << c3 << " mag " << sqrt(c1*c1+c2*c2+c3*c3) << std::endl;
+    //      ::std::cout << c1 << "   " << c2 << "   " << c3 << " mag " << sqrt(c1*c1+c2*c2+c3*c3) << std::endl;
 
     VectorType coord = (*n)->GetCoordinates();
     coord[0] = c1;
@@ -972,7 +972,7 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
     coord[2] = c3;
     // /      (*n)->SetCoordinates(coord);
     }
-  ::::ants::antscout << " coords on unit sphere done " << std::endl;
+  ::std::cout << " coords on unit sphere done " << std::endl;
 }
 
 template <typename TSurface, typename TImage, unsigned int TDimension>
@@ -989,12 +989,12 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
   if( m_ReadFromFile )
     {
     const char* filename = m_ParameterFileName.c_str();
-    ::::ants::antscout << "Reading FEM problem from file: " << std::string(filename) << "\n";
+    ::std::cout << "Reading FEM problem from file: " << std::string(filename) << "\n";
     std::ifstream f;
     f.open(filename);
     if( !f )
       {
-      ::::ants::antscout << "File " << filename << " not found!\n";
+      ::std::cout << "File " << filename << " not found!\n";
       return;
       }
 
@@ -1004,8 +1004,8 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
       }
     catch( ::itk::fem::FEMException & e )
       {
-      ::::ants::antscout << "Error reading FEM problem: " << filename << "!\n";
-      e.Print(::::ants::antscout);
+      ::std::cout << "Error reading FEM problem: " << filename << "!\n";
+      e.Print(::std::cout);
       return;
       }
 
@@ -1018,7 +1018,7 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
   //   else this->GenerateSystemFromSurfaceMesh();
 
   int dir = m_NorthPole;
-//  ::::ants::antscout << " input dir to fix "; std::cin >> dir;
+//  ::std::cout << " input dir to fix "; std::cin >> dir;
   this->FindPoles(dir);
   if( m_NorthPole != m_SouthPole )
     {
@@ -1041,22 +1041,22 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
     {
     for( ::itk::fem::Solver::NodeArray::iterator n = m_Solver.node.begin(); n != m_Solver.node.end(); ++n )
       {
-      ::::ants::antscout << "Node#: " << (*n)->GN << ": ";
-      ::::ants::antscout << " coord " << (*n)->GetCoordinates() << std::endl;
+      ::std::cout << "Node#: " << (*n)->GN << ": ";
+      ::std::cout << " coord " << (*n)->GetCoordinates() << std::endl;
       }
     for( ::itk::fem::Solver::ElementArray::iterator n = m_Solver.el.begin(); n != m_Solver.el.end(); ++n )
       {
-      ::::ants::antscout << "Elt#: " << (*n)->GN << ": has " << (*n)->GetNumberOfNodes() << " nodes ";
+      ::std::cout << "Elt#: " << (*n)->GN << ": has " << (*n)->GetNumberOfNodes() << " nodes ";
       for( int i = 0; i < (*n)->GetNumberOfNodes(); i++ )
         {
-        ::::ants::antscout << " coord " << (*n)->GetNode(i)->GetCoordinates() << std::endl;
+        ::std::cout << " coord " << (*n)->GetNode(i)->GetCoordinates() << std::endl;
         }
       }
     }
 
   unsigned int maxits = m_Solver.GetNumberOfDegreesOfFreedom();   // should be > twice ndofs
   // if (m_Debug)
-  ::::ants::antscout << " ndof " << maxits << std::endl;
+  ::std::cout << " ndof " << maxits << std::endl;
   itpackWrapper.SetMaximumNumberIterations(maxits * 4);
   itpackWrapper.SetTolerance(1.e-5);
   itpackWrapper.JacobianConjugateGradient();
@@ -1067,10 +1067,10 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
    * Assemble the master stiffness matrix. In order to do this
    * the GFN's should already be assigned to every DOF.
    */
-  ::::ants::antscout << " assemble k " << std::endl;
+  ::std::cout << " assemble k " << std::endl;
   m_Solver.AssembleK();
 
-  ::::ants::antscout << " assemble k done " << std::endl;
+  ::std::cout << " assemble k done " << std::endl;
   if( m_Debug )
     {
     for( int i = 0; i < m_Solver.GetNumberOfDegreesOfFreedom(); i++ )
@@ -1083,10 +1083,10 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
           {
           sum += val;
           }
-//    if (val != 0) ::::ants::antscout << " entry i,j " << i << " , " << j << "  =  " <<
+//    if (val != 0) ::std::cout << " entry i,j " << i << " , " << j << "  =  " <<
 // m_Solver.GetLinearSystemWrapper()->GetMatrixValue(i,j)<<std::endl;
         }
-      ::::ants::antscout << " sum #" << i << " = " << sum << std::endl;
+      ::std::cout << " sum #" << i << " = " << sum << std::endl;
       }
     }
   /**
@@ -1120,25 +1120,25 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
       this->ApplyImaginaryForces(m_NorthPole);
       }
     m_Solver.AssembleF();
-    ::::ants::antscout << " force done " << std::endl;
+    ::std::cout << " force done " << std::endl;
     m_Solver.Solve();
-    ::::ants::antscout << " solve done " << std::endl;
+    ::std::cout << " solve done " << std::endl;
     m_Solver.UpdateDisplacements(); // copies solution to nodes
     m_Debug = true;
     if( m_Debug )
       {
-      ::::ants::antscout << "\nNodal displacements:\n";
+      ::std::cout << "\nNodal displacements:\n";
       }
     unsigned int ct = 0;
     for( ::itk::fem::Solver::NodeArray::iterator n = m_Solver.node.begin(); n != m_Solver.node.end(); ++n )
       {
       if( m_Debug )
         {
-        ::::ants::antscout << "Node#: " << (*n)->GN << ": ";
+        ::std::cout << "Node#: " << (*n)->GN << ": ";
         }
       if( m_Debug )
         {
-        ::::ants::antscout << " coord " << (*n)->GetCoordinates() << std::endl;
+        ::std::cout << " coord " << (*n)->GetCoordinates() << std::endl;
         }
       // For each DOF in the node... */
       for( unsigned int d = 0, dof;
@@ -1146,11 +1146,11 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
         {
         if( m_Debug )
           {
-          ::::ants::antscout << m_Solver.GetSolution(dof);
+          ::std::cout << m_Solver.GetSolution(dof);
           }
         if( m_Debug )
           {
-          ::::ants::antscout << ",  ";
+          ::std::cout << ",  ";
           }
 //         if (d==0 && im == 0) {m_RealSolution[ct]=m_Solver.GetSolution(dof); ct++;}
 //         if (d==0 && im == 1) {m_ImagSolution[ct]=m_Solver.GetSolution(dof); ct++;}
@@ -1162,11 +1162,11 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
           {
           m_ImagSolution[dof] = m_Solver.GetSolution(dof); ct++;
           }
-//         ::::ants::antscout << " dof " << dof << " ct " << ct << std::endl;
+//         ::std::cout << " dof " << dof << " ct " << ct << std::endl;
         }
       if( m_Debug )
         {
-        ::::ants::antscout << "\b\b\b \b\n";
+        ::std::cout << "\b\b\b \b\n";
         }
       m_Debug = false;
       }
@@ -1195,7 +1195,7 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
 
   vtkFloatArray* param = vtkFloatArray::New();
   param->SetName("angle");
-  ::::ants::antscout << " start pts ";
+  ::std::cout << " start pts ";
   int idx = 0;
 
   vtkDataArray* scs = NULL;
@@ -1220,7 +1220,7 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
     float        c3 = 2.0 * radsq / (1.0 + radsq) - 1.0;
     if( idx % 1000 == 0 )
       {
-      ::::ants::antscout << c1 << "   " << c2 << "   " << c3 << " mag "
+      ::std::cout << c1 << "   " << c2 << "   " << c3 << " mag "
                          << sqrt(c1 * c1 + c2 * c2 + c3 * c3) << std::endl;
       }
 
@@ -1256,11 +1256,11 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
     idx++;
     }
 
-  ::::ants::antscout << " done with pts " << std::endl;
+  ::std::cout << " done with pts " << std::endl;
   vtkCellArray* tris1 = vtkCellArray::New();
   vtkCellArray* tris2 = vtkCellArray::New();
 
-  ::::ants::antscout << " start with tris " << std::endl;
+  ::std::cout << " start with tris " << std::endl;
   for( ::itk::fem::Solver::ElementArray::iterator n = m_Solver.el.begin(); n != m_Solver.el.end(); ++n )
     {
     tris1->InsertNextCell(3);
@@ -1271,7 +1271,7 @@ void  FEMConformalMap<TSurface, TImage, TDimension>
       tris2->InsertCellPoint( (*n)->GetNode(i)->GN);
       }
     }
-  ::::ants::antscout << " done with tris " << std::endl;
+  ::std::cout << " done with tris " << std::endl;
   // Assign points and cells
   polydata1->SetPoints(vpoints1);
   polydata2->SetPoints(vpoints2);
