@@ -169,21 +169,21 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
 
   if( !labels )
     {
-    ::ants::antscout << " cant get Labels --- need an array named Label in the mesh ... " << std::endl;
+    std::cout << " cant get Labels --- need an array named Label in the mesh ... " << std::endl;
     std::exception();
     }
   else
     {
-    ::ants::antscout << " got Labels " << std::endl;
+    std::cout << " got Labels " << std::endl;
     }
   for( int i = 0; i < numPoints; i++ )
     {
     double* pt = vtkpoints->GetPoint(i);
     manifoldIntegrator->GetGraphNode(i)->SetValue(labels->GetTuple1(i), 3);
-    //    ::ants::antscout << " label " << labels->GetTuple1(i) <<  " & " <<  label <<std::endl;
+    //    std::cout << " label " << labels->GetTuple1(i) <<  " & " <<  label <<std::endl;
     if( fabs( labels->GetTuple1(i) - label ) < 0.5 )
       {
-      //      ::ants::antscout << " choose " <<  labels->GetTuple1(i) << " & " <<  label << std::endl;
+      //      std::cout << " choose " <<  labels->GetTuple1(i) << " & " <<  label << std::endl;
       meanx += pt[0]; meany += pt[1]; meanz += pt[2];
       ct++;
       //      i=numPoints+1;
@@ -210,21 +210,21 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
       {
       mindist = dist;
       m_SourceNodeNumber = i;
-      //    ::ants::antscout << "  label " << label  << " chose " << labels->GetTuple1(i)  << std::endl;
+      //    std::cout << "  label " << label  << " chose " << labels->GetTuple1(i)  << std::endl;
       }
     }
   if( this->FindLoopAroundNode( this->m_SourceNodeNumber ) == 2  )
     {
-    ::ants::antscout << " found loop " << std::endl;
+    std::cout << " found loop " << std::endl;
     }
 
   if( ct > 0 )
     {
-    ::ants::antscout << meanx << "  " <<  meany <<  "  " << meanz << std::endl;
+    std::cout << meanx << "  " <<  meany <<  "  " << meanz << std::endl;
     }
   else
     {
-    ::ants::antscout << " no label " << label << " exiting " << std::endl;
+    std::cout << " no label " << label << " exiting " << std::endl;
     std::exception();
     }
 }
@@ -293,7 +293,7 @@ float FEMDiscConformalMap<TSurface, TImage, TDimension>
     x = (1 - arclength) / 0.25; /* 1 => 0 */
     y = 0;
     }
-//  ::ants::antscout <<" x " << x << " y " << y << " al " << arclength << std::endl;
+//  std::cout <<" x " << x << " y " << y << " al " << arclength << std::endl;
 
   if( whichParam == 0 )
     {
@@ -361,7 +361,7 @@ unsigned int FEMDiscConformalMap<TSurface, TImage, TDimension>
   for( unsigned int i = 0; i < this->m_DiscBoundaryList.size(); i++ )
     {
     unsigned int nxt = ( ( i + 1 ) % this->m_DiscBoundaryList.size() );
-    //   ::ants::antscout << " this->m_DiscBoundaryList[i]->GetLocation() " <<
+    //   std::cout << " this->m_DiscBoundaryList[i]->GetLocation() " <<
     // this->m_DiscBoundaryList[i]->GetLocation() <<
     // std::endl;
     diff = this->m_DiscBoundaryList[i]->GetLocation() - this->m_DiscBoundaryList[nxt]->GetLocation();
@@ -381,7 +381,7 @@ unsigned int FEMDiscConformalMap<TSurface, TImage, TDimension>
         }
       }
     }
-  ::ants::antscout << " length " << totallength << " valid? " << isvalid << " entries "
+  std::cout << " length " << totallength << " valid? " << isvalid << " entries "
                      << this->m_DiscBoundaryList.size()
                      << " gsz " << this->m_HelpFindLoop.size() << std::endl;
 
@@ -425,11 +425,11 @@ unsigned int FEMDiscConformalMap<TSurface, TImage, TDimension>
     }
   if( !BestG  )
     {
-    ::ants::antscout << " does not exist " << std::endl; return false;
+    std::cout << " does not exist " << std::endl; return false;
     }
   if( this->m_HelpFindLoop[BestG->GetIdentity()] != 0 )
     {
-    ::ants::antscout << " already done " << std::endl; return false;
+    std::cout << " already done " << std::endl; return false;
     }
   std::vector<GraphSearchNodePointer> neighborlist;
   long                                paramct = 0;
@@ -446,7 +446,7 @@ unsigned int FEMDiscConformalMap<TSurface, TImage, TDimension>
       this->m_HelpFindLoop[BestG->GetIdentity()] = paramct;
       }
     }
-  //  ::ants::antscout << " len1 " << this->m_DiscBoundaryList.size()  <<  " len2 " <<  neighborlist.size() <<
+  //  std::cout << " len1 " << this->m_DiscBoundaryList.size()  <<  " len2 " <<  neighborlist.size() <<
   // std::endl;
   this->SetDiscBoundaryList( neighborlist );
   //  this->m_DiscBoundaryList.assign(neighborlist.begin(),neighborlist.end());
@@ -503,7 +503,7 @@ unsigned int FEMDiscConformalMap<TSurface, TImage, TDimension>
       }
     newtotallength += tangentlength;
     }
-  ::ants::antscout << " total1 " << totallength << " total2 " << newtotallength << std::endl;
+  std::cout << " total1 " << totallength << " total2 " << newtotallength << std::endl;
   // check for self-intersection
   for( unsigned int i = 0; i < this->m_DiscBoundaryList.size(); i++ )
     {
@@ -530,8 +530,8 @@ unsigned int FEMDiscConformalMap<TSurface, TImage, TDimension>
   unsigned long MAXLIST = 200;
   if( this->m_DiscBoundaryList.size() > MAXLIST )
     {
-    ::ants::antscout <<     this->m_RootNode->GetLocation() << std::endl;
-    ::ants::antscout << "long list " << MAXLIST << std::endl;
+    std::cout <<     this->m_RootNode->GetLocation() << std::endl;
+    std::cout << "long list " << MAXLIST << std::endl;
     return 2;
     }
   return isvalid;
@@ -612,7 +612,7 @@ unsigned int  FEMDiscConformalMap<TSurface, TImage, TDimension>
   discParameterizer->SetSurfaceMesh(this->m_SurfaceMesh);
   discParameterizer->InitializeGraph3();
   discParameterizer->SetMaxCost(1.e9);
-  ::ants::antscout << " dcz " << discParameterizer->GetGraphSize() << std::endl;
+  std::cout << " dcz " << discParameterizer->GetGraphSize() << std::endl;
   for( int i = 0; i < discParameterizer->GetGraphSize(); i++ )
     {
     discParameterizer->GetGraphNode(i)->SetTotalCost(vnl_huge_val(discParameterizer->GetMaxCost() ) );
@@ -645,7 +645,7 @@ unsigned int  FEMDiscConformalMap<TSurface, TImage, TDimension>
         farnode2 = discParameterizer->GetGraphNode(i);
         }
       vct++;
-      // ::ants::antscout << " dist " << t << " vct " << vct << std::endl;
+      // std::cout << " dist " << t << " vct " << vct << std::endl;
       }
     }
   discParameterizer->BackTrack(farnode2);
@@ -654,7 +654,7 @@ unsigned int  FEMDiscConformalMap<TSurface, TImage, TDimension>
   lastlooper->SetSurfaceMesh(this->m_SurfaceMesh);
   lastlooper->InitializeGraph3();
   lastlooper->SetMaxCost(1.e9);
-  //     ::ants::antscout << " dcz "<< lastlooper->GetGraphSize() << std::endl;
+  //     std::cout << " dcz "<< lastlooper->GetGraphSize() << std::endl;
   for( int i = 0; i < lastlooper->GetGraphSize(); i++ )
     {
     lastlooper->GetGraphNode(i)->SetTotalCost(vnl_huge_val(lastlooper->GetMaxCost() ) );
@@ -691,7 +691,7 @@ unsigned int  FEMDiscConformalMap<TSurface, TImage, TDimension>
         farnode3 = lastlooper->GetGraphNode(i);
         }
       vct++;
-      //           ::ants::antscout << " dist " << t << " vct " << vct << std::endl;
+      //           std::cout << " dist " << t << " vct " << vct << std::endl;
       }
     }
   //     std::exception();
@@ -718,41 +718,41 @@ unsigned int  FEMDiscConformalMap<TSurface, TImage, TDimension>
   //
   this->m_DiscBoundaryList.clear();
   // add both the above to the list
-  //     ::ants::antscout << " part 1 " << std::endl;
+  //     std::cout << " part 1 " << std::endl;
   for( unsigned int i = 0; i < discParameterizer->GetPathSize(); i++ )
     {
     unsigned int id = discParameterizer->GetPathAtIndex(i)->GetIdentity();
-    //  ::ants::antscout << manifoldIntegrator->GetGraphNode(id)->GetLocation() << std::endl;
+    //  std::cout << manifoldIntegrator->GetGraphNode(id)->GetLocation() << std::endl;
     this->m_DiscBoundaryList.push_back( manifoldIntegrator->GetGraphNode(id) );
     }
-  //     ::ants::antscout << " part 2 " << std::endl;
+  //     std::cout << " part 2 " << std::endl;
   lastlooper->BackTrack( lastlooper->GetGraphNode( farnode1->GetIdentity() ) );
   for( unsigned int i = 0; i < lastlooper->GetPathSize(); i++ )
     {
     unsigned int id = lastlooper->GetPathAtIndex(i)->GetIdentity();
-    //         ::ants::antscout << manifoldIntegrator->GetGraphNode(id)->GetLocation() << std::endl;
+    //         std::cout << manifoldIntegrator->GetGraphNode(id)->GetLocation() << std::endl;
     this->m_DiscBoundaryList.push_back( manifoldIntegrator->GetGraphNode(id) );
     }
 
-  //     ::ants::antscout << farnode1->GetLocation() << std::endl;
-  // ::ants::antscout << farnode2->GetLocation() << std::endl;
-  //     ::ants::antscout << farnode3->GetLocation() << std::endl;
-  //     ::ants::antscout << " another idea --- get two points far apart  then solve a minimization problem across the
+  //     std::cout << farnode1->GetLocation() << std::endl;
+  // std::cout << farnode2->GetLocation() << std::endl;
+  //     std::cout << farnode3->GetLocation() << std::endl;
+  //     std::cout << " another idea --- get two points far apart  then solve a minimization problem across the
   // graph
   // that gives the average value in 0 => 1 ... " << std::endl;
-  // ::ants::antscout << " path 1 sz " << discParameterizer->GetPathSize() << std::endl;
+  // std::cout << " path 1 sz " << discParameterizer->GetPathSize() << std::endl;
 
   // finally do but add in reverse order
-  // ::ants::antscout << " part 3 " <<farnode2->GetIdentity() << " and " << farnode1->GetIdentity() << std::endl;
+  // std::cout << " part 3 " <<farnode2->GetIdentity() << " and " << farnode1->GetIdentity() << std::endl;
   lastlooper->EmptyPath();
   lastlooper->BackTrack(  lastlooper->GetGraphNode( farnode2->GetIdentity() ) );
   for( unsigned int i = lastlooper->GetPathSize() - 1; i > 0; i-- )
     {
     unsigned int id = lastlooper->GetPathAtIndex(i)->GetIdentity();
-    //         ::ants::antscout << manifoldIntegrator->GetGraphNode(id)->GetLocation() << std::endl;
+    //         std::cout << manifoldIntegrator->GetGraphNode(id)->GetLocation() << std::endl;
     this->m_DiscBoundaryList.push_back( manifoldIntegrator->GetGraphNode(id) );
     }
-  ::ants::antscout << " Almost ... " << std::endl;
+  std::cout << " Almost ... " << std::endl;
 
   this->m_HelpFindLoop.clear();
   this->m_HelpFindLoop.resize(gsz, 0);
@@ -761,7 +761,7 @@ unsigned int  FEMDiscConformalMap<TSurface, TImage, TDimension>
     m_HelpFindLoop[this->m_DiscBoundaryList[j]->GetIdentity()] = j + 1;
     }
 
-  ::ants::antscout << " Achievement!! " << std::endl;
+  std::cout << " Achievement!! " << std::endl;
 
   return 2;
 }
@@ -797,7 +797,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
             inb = 1;
             }
           } // neighborhood
-        if( inb > 0 ) //      ::ants::antscout <<  " Node is in boundary " << std::endl;
+        if( inb > 0 ) //      std::cout <<  " Node is in boundary " << std::endl;
           {
           inb = 0;
           for( unsigned int i = 0; i < manifoldIntegrator->GetGraphNode(j)->m_NumberOfNeighbors; i++ )
@@ -822,7 +822,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
         } // less than max cost
       }   // if node exists
     }     // gsz
-  ::ants::antscout << " Boundary has " << this->m_DiscBoundaryList.size() << " elements with eff. max cost "
+  std::cout << " Boundary has " << this->m_DiscBoundaryList.size() << " elements with eff. max cost "
                      <<  effectivemaxcost << std::endl;
   if( CheckCost )
     {
@@ -837,7 +837,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
     bool paramdone = false;
     while(  !paramdone )
       {
-      ::ants::antscout << " start param "  << bsz << std::endl;
+      std::cout << " start param "  << bsz << std::endl;
       if( bsz == 0 )
         {
         std::exception();
@@ -846,7 +846,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
         {
         if(  this->m_DiscBoundaryList[myi] != this->m_DiscBoundaryList[rootind] )
           {
-          ::ants::antscout << " myi " << myi << " root " << rootind << " bc " << boundcount << std::endl;
+          std::cout << " myi " << myi << " root " << rootind << " bc " << boundcount << std::endl;
           for( unsigned int n = 0; n < this->m_DiscBoundaryList[rootind]->m_NumberOfNeighbors; n++ )
             {
             if(  this->m_DiscBoundaryList[myi] == this->m_DiscBoundaryList[rootind]->m_Neighbors[n] &&
@@ -863,7 +863,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
                 alreadyfound[myi] = true;
                 this->m_DiscBoundarySorter[myi] = boundcount;
                 n = this->m_DiscBoundaryList[rootind]->m_NumberOfNeighbors + 1;
-                ::ants::antscout << " cur " <<  this->m_DiscBoundaryList[rootind]->GetLocation() << " next "
+                std::cout << " cur " <<  this->m_DiscBoundaryList[rootind]->GetLocation() << " next "
                                    <<  this->m_DiscBoundaryList[myi]->GetLocation() << " boundcount "  << boundcount
                                    << " of " << bsz
                                    << "  curroot " << rootind << std::endl;
@@ -883,7 +883,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
           boundcount--;
           rootind = lastroot;
           this->m_DiscBoundarySorter[rootind] = -1;
-          ::ants::antscout << " failure " << std::endl;
+          std::cout << " failure " << std::endl;
           std::exception();
           }
         } // all boundary nodes
@@ -897,26 +897,26 @@ template <typename TSurface, typename TImage, unsigned int TDimension>
 void  FEMDiscConformalMap<TSurface, TImage, TDimension>
 ::ExtractSurfaceDisc(unsigned int label)
 {
-  ::ants::antscout << " set surface mesh " << std::endl;
+  std::cout << " set surface mesh " << std::endl;
 
   manifoldIntegrator->SetSurfaceMesh(this->m_SurfaceMesh);
-  ::ants::antscout << " begin initializing graph " << std::endl;
+  std::cout << " begin initializing graph " << std::endl;
   manifoldIntegrator->InitializeGraph3();
   this->m_SurfaceMesh = manifoldIntegrator->GetSurfaceMesh();
 //   float frac=0;
 //  IndexType index;
   if( this->m_Label_to_Flatten == 0 )
     {
-    ::ants::antscout << " enter LabelToExtract ";  std::cin >> m_Label_to_Flatten;
+    std::cout << " enter LabelToExtract ";  std::cin >> m_Label_to_Flatten;
     float mc = 0;
-    ::ants::antscout << " Enter max cost ";  std::cin >> mc;
+    std::cout << " Enter max cost ";  std::cin >> mc;
     m_MaxCost = mc;
     }
   manifoldIntegrator->SetMaxCost(this->m_MaxCost);
   this->FindMeanSourceInLabel( this->m_Label_to_Flatten );
   //  this->LocateAndParameterizeDiscBoundary(  m_Label_to_Flatten , false );
   //   this->LocateAndParameterizeDiscBoundary(  m_Label_to_Flatten , true );
-  // ::ants::antscout << " findpath in extractsurfacedisk done ";
+  // std::cout << " findpath in extractsurfacedisk done ";
 
 // assign scalars to the original surface mesh
 //  typedef itk::SurfaceMeshCurvature<GraphSearchNodeType,GraphSearchNodeType> surfktype;
@@ -936,7 +936,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
     param->InsertNextValue(temp * 255. / m_MaxCost);
     }
 
-  ::ants::antscout << " extractsurfacedisk done ";
+  std::cout << " extractsurfacedisk done ";
   //  m_SurfaceMesh->GetPointData()->SetScalars(param);
 }
 
@@ -946,9 +946,9 @@ bool  FEMDiscConformalMap<TSurface, TImage, TDimension>
 {
   if( !this->m_SurfaceMesh )
     {
-    ::ants::antscout << " NO MESH"; return false;
+    std::cout << " NO MESH"; return false;
     }
-  ::ants::antscout << " Generate system from surface mesh " << std::endl;
+  std::cout << " Generate system from surface mesh " << std::endl;
   m_Smooth = m_Sigma;
   // create a material
   // Choose the material properties
@@ -996,8 +996,8 @@ bool  FEMDiscConformalMap<TSurface, TImage, TDimension>
       }
     }
 
-  ::ants::antscout << " Found " << foundnum << " nodes " << std::endl;
-  ::ants::antscout <<  " bound " << boundsz << std::endl;
+  std::cout << " Found " << foundnum << " nodes " << std::endl;
+  std::cout <<  " bound " << boundsz << std::endl;
   vtkCellArray* vtkcells = this->m_SurfaceMesh->GetPolys();
 
   vtkIdType     npts;
@@ -1005,12 +1005,12 @@ bool  FEMDiscConformalMap<TSurface, TImage, TDimension>
   unsigned long i = 0;
 //   unsigned long toti = vtkcells->GetNumberOfCells();
 //   unsigned long rate = toti/50;
-//  ::ants::antscout << " progress ";
+//  std::cout << " progress ";
   for( vtkcells->InitTraversal(); vtkcells->GetNextCell(npts, pts); )
     {
-    //  if ( i % rate == 0 && i > rate ) ::ants::antscout << "  " <<  (float) i / (float) toti << " ";
+    //  if ( i % rate == 0 && i > rate ) std::cout << "  " <<  (float) i / (float) toti << " ";
     // turn the cell into an element
-    //      ::ants::antscout << " points ids a " << pts[0] << " b " << pts[1] << " c " << pts[2] << std::endl;
+    //      std::cout << " points ids a " << pts[0] << " b " << pts[1] << " c " << pts[2] << std::endl;
     bool                 eltok = true;
     ElementType::Pointer e;
     e = dynamic_cast<ElementType *>(e1->Clone() );
@@ -1050,10 +1050,10 @@ bool  FEMDiscConformalMap<TSurface, TImage, TDimension>
       e->GN = i;
       m_Solver.el.push_back(itk::fem::FEMP<itk::fem::Element>(e) );
       i++;
-      } // else ::ants::antscout <<" cannot find elt " << std::endl;
+      } // else std::cout <<" cannot find elt " << std::endl;
     }
 
-  ::ants::antscout << " DONE: NUMBER OF CELLS " << i << std::endl;
+  std::cout << " DONE: NUMBER OF CELLS " << i << std::endl;
 
   return true;
 }
@@ -1123,7 +1123,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
     eltct++;
     }
 
-  ::ants::antscout << " Fixed elt number " << fixct << " of " << eltct << std::endl;
+  std::cout << " Fixed elt number " << fixct << " of " << eltct << std::endl;
 }
 
 template <typename TSurface, typename TImage, unsigned int TDimension>
@@ -1204,7 +1204,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>::MakeFlatImage()
   m_FlatImage->Allocate();
   typename FlatImageType::IndexType index;
 
-  ::ants::antscout << " Making flat image " << std::endl;
+  std::cout << " Making flat image " << std::endl;
   int maxits = 100;
   for( int its = 0; its <= maxits; its++ )
     {
@@ -1216,7 +1216,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>::MakeFlatImage()
         (long int)(0.5 + ( 1.0 + manifoldIntegrator->GetGraphNode( (*n)->GN)->GetValue(0) ) * (float)(sz - 1) / 2.);
       index[1] =
         (long int)(0.5 + ( 1.0 + manifoldIntegrator->GetGraphNode( (*n)->GN)->GetValue(1) ) * (float)(sz - 1) / 2.);
-      // ::ants::antscout << " ind " << index << std::endl;
+      // std::cout << " ind " << index << std::endl;
       m_FlatImage->SetPixel(index, temp);
       }
     typedef itk::DiscreteGaussianImageFilter<FlatImageType, FlatImageType> dgf;
@@ -1240,7 +1240,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>::MakeFlatImage()
         float x = (float)index[0] - (float)sz / 2.0;
         float y = (float)index[1] - (float)sz / 2.0;
         float dist = sqrt(x * x + y * y);
-        //        ::ants::antscout << "center " << center <<  " index " << index << "dist " << dist ;
+        //        std::cout << "center " << center <<  " index " << index << "dist " << dist ;
         if( dist > center )
           {
           it.Set( 0.0 );
@@ -1254,7 +1254,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>::MakeFlatImage()
 template <typename TSurface, typename TImage, unsigned int TDimension>
 void  FEMDiscConformalMap<TSurface, TImage, TDimension>::BuildOutputMeshes(float tval)
 {
-  ::ants::antscout << " build output mesh " << std::endl;
+  std::cout << " build output mesh " << std::endl;
 
   typedef GraphSearchNodeType::NodeLocationType loctype;
   // Get the number of points in the mesh
@@ -1288,7 +1288,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>::BuildOutputMeshes(float
   vpoints1->SetNumberOfPoints(numPoints);
   vpoints2->SetNumberOfPoints(numPoints);
 
-  ::ants::antscout << " start pts ";
+  std::cout << " start pts ";
   int idx = 0;
 
   vtkFloatArray* param = vtkFloatArray::New();
@@ -1328,11 +1328,11 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>::BuildOutputMeshes(float
     idx++;
     }
 
-  ::ants::antscout << " done with pts " << std::endl;
+  std::cout << " done with pts " << std::endl;
   vtkCellArray* tris1 = vtkCellArray::New();
   vtkCellArray* tris2 = vtkCellArray::New();
 
-  ::ants::antscout << " start with tris " << std::endl;
+  std::cout << " start with tris " << std::endl;
   for( ::itk::fem::Solver::ElementArray::iterator n = m_Solver.el.begin(); n != m_Solver.el.end(); ++n )
     {
     tris1->InsertNextCell(3);
@@ -1343,7 +1343,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>::BuildOutputMeshes(float
       tris2->InsertCellPoint( (*n)->GetNode(i)->GN);
       }
     }
-  ::ants::antscout << " done with tris " << std::endl;
+  std::cout << " done with tris " << std::endl;
   // Assign points and cells
   polydata1->SetPoints(vpoints1);
   polydata2->SetPoints(vpoints2);
@@ -1382,12 +1382,12 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
   if( m_ReadFromFile )
     {
     const char* filename = m_ParameterFileName.c_str();
-    ::ants::antscout << "Reading FEM problem from file: " << std::string(filename) << "\n";
+    std::cout << "Reading FEM problem from file: " << std::string(filename) << "\n";
     std::ifstream f;
     f.open(filename);
     if( !f )
       {
-      ::ants::antscout << "File " << filename << " not found!\n";
+      std::cout << "File " << filename << " not found!\n";
       return;
       }
 
@@ -1397,8 +1397,8 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
       }
     catch( ::itk::fem::FEMException & e )
       {
-      ::ants::antscout << "Error reading FEM problem: " << filename << "!\n";
-      e.Print(::ants::antscout);
+      std::cout << "Error reading FEM problem: " << filename << "!\n";
+      e.Print(std::cout);
       return;
       }
 
@@ -1430,23 +1430,23 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
     {
     for( ::itk::fem::Solver::NodeArray::iterator n = m_Solver.node.begin(); n != m_Solver.node.end(); ++n )
       {
-      ::ants::antscout << "Node#: " << (*n)->GN << ": ";
-      ::ants::antscout << " coord " << (*n)->GetCoordinates()
+      std::cout << "Node#: " << (*n)->GN << ": ";
+      std::cout << " coord " << (*n)->GetCoordinates()
                          << " coord2 " << manifoldIntegrator->GetGraphNode( (*n)->GN)->GetLocation() << std::endl;
       }
     for( ::itk::fem::Solver::ElementArray::iterator n = m_Solver.el.begin(); n != m_Solver.el.end(); ++n )
       {
-      ::ants::antscout << "Elt#: " << (*n)->GN << ": has " << (*n)->GetNumberOfNodes() << " nodes ";
+      std::cout << "Elt#: " << (*n)->GN << ": has " << (*n)->GetNumberOfNodes() << " nodes ";
       for( unsigned int i = 0; i < (*n)->GetNumberOfNodes(); i++ )
         {
-        ::ants::antscout << " coord " << (*n)->GetNode(i)->GetCoordinates() << std::endl;
+        std::cout << " coord " << (*n)->GetNode(i)->GetCoordinates() << std::endl;
         }
       }
     }
 
   unsigned int maxits = m_Solver.GetNumberOfDegreesOfFreedom(); // should be > twice ndofs
   // if (m_Debug)
-  ::ants::antscout << " ndof " << maxits << std::endl;
+  std::cout << " ndof " << maxits << std::endl;
   itpackWrapper.SetMaximumNumberIterations(maxits * 5);
   itpackWrapper.SetTolerance(1.e-4);
   itpackWrapper.SuccessiveOverrelaxation();
@@ -1458,12 +1458,12 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
   m_Solver.AssembleK();
   m_Solver.DecomposeK();
   //  this->ApplyRealForces();
-  ::ants::antscout << " appl force ";
+  std::cout << " appl force ";
   m_Solver.AssembleF();
   //  for (int i=0; i<maxits; i++) if (m_Solver.GetVectorValue(i) != 0) m_Solver.SetVectorValue(i,1.0);
-  ::ants::antscout << " b solve ";
+  std::cout << " b solve ";
   m_Solver.Solve();
-  ::ants::antscout << " e solve ";
+  std::cout << " e solve ";
   m_Solver.UpdateDisplacements(); // copies solution to nodes
   unsigned long ct  =  0;
   for( ::itk::fem::Solver::NodeArray::iterator n = m_Solver.node.begin(); n != m_Solver.node.end(); ++n )
@@ -1472,7 +1472,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
          d++ )
       {
       m_RealSolution[dof] = m_Solver.GetSolution(dof);
-      //      if ( ct % 10 == 0) ::ants::antscout << " mrdof " <<  m_RealSolution[dof]  << " dof " << dof <<
+      //      if ( ct % 10 == 0) std::cout << " mrdof " <<  m_RealSolution[dof]  << " dof " << dof <<
       // std::endl;
       }
     ct++;
@@ -1500,7 +1500,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
          d++ )
       {
       m_ImagSolution[dof] = m_Solver.GetSolution(dof);
-      //      if (ct % 10 == 0) ::ants::antscout << " midof " <<  m_ImagSolution[dof]  <<  " dof " << dof <<
+      //      if (ct % 10 == 0) std::cout << " midof " <<  m_ImagSolution[dof]  <<  " dof " << dof <<
       // std::endl;
       }
     ct++;
@@ -1564,7 +1564,7 @@ void  FEMDiscConformalMap<TSurface, TImage, TDimension>
         }
       }
     }
-  ::ants::antscout << "  distDistortion/ct " << distDistortion / (float)ct << " maxmfd " << maxmanifolddist
+  std::cout << "  distDistortion/ct " << distDistortion / (float)ct << " maxmfd " << maxmanifolddist
                      << std::endl;
   return;
 
@@ -1589,7 +1589,7 @@ template <typename TSurface, typename TImage, unsigned int TDimension>
 void  FEMDiscConformalMap<TSurface, TImage, TDimension>
 ::ConjugateHarmonic()
 {
-  ::ants::antscout << " Conformal coordinates " << std::endl;
+  std::cout << " Conformal coordinates " << std::endl;
 
   unsigned long ct  = 0;
 
