@@ -18,38 +18,41 @@
 namespace matHelper
 {
 template <typename TFloat, unsigned int dim>
-unsigned int Rows(const vnl_matrix_fixed<TFloat,dim,dim> &)
-{
-  return dim;
-}
-template <typename TFloat, unsigned int dim>
-unsigned int Columns(const vnl_matrix_fixed<TFloat,dim,dim> &)
+unsigned int Rows(const vnl_matrix_fixed<TFloat, dim, dim> &)
 {
   return dim;
 }
 
-template <typename TFloat,unsigned int rows, unsigned int columns>
-unsigned int Rows(const itk::Matrix<TFloat,rows,columns> &)
+template <typename TFloat, unsigned int dim>
+unsigned int Columns(const vnl_matrix_fixed<TFloat, dim, dim> &)
+{
+  return dim;
+}
+
+template <typename TFloat, unsigned int rows, unsigned int columns>
+unsigned int Rows(const itk::Matrix<TFloat, rows, columns> &)
 {
   return rows;
 }
 
-template <typename TFloat,unsigned int rows, unsigned int columns>
-unsigned int Columns(const itk::Matrix<TFloat,rows,columns> &)
+template <typename TFloat, unsigned int rows, unsigned int columns>
+unsigned int Columns(const itk::Matrix<TFloat, rows, columns> &)
 {
   return columns;
 }
+
 template <typename TFloat>
-unsigned int Rows(const itk::VariableSizeMatrix<TFloat> &mat)
+unsigned int Rows(const itk::VariableSizeMatrix<TFloat> & mat)
 {
   return mat.Rows();
 }
 
 template <typename TFloat>
-unsigned int Columns(const itk::VariableSizeMatrix<TFloat> &mat)
+unsigned int Columns(const itk::VariableSizeMatrix<TFloat> & mat)
 {
   return mat.Cols();
 }
+
 }
 
 template <class TensorType, class MatrixType>
@@ -62,11 +65,12 @@ void Vector2Matrix( TensorType & dtv, MatrixType & dtm )
   // dtm(1, 2) = dtm(2, 1) = dtv[4];
   // dtm(2, 2) = dtv[5];
   unsigned int tensorIndex = 0;
-  for(unsigned i = 0; i < matHelper::Rows(dtm); ++i)
+
+  for( unsigned i = 0; i < matHelper::Rows(dtm); ++i )
     {
-    for(unsigned j = i; matHelper::Columns(dtm); ++j, ++tensorIndex)
+    for( unsigned j = i; j < matHelper::Columns(dtm); ++j, ++tensorIndex )
       {
-      dtm(i,j) = dtm(j,i) = dtv[tensorIndex];
+      dtm(i, j) = dtm(j, i) = dtv[tensorIndex];
       }
     }
 }
@@ -76,7 +80,7 @@ MatrixType Vector2Matrix( TensorType dtv )
 {
   MatrixType dtm(3, 3);
 
-  Vector2Matrix<TensorType,MatrixType>(dtv,dtm);
+  Vector2Matrix<TensorType, MatrixType>(dtv, dtm);
 
   return dtm;
 }
@@ -93,11 +97,12 @@ TensorType Matrix2Vector( MatrixType dtm )
   // dtv[4] = dtm(1, 2);
   // dtv[5] = dtm(2, 2);
   unsigned int tensorIndex = 0;
-  for(unsigned i = 0; i < dtm.rows(); ++i)
+
+  for( unsigned i = 0; i < dtm.rows(); ++i )
     {
-    for(unsigned j = i; dtm.cols(); ++j, ++tensorIndex)
+    for( unsigned j = i; j < dtm.cols(); ++j, ++tensorIndex )
       {
-      dtv[tensorIndex] = dtm(i,j);
+      dtv[tensorIndex] = dtm(i, j);
       }
     }
   return dtv;
@@ -143,14 +148,14 @@ float DiffusionCoefficient( TensorType dtv, VectorType direction, bool normalize
 namespace tensorHelper
 {
 
-template<typename TFloat, unsigned int NDim>
-unsigned int size(const itk::SymmetricSecondRankTensor<TFloat,NDim> &)
+template <typename TFloat, unsigned int NDim>
+unsigned int size(const itk::SymmetricSecondRankTensor<TFloat, NDim> &)
 {
   return NDim;
 }
 
-template<typename TFloat, unsigned int NDim>
-unsigned int size(const itk::Vector<TFloat,NDim> &)
+template <typename TFloat, unsigned int NDim>
+unsigned int size(const itk::Vector<TFloat, NDim> &)
 {
   return NDim;
 }
@@ -180,22 +185,22 @@ TensorType TensorLogAndExp( TensorType dtv, bool takelog, bool & success)
   //   return dtv;
   //   }
   // rewrite above to avoid going beyond tensor array bounds.
-  {
-  unsigned int indices[3] = { 1, 2, 4 };
-  unsigned int jj;
-  for(jj = 0; indices[jj] < tensorHelper::size(dtv); ++jj)
     {
-    if(dtv[indices[jj]] != 0.0)
+    unsigned int indices[3] = { 1, 2, 4 };
+    unsigned int jj;
+    for( jj = 0; indices[jj] < tensorHelper::size(dtv); ++jj )
       {
-      break;
+      if( dtv[indices[jj]] != 0.0 )
+        {
+        break;
+        }
+      }
+    if( jj == 3 )
+      {
+      success = false;
+      return dtv;
       }
     }
-  if(jj == 3)
-    {
-    success = false;
-    return dtv;
-    }
-  }
 
   if( mag < eps )
     {
@@ -216,9 +221,9 @@ TensorType TensorLogAndExp( TensorType dtv, bool takelog, bool & success)
 
   if( fabs(e3) < eps )
     {
-    //success = false;
-    //ants::antscout << "-4" << std::flush;
-    //return dtv;
+    // success = false;
+    // std::cout << "-4" << std::flush;
+    // return dtv;
     }
 
   MatrixType eigmat(3, 3);
@@ -276,9 +281,10 @@ template <class TensorType>
 bool IsRealTensor( TensorType dtv )
 {
   bool isreal = true;
-  for ( unsigned int i=0; i<6; i++ )
+
+  for( unsigned int i = 0; i < 6; i++ )
     {
-    if ( !vnl_math_isfinite( dtv[i] ) )
+    if( !vnl_math_isfinite( dtv[i] ) )
       {
       isreal = false;
       }
@@ -289,6 +295,14 @@ bool IsRealTensor( TensorType dtv )
 template <class TensorType>
 float  GetTensorFA( TensorType dtv )
 {
+
+  // Check for zero diffusion (probably background) and return zero FA 
+  // if that's the case
+  if (dtv[0] + dtv[3] + dtv[5] == 0.0f) 
+    {
+      return 0.0f;
+    }
+
   typedef vnl_matrix<double> MatrixType;
   MatrixType DT(3, 3);
   DT.fill(0);
@@ -419,8 +433,6 @@ float  GetMetricTensorCost(  TVectorType dpath,  TTensorType dtv, unsigned int m
 template <class TVectorType, class TTensorType>
 TVectorType ChangeTensorByVector(  TVectorType dpath,  TTensorType dtv, float epsilon)
 {
-  typedef TVectorType VectorType;
-
   typedef vnl_matrix<double> MatrixType;
   MatrixType DT(3, 3);
   DT.fill(0);
@@ -503,8 +515,7 @@ float  GetTensorADC( TTensorType dtv,  unsigned int opt = 0)
     {
     return ( dtv[0] + dtv[3] + dtv[5] ) / 3.0;
     }
-   float eps = 1.e-9, mag = 0;
-
+  float eps = 1.e-9, mag = 0;
   for( unsigned int jj = 0; jj < 6; jj++ )
     {
     float ff = dtv[jj];
@@ -525,28 +536,6 @@ float  GetTensorADC( TTensorType dtv,  unsigned int opt = 0)
     return 0;
     }
 
-   //  typedef itk::Vector<float, 6> TensorTypeIn;
-  typedef itk::Vector<float, 6> TensorType;
-  typedef itk::Vector<float, 6> TensorTypeOut;
-  typedef itk::Vector<float, 6> TensorTypeIn;
-  const unsigned int ImageDimension = 3;
-  typedef itk::Image<TensorTypeIn, ImageDimension>  InTensorImageType;
-  typedef itk::Image<TensorTypeOut, ImageDimension> OutTensorImageType;
-  typedef itk::Image<TensorTypeOut, ImageDimension> TensorImageType;
-  typedef     InTensorImageType::Pointer            TensorImagePointer;
-  typedef float                                     PixelType;
-  typedef itk::Vector<float, ImageDimension>        VectorType1;
-  typedef itk::Image<VectorType1, ImageDimension>   FieldType;
-  typedef itk::Image<PixelType, ImageDimension>     ImageType;
-  typedef itk::ImageFileReader<InTensorImageType>   readertype;
-  typedef itk::ImageFileWriter<OutTensorImageType>  writertype;
-  typedef ImageType::IndexType                      IndexType;
-  typedef ImageType::SizeType                       SizeType;
-  typedef ImageType::SpacingType                    SpacingType;
-//   typedef itk::AffineTransform<double,ImageDimension>   AffineTransformType;
-//   typedef itk::LinearInterpolateImageFunction<ImageType,double>  InterpolatorType1;
-//   typedef itk::NearestNeighborInterpolateImageFunction<ImageType,double>  InterpolatorType2;
-
   itk::Vector<float, 6> dtv2;
   typedef vnl_matrix<double> MatrixType;
   MatrixType DT(3, 3);
@@ -557,22 +546,20 @@ float  GetTensorADC( TTensorType dtv,  unsigned int opt = 0)
   DT(1, 0) = DT(0, 1) = dtv[1];
   DT(2, 0) = DT(0, 2) = dtv[2];
   DT(2, 1) = DT(1, 2) = dtv[4];
-  //  if (takelog )ants::antscout << " TAKING LOG " << std::endl;  elseants::antscout << "TAKING EXP " << std::endl;
-  // ants::antscout << " dtv " << dtv << std::endl;
+  //  if (takelog )std::cout << " TAKING LOG " << std::endl;  elsestd::cout << "TAKING EXP " << std::endl;
+  // std::cout << " dtv " << dtv << std::endl;
   vnl_symmetric_eigensystem<double> eig(DT);
   double                            e1 = (eig.D(0, 0) );
   double                            e2 = (eig.D(1, 1) );
   double                            e3 = (eig.D(2, 2) );
 
   /*
-
-  opt	return
-  1	ADC
-  2   radial diffusion
-  3	e1
-  4	e2
-  5	e3
-
+  opt  return
+  1    ADC
+  2    radial diffusion
+  3    e1
+  4    e2
+  5    e3
   */
 
   if( opt <= 1 )
@@ -672,28 +659,6 @@ itk::RGBPixel<float>   GetTensorPrincipalEigenvector( TTensorType dtv )
     return zero;
     }
 
-  //  typedef itk::Vector<float, 6> TensorTypeIn;
-  typedef itk::Vector<float, 6> TensorType;
-  typedef itk::Vector<float, 6> TensorTypeOut;
-  typedef itk::Vector<float, 6> TensorTypeIn;
-  const unsigned int ImageDimension = 3;
-  typedef itk::Image<TensorTypeIn, ImageDimension>  InTensorImageType;
-  typedef itk::Image<TensorTypeOut, ImageDimension> OutTensorImageType;
-  typedef itk::Image<TensorTypeOut, ImageDimension> TensorImageType;
-  typedef     InTensorImageType::Pointer            TensorImagePointer;
-  typedef float                                     PixelType;
-  typedef itk::Vector<float, ImageDimension>        VectorType1;
-  typedef itk::Image<VectorType1, ImageDimension>   FieldType;
-  typedef itk::Image<PixelType, ImageDimension>     ImageType;
-  typedef itk::ImageFileReader<InTensorImageType>   readertype;
-  typedef itk::ImageFileWriter<OutTensorImageType>  writertype;
-  typedef ImageType::IndexType                      IndexType;
-  typedef ImageType::SizeType                       SizeType;
-  typedef ImageType::SpacingType                    SpacingType;
-//   typedef itk::AffineTransform<double,ImageDimension>   AffineTransformType;
-//   typedef itk::LinearInterpolateImageFunction<ImageType,double>  InterpolatorType1;
-//   typedef itk::NearestNeighborInterpolateImageFunction<ImageType,double>  InterpolatorType2;
-
   itk::Vector<float, 6> dtv2;
   typedef vnl_matrix<double> MatrixType;
   MatrixType DT(3, 3);
@@ -704,8 +669,8 @@ itk::RGBPixel<float>   GetTensorPrincipalEigenvector( TTensorType dtv )
   DT(1, 0) = DT(0, 1) = dtv[1];
   DT(2, 0) = DT(0, 2) = dtv[2];
   DT(2, 1) = DT(1, 2) = dtv[4];
-  //  if (takelog )ants::antscout << " TAKING LOG " << std::endl;  elseants::antscout << "TAKING EXP " << std::endl;
-  // ants::antscout << " dtv " << dtv << std::endl;
+  //  if (takelog )std::cout << " TAKING LOG " << std::endl;  elsestd::cout << "TAKING EXP " << std::endl;
+  // std::cout << " dtv " << dtv << std::endl;
   vnl_symmetric_eigensystem<double> eig(DT);
 
   itk::RGBPixel<float> rgb;
@@ -775,28 +740,6 @@ itk::Vector<float>   GetTensorPrincipalEigenvector( TTensorType dtv, unsigned in
     return zero;
     }
 
-  //  typedef itk::Vector<float, 6> TensorTypeIn;
-  typedef itk::Vector<float, 6> TensorType;
-  typedef itk::Vector<float, 6> TensorTypeOut;
-  typedef itk::Vector<float, 6> TensorTypeIn;
-  const unsigned int ImageDimension = 3;
-  typedef itk::Image<TensorTypeIn, ImageDimension>  InTensorImageType;
-  typedef itk::Image<TensorTypeOut, ImageDimension> OutTensorImageType;
-  typedef itk::Image<TensorTypeOut, ImageDimension> TensorImageType;
-  typedef     InTensorImageType::Pointer            TensorImagePointer;
-  typedef float                                     PixelType;
-  typedef itk::Vector<float, ImageDimension>        VectorType1;
-  typedef itk::Image<VectorType1, ImageDimension>   FieldType;
-  typedef itk::Image<PixelType, ImageDimension>     ImageType;
-  typedef itk::ImageFileReader<InTensorImageType>   readertype;
-  typedef itk::ImageFileWriter<OutTensorImageType>  writertype;
-  typedef ImageType::IndexType                      IndexType;
-  typedef ImageType::SizeType                       SizeType;
-  typedef ImageType::SpacingType                    SpacingType;
-//   typedef itk::AffineTransform<double,ImageDimension>   AffineTransformType;
-//   typedef itk::LinearInterpolateImageFunction<ImageType,double>  InterpolatorType1;
-//   typedef itk::NearestNeighborInterpolateImageFunction<ImageType,double>  InterpolatorType2;
-
   itk::Vector<float, 6> dtv2;
   typedef vnl_matrix<double> MatrixType;
   MatrixType DT(3, 3);
@@ -807,8 +750,8 @@ itk::Vector<float>   GetTensorPrincipalEigenvector( TTensorType dtv, unsigned in
   DT(1, 0) = DT(0, 1) = dtv[1];
   DT(2, 0) = DT(0, 2) = dtv[2];
   DT(2, 1) = DT(1, 2) = dtv[4];
-  //  if (takelog )ants::antscout << " TAKING LOG " << std::endl;  else ants::antscout << "TAKING EXP " << std::endl;
-  // ants::antscout << " dtv " << dtv << std::endl;
+  //  if (takelog )std::cout << " TAKING LOG " << std::endl;  else std::cout << "TAKING EXP " << std::endl;
+  // std::cout << " dtv " << dtv << std::endl;
   vnl_symmetric_eigensystem<double> eig(DT);
 
   itk::Vector<float, 3> rgb;
