@@ -22,16 +22,40 @@ namespace itk
 {
 namespace ants
 {
+
+  std::string ConvertToHumanReadable(const std::string input)
+    {
+    typedef std::map<std::string,std::string> TypeMapType;
+    TypeMapType cnvtMap;
+    cnvtMap[typeid(signed char).name()] = "signed int";
+    cnvtMap[typeid(unsigned char).name()] = "unsigned int";
+    cnvtMap[typeid(signed short).name()] = "signed int";
+    cnvtMap[typeid(unsigned short).name()] = "unsigned int";
+    cnvtMap[typeid(signed int).name()] = "signed int";
+    cnvtMap[typeid(unsigned int).name()] = "unsigned int";
+    cnvtMap[typeid(signed long).name()] = "signed int";
+    cnvtMap[typeid(unsigned long).name()] = "unsigned int";
+    cnvtMap[typeid(float).name()] = "float";
+    cnvtMap[typeid(double).name()] = "double";
+    cnvtMap[typeid(std::string).name()] = "std::string";
+    cnvtMap[typeid(char *).name()] = "char *";
+
+    TypeMapType::iterator mi=cnvtMap.find(input);
+    if ( mi == cnvtMap.end() )
+      {
+      return std::string("Unmapped Type");
+      }
+    return mi->second;
+    }
 CommandLineParser
-::CommandLineParser()
+::CommandLineParser():
+  m_LeftDelimiter  ( '[' ),
+  m_RightDelimiter ( ']' )
 {
   this->m_Options.clear();
   this->m_Command.clear();
   this->m_CommandDescription.clear();
   this->m_UnknownOptions.clear();
-
-  this->m_LeftDelimiter = '[';
-  this->m_RightDelimiter = ']';
 }
 
 void
@@ -69,7 +93,7 @@ CommandLineParser
   return s2.length() <= s1.length() && s1.compare(0, s2.length(), s2) == 0;
 }
 
-void
+int
 CommandLineParser
 ::Parse( unsigned int argc, char * *argv )
 {
@@ -78,8 +102,12 @@ CommandLineParser
 
   unsigned int n = 0;
   unsigned int order = 0;
+  bool allFlagsAreValid = true;
 
-  this->m_Command = arguments[n++];
+  if ( arguments.size() > 1 )
+    {
+    this->m_Command = arguments[n++];
+    }
 
   while( n < arguments.size() )
     {
@@ -95,8 +123,12 @@ CommandLineParser
       {
       name = argument.substr( 1, 2 );
       }
-
-    if( !( name.empty() ) && !atof( name.c_str() ) )
+    if ( name.size() > 0 )
+      allFlagsAreValid &= this->ValidateFlag(name);
+    if( ( !( name.empty() ) )     &&
+        ( !atof( name.c_str() ) ) &&
+        ( name.size() > 0 )
+      )
       {
       OptionType::Pointer option = this->GetOption( name );
       if( !option )
@@ -171,8 +203,13 @@ CommandLineParser
         }
       }
     }
-
+  if( ! allFlagsAreValid )
+    {
+    std::cerr << "ERROR:  Invalid command line flags found! Aborting execution." << std::endl;
+    return EXIT_FAILURE;
+    }
   this->AssignStages();
+  return EXIT_SUCCESS;
 }
 
 std::vector<std::string>
@@ -193,80 +230,87 @@ CommandLineParser
     {
     std::string a( argv[n] );
 
-    // replace left delimiters
-    std::replace( a.begin(), a.end(), '{', '[' );
-    std::replace( a.begin(), a.end(), '(', '[' );
-    std::replace( a.begin(), a.end(), '<', '[' );
-
-    // replace right delimiters
-    std::replace( a.begin(), a.end(), '}', ']' );
-    std::replace( a.begin(), a.end(), ')', ']' );
-    std::replace( a.begin(), a.end(), '>', ']' );
-
-    if( isArgOpen )
+    if( n == 0 )
       {
-      std::size_t leftDelimiterPosition = a.find( this->m_LeftDelimiter );
-      if( leftDelimiterPosition != std::string::npos )
-        {
-        itkExceptionMacro( "Incorrect command line specification. Missing leftDelimiterPosition? " << a);
-        }
+      arguments.push_back( a );
+      }
+    else
+      {
+      // replace left delimiters
+      std::replace( a.begin(),  a.begin()+1, '{', '[' );
+      std::replace( a.begin(), a.begin()+1, '(', '[' );
+      std::replace( a.begin(), a.begin()+1, '<', '[' );
 
-      std::size_t rightDelimiterPosition = a.find( this->m_RightDelimiter );
-      if( rightDelimiterPosition != std::string::npos )
+      // replace right delimiters
+      std::replace( a.end()-1, a.end(), '}', ']' );
+      std::replace( a.end()-1, a.end(), ')', ']' );
+      std::replace( a.end()-1, a.end(), '>', ']' );
+
+      if( isArgOpen )
         {
-        if( rightDelimiterPosition < a.length() - 1 )
+        std::size_t leftDelimiterPosition = a.find( this->m_LeftDelimiter );
+        if( leftDelimiterPosition != std::string::npos )
           {
-          itkExceptionMacro( "Incorrect command line specification. Missing rightDelimiterPosition? " << a  );
+          itkExceptionMacro( "Incorrect command line specification. Missing leftDelimiterPosition? " << a );
+          }
+
+        std::size_t rightDelimiterPosition = a.find( this->m_RightDelimiter );
+        if( rightDelimiterPosition != std::string::npos )
+          {
+          if( rightDelimiterPosition < a.length() - 1 )
+            {
+            itkExceptionMacro( "Incorrect command line specification. Missing rightDelimiterPosition? " << a );
+            }
+          else
+            {
+            currentArg += a;
+            arguments.push_back( currentArg );
+            currentArg.clear();
+            isArgOpen = false;
+            }
           }
         else
           {
           currentArg += a;
+          }
+        }
+      else
+        {
+        std::size_t leftDelimiterPosition = a.find( this->m_LeftDelimiter );
+        std::size_t rightDelimiterPosition = a.find( this->m_RightDelimiter );
+
+        if( leftDelimiterPosition == std::string::npos )
+          {
+          if( rightDelimiterPosition == std::string::npos )
+            {
+            currentArg += a;
+            arguments.push_back( currentArg );
+            currentArg.clear();
+            }
+          else
+            {
+            itkExceptionMacro( "Incorrect command line specification. " << a);
+            }
+          }
+        else if( leftDelimiterPosition != std::string::npos &&
+                 rightDelimiterPosition != std::string::npos &&
+                 leftDelimiterPosition < rightDelimiterPosition )
+          {
+          if( rightDelimiterPosition < a.length() - 1 )
+            {
+            itkExceptionMacro( "Incorrect command line specification. " << a );
+            }
+          currentArg += a;
           arguments.push_back( currentArg );
           currentArg.clear();
           isArgOpen = false;
           }
-        }
-      else
-        {
-        currentArg += a;
-        }
-      }
-    else
-      {
-      std::size_t leftDelimiterPosition = a.find( this->m_LeftDelimiter );
-      std::size_t rightDelimiterPosition = a.find( this->m_RightDelimiter );
-
-      if( leftDelimiterPosition == std::string::npos )
-        {
-        if( rightDelimiterPosition == std::string::npos )
+        else if( rightDelimiterPosition == std::string::npos &&
+                 leftDelimiterPosition != std::string::npos )
           {
           currentArg += a;
-          arguments.push_back( currentArg );
-          currentArg.clear();
+          isArgOpen = true;
           }
-        else
-          {
-          itkExceptionMacro( "Incorrect command line specification. " << a);
-          }
-        }
-      else if( leftDelimiterPosition != std::string::npos &&
-               rightDelimiterPosition != std::string::npos &&
-               leftDelimiterPosition < rightDelimiterPosition )
-        {
-        if( rightDelimiterPosition < a.length() - 1 )
-          {
-          itkExceptionMacro( "Incorrect command line specification. " << a );
-          }
-        currentArg += a;
-        arguments.push_back( currentArg );
-        currentArg.clear();
-        isArgOpen = false;
-        }
-      else if( rightDelimiterPosition == std::string::npos &&
-               leftDelimiterPosition != std::string::npos )
-        {
-        currentArg += a;
-        isArgOpen = true;
         }
       }
     }
@@ -291,7 +335,7 @@ CommandLineParser
       return *it;
       }
     }
-  return NULL;
+  return ITK_NULLPTR;
 }
 
 CommandLineParser::OptionType::Pointer
@@ -307,7 +351,31 @@ CommandLineParser
       return *it;
       }
     }
-  return NULL;
+  return ITK_NULLPTR;
+}
+
+bool
+CommandLineParser::
+ValidateFlag(const std::string & currentFlag)
+{
+  bool validFlagFound = false;
+  for( OptionListType::const_iterator it = this->m_Options.begin(); it != this->m_Options.end(); ++it )
+    {
+    const char shortName = (*it)->GetShortName();
+    const std::string longName  = (*it)->GetLongName();
+    if( (    ( currentFlag.size() == 1 ) &&
+             ( shortName == currentFlag[0] ) )
+          || ( longName == currentFlag ) )
+      {
+      validFlagFound = true;
+      }
+    }
+
+  if ( ( ! validFlagFound ) && ( currentFlag.size() > 0 ))
+    {
+    std::cout << "ERROR:  Invalid flag provided " << currentFlag << std::endl;
+    }
+  return validFlagFound;
 }
 
 void
